pub struct FirewallActivation { /* private fields */ }Expand description
Implements a client for the Network Security API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = FirewallActivation::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_firewall_endpoints()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for managing Firewall Endpoints and Associations.
Configuration
To configure FirewallActivation use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://networksecurity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
FirewallActivation holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap FirewallActivation in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl FirewallActivation
impl FirewallActivation
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for FirewallActivation.
let client = FirewallActivation::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: FirewallActivation + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: FirewallActivation + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_firewall_endpoints(&self) -> ListFirewallEndpoints
pub fn list_firewall_endpoints(&self) -> ListFirewallEndpoints
Lists FirewallEndpoints in a given organization and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, parent: &str
) -> Result<()> {
let mut list = client.list_firewall_endpoints()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_firewall_endpoint(&self) -> GetFirewallEndpoint
pub fn get_firewall_endpoint(&self) -> GetFirewallEndpoint
Gets details of a single org Endpoint.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, name: &str
) -> Result<()> {
let response = client.get_firewall_endpoint()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_firewall_endpoint(&self) -> CreateFirewallEndpoint
pub fn create_firewall_endpoint(&self) -> CreateFirewallEndpoint
Creates a new FirewallEndpoint in a given organization and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::FirewallEndpoint;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, parent: &str
) -> Result<()> {
let response = client.create_firewall_endpoint()
.set_parent(parent)
.set_firewall_endpoint(
FirewallEndpoint::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_firewall_endpoint(&self) -> DeleteFirewallEndpoint
pub fn delete_firewall_endpoint(&self) -> DeleteFirewallEndpoint
Deletes a single org Endpoint.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, name: &str
) -> Result<()> {
client.delete_firewall_endpoint()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn update_firewall_endpoint(&self) -> UpdateFirewallEndpoint
pub fn update_firewall_endpoint(&self) -> UpdateFirewallEndpoint
Update a single org Endpoint.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::FirewallEndpoint;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, name: &str
) -> Result<()> {
let response = client.update_firewall_endpoint()
.set_firewall_endpoint(
FirewallEndpoint::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_firewall_endpoint_associations(
&self,
) -> ListFirewallEndpointAssociations
pub fn list_firewall_endpoint_associations( &self, ) -> ListFirewallEndpointAssociations
Lists Associations in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, parent: &str
) -> Result<()> {
let mut list = client.list_firewall_endpoint_associations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_firewall_endpoint_association(
&self,
) -> GetFirewallEndpointAssociation
pub fn get_firewall_endpoint_association( &self, ) -> GetFirewallEndpointAssociation
Gets details of a single FirewallEndpointAssociation.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, name: &str
) -> Result<()> {
let response = client.get_firewall_endpoint_association()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_firewall_endpoint_association(
&self,
) -> CreateFirewallEndpointAssociation
pub fn create_firewall_endpoint_association( &self, ) -> CreateFirewallEndpointAssociation
Creates a new FirewallEndpointAssociation in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::FirewallEndpointAssociation;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, parent: &str
) -> Result<()> {
let response = client.create_firewall_endpoint_association()
.set_parent(parent)
.set_firewall_endpoint_association(
FirewallEndpointAssociation::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_firewall_endpoint_association(
&self,
) -> DeleteFirewallEndpointAssociation
pub fn delete_firewall_endpoint_association( &self, ) -> DeleteFirewallEndpointAssociation
Deletes a single FirewallEndpointAssociation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, name: &str
) -> Result<()> {
client.delete_firewall_endpoint_association()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn update_firewall_endpoint_association(
&self,
) -> UpdateFirewallEndpointAssociation
pub fn update_firewall_endpoint_association( &self, ) -> UpdateFirewallEndpointAssociation
Update a single FirewallEndpointAssociation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::FirewallEndpointAssociation;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation, name: &str
) -> Result<()> {
let response = client.update_firewall_endpoint_association()
.set_firewall_endpoint_association(
FirewallEndpointAssociation::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &FirewallActivation
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for FirewallActivation
impl Clone for FirewallActivation
Sourcefn clone(&self) -> FirewallActivation
fn clone(&self) -> FirewallActivation
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more