SecurityProfileGroupService

Struct SecurityProfileGroupService 

pub struct SecurityProfileGroupService { /* private fields */ }
Implements a client for the Network Security API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
   organization_id: &str,
   location_id: &str,
) -> anyhow::Result<()> {
    let client = SecurityProfileGroupService::builder().build().await?;
    let mut list = client.list_security_profile_groups()
        .set_parent(format!("organizations/{organization_id}/locations/{location_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}

Service Description

SecurityProfileGroup is a resource that defines an action for specific threat signatures or severity levels.

Configuration

To configure SecurityProfileGroupService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

SecurityProfileGroupService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap SecurityProfileGroupService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl SecurityProfileGroupService

pub fn builder() -> ClientBuilder

Returns a builder for SecurityProfileGroupService.

let client = SecurityProfileGroupService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: SecurityProfileGroupService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_security_profile_groups(&self) -> ListSecurityProfileGroups

Lists SecurityProfileGroups in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str
) -> Result<()> {
    let mut list = client.list_security_profile_groups()
        .set_parent(format!("organizations/{organization_id}/locations/{location_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_security_profile_group(&self) -> GetSecurityProfileGroup

Gets details of a single SecurityProfileGroup.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str, security_profile_group_id: &str
) -> Result<()> {
    let response = client.get_security_profile_group()
        .set_name(format!("organizations/{organization_id}/locations/{location_id}/securityProfileGroups/{security_profile_group_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_security_profile_group(&self) -> CreateSecurityProfileGroup

Creates a new SecurityProfileGroup in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str
) -> Result<()> {
    let response = client.create_security_profile_group()
        .set_parent(format!("organizations/{organization_id}/locations/{location_id}"))
        .set_security_profile_group(
            SecurityProfileGroup::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_security_profile_group(&self) -> UpdateSecurityProfileGroup

Updates the parameters of a single SecurityProfileGroup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str, security_profile_group_id: &str
) -> Result<()> {
    let response = client.update_security_profile_group()
        .set_security_profile_group(
            SecurityProfileGroup::new().set_name(format!("organizations/{organization_id}/locations/{location_id}/securityProfileGroups/{security_profile_group_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_security_profile_group(&self) -> DeleteSecurityProfileGroup

Deletes a single SecurityProfileGroup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str, security_profile_group_id: &str
) -> Result<()> {
    client.delete_security_profile_group()
        .set_name(format!("organizations/{organization_id}/locations/{location_id}/securityProfileGroups/{security_profile_group_id}"))
        .poller().until_done().await?;
    Ok(())
}
pub fn list_security_profiles(&self) -> ListSecurityProfiles

Lists SecurityProfiles in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str
) -> Result<()> {
    let mut list = client.list_security_profiles()
        .set_parent(format!("organizations/{organization_id}/locations/{location_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_security_profile(&self) -> GetSecurityProfile

Gets details of a single SecurityProfile.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str, security_profile_id: &str
) -> Result<()> {
    let response = client.get_security_profile()
        .set_name(format!("organizations/{organization_id}/locations/{location_id}/securityProfiles/{security_profile_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_security_profile(&self) -> CreateSecurityProfile

Creates a new SecurityProfile in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::SecurityProfile;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str
) -> Result<()> {
    let response = client.create_security_profile()
        .set_parent(format!("organizations/{organization_id}/locations/{location_id}"))
        .set_security_profile(
            SecurityProfile::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_security_profile(&self) -> UpdateSecurityProfile

Updates the parameters of a single SecurityProfile.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::SecurityProfile;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str, security_profile_id: &str
) -> Result<()> {
    let response = client.update_security_profile()
        .set_security_profile(
            SecurityProfile::new().set_name(format!("organizations/{organization_id}/locations/{location_id}/securityProfiles/{security_profile_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_security_profile(&self) -> DeleteSecurityProfile

Deletes a single SecurityProfile.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService, organization_id: &str, location_id: &str, security_profile_id: &str
) -> Result<()> {
    client.delete_security_profile()
        .set_name(format!("organizations/{organization_id}/locations/{location_id}/securityProfiles/{security_profile_id}"))
        .poller().until_done().await?;
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: * Global locations: If name is empty, the method lists the public locations available to all projects. * Project-specific locations: If name follows the format projects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.

For gRPC and client library implementations, the resource name is passed as the name field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &SecurityProfileGroupService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}