Module model

Module model 

The messages and enums that are part of this client library.

Modules

address_group
Defines additional types related to AddressGroup.
authorization_policy
Defines additional types related to AuthorizationPolicy.
authz_policy
Defines additional types related to AuthzPolicy.
backend_authentication_config
Defines additional types related to BackendAuthenticationConfig.
certificate_provider
Defines additional types related to CertificateProvider.
dns_threat_detector
Defines additional types related to DnsThreatDetector.
firewall_endpoint
Defines additional types related to FirewallEndpoint.
firewall_endpoint_association
Defines additional types related to FirewallEndpointAssociation.
gateway_security_policy_rule
Defines additional types related to GatewaySecurityPolicyRule.
intercept_deployment
Defines additional types related to InterceptDeployment.
intercept_deployment_group
Defines additional types related to InterceptDeploymentGroup.
intercept_endpoint_group
Defines additional types related to InterceptEndpointGroup.
intercept_endpoint_group_association
Defines additional types related to InterceptEndpointGroupAssociation.
intercept_location
Defines additional types related to InterceptLocation.
list_address_group_references_response
Defines additional types related to ListAddressGroupReferencesResponse.
mirroring_deployment
Defines additional types related to MirroringDeployment.
mirroring_deployment_group
Defines additional types related to MirroringDeploymentGroup.
mirroring_endpoint_group
Defines additional types related to MirroringEndpointGroup.
mirroring_endpoint_group_association
Defines additional types related to MirroringEndpointGroupAssociation.
mirroring_location
Defines additional types related to MirroringLocation.
security_profile
Defines additional types related to SecurityProfile.
server_tls_policy
Defines additional types related to ServerTlsPolicy.
tls_inspection_policy
Defines additional types related to TlsInspectionPolicy.
url_filter
Defines additional types related to UrlFilter.
validation_ca
Defines additional types related to ValidationCA.

Structs

AddAddressGroupItemsRequest
Request used by the AddAddressGroupItems method.
AddressGroup
AddressGroup is a resource that specifies how a collection of IP/DNS used in Firewall Policy.
AntivirusOverride
Defines what action to take for antivirus threats per protocol.
AuthorizationPolicy
AuthorizationPolicy is a resource that specifies how a server should authorize incoming connections. This resource in itself does not change the configuration unless it’s attached to a target https proxy or endpoint config selector resource.
AuthzPolicy
AuthzPolicy is a resource that allows to forward traffic to a callout backend designed to scan the traffic for security purposes.
BackendAuthenticationConfig
BackendAuthenticationConfig message groups the TrustConfig together with other settings that control how the load balancer authenticates, and expresses its identity to, the backend:
CertificateProvider
Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication.
CertificateProviderInstance
Specification of a TLS certificate provider instance. Workloads may have one or more CertificateProvider instances (plugins) and one of them is enabled and configured by specifying this message. Workloads use the values from this message to locate and load the CertificateProvider instance configuration.
ClientTlsPolicy
ClientTlsPolicy is a resource that specifies how a client should authenticate connections to backends of a service. This resource itself does not affect configuration unless it is attached to a backend service resource.
CloneAddressGroupItemsRequest
Request used by the CloneAddressGroupItems method.
CreateAddressGroupRequest
Request used by the CreateAddressGroup method.
CreateAuthorizationPolicyRequest
Request used by the CreateAuthorizationPolicy method.
CreateAuthzPolicyRequest
Message for creating an AuthzPolicy resource.
CreateBackendAuthenticationConfigRequest
Request used by the CreateBackendAuthenticationConfig method.
CreateClientTlsPolicyRequest
Request used by the CreateClientTlsPolicy method.
CreateDnsThreatDetectorRequest
The message to create a DnsThreatDetector.
CreateFirewallEndpointAssociationRequest
Message for creating a Association
CreateFirewallEndpointRequest
Message for creating a Endpoint
CreateGatewaySecurityPolicyRequest
Request used by the CreateGatewaySecurityPolicy method.
CreateGatewaySecurityPolicyRuleRequest
Methods for GatewaySecurityPolicy RULES/GatewaySecurityPolicyRules. Request used by the CreateGatewaySecurityPolicyRule method.
CreateInterceptDeploymentGroupRequest
Request message for CreateInterceptDeploymentGroup.
CreateInterceptDeploymentRequest
Request message for CreateInterceptDeployment.
CreateInterceptEndpointGroupAssociationRequest
Request message for CreateInterceptEndpointGroupAssociation.
CreateInterceptEndpointGroupRequest
Request message for CreateInterceptEndpointGroup.
CreateMirroringDeploymentGroupRequest
Request message for CreateMirroringDeploymentGroup.
CreateMirroringDeploymentRequest
Request message for CreateMirroringDeployment.
CreateMirroringEndpointGroupAssociationRequest
Request message for CreateMirroringEndpointGroupAssociation.
CreateMirroringEndpointGroupRequest
Request message for CreateMirroringEndpointGroup.
CreateSecurityProfileGroupRequest
Request used by the CreateSecurityProfileGroup method.
CreateSecurityProfileRequest
Request used by the CreateSecurityProfile method.
CreateServerTlsPolicyRequest
Request used by the CreateServerTlsPolicy method.
CreateTlsInspectionPolicyRequest
Request used by the CreateTlsInspectionPolicy method.
CreateUrlListRequest
Request used by the CreateUrlList method.
CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.
DeleteAddressGroupRequest
Request used by the DeleteAddressGroup method.
DeleteAuthorizationPolicyRequest
Request used by the DeleteAuthorizationPolicy method.
DeleteAuthzPolicyRequest
Message for deleting an AuthzPolicy resource.
DeleteBackendAuthenticationConfigRequest
Request used by the DeleteBackendAuthenticationConfig method.
DeleteClientTlsPolicyRequest
Request used by the DeleteClientTlsPolicy method.
DeleteDnsThreatDetectorRequest
The message for deleting a DnsThreatDetector.
DeleteFirewallEndpointAssociationRequest
Message for deleting a Association
DeleteFirewallEndpointRequest
Message for deleting a Endpoint
DeleteGatewaySecurityPolicyRequest
Request used by the DeleteGatewaySecurityPolicy method.
DeleteGatewaySecurityPolicyRuleRequest
Request used by the DeleteGatewaySecurityPolicyRule method.
DeleteInterceptDeploymentGroupRequest
Request message for DeleteInterceptDeploymentGroup.
DeleteInterceptDeploymentRequest
Request message for DeleteInterceptDeployment.
DeleteInterceptEndpointGroupAssociationRequest
Request message for DeleteInterceptEndpointGroupAssociation.
DeleteInterceptEndpointGroupRequest
Request message for DeleteInterceptEndpointGroup.
DeleteMirroringDeploymentGroupRequest
Request message for DeleteMirroringDeploymentGroup.
DeleteMirroringDeploymentRequest
Request message for DeleteMirroringDeployment.
DeleteMirroringEndpointGroupAssociationRequest
Request message for DeleteMirroringEndpointGroupAssociation.
DeleteMirroringEndpointGroupRequest
Request message for DeleteMirroringEndpointGroup.
DeleteSecurityProfileGroupRequest
Request used by the DeleteSecurityProfileGroup method.
DeleteSecurityProfileRequest
Request used by the DeleteSecurityProfile method.
DeleteServerTlsPolicyRequest
Request used by the DeleteServerTlsPolicy method.
DeleteTlsInspectionPolicyRequest
Request used by the DeleteTlsInspectionPolicy method.
DeleteUrlListRequest
Request used by the DeleteUrlList method.
DnsThreatDetector
A DNS threat detector sends DNS query logs to a provider that then analyzes the logs to identify threat events in the DNS queries. By default, all VPC networks in your projects are included. You can exclude specific networks by supplying excluded_networks.
FirewallEndpoint
Message describing Endpoint object.
FirewallEndpointAssociation
Message describing Association object
GatewaySecurityPolicy
The GatewaySecurityPolicy resource contains a collection of GatewaySecurityPolicyRules and associated metadata.
GatewaySecurityPolicyRule
The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.
GetAddressGroupRequest
Request used by the GetAddressGroup method.
GetAuthorizationPolicyRequest
Request used by the GetAuthorizationPolicy method.
GetAuthzPolicyRequest
Message for getting a AuthzPolicy resource.
GetBackendAuthenticationConfigRequest
Request used by the GetBackendAuthenticationConfig method.
GetClientTlsPolicyRequest
Request used by the GetClientTlsPolicy method.
GetDnsThreatDetectorRequest
The message sent to get a DnsThreatDetector.
GetFirewallEndpointAssociationRequest
Message for getting a Association
GetFirewallEndpointRequest
Message for getting a Endpoint
GetGatewaySecurityPolicyRequest
Request used by the GetGatewaySecurityPolicy method.
GetGatewaySecurityPolicyRuleRequest
Request used by the GetGatewaySecurityPolicyRule method.
GetInterceptDeploymentGroupRequest
Request message for GetInterceptDeploymentGroup.
GetInterceptDeploymentRequest
Request message for GetInterceptDeployment.
GetInterceptEndpointGroupAssociationRequest
Request message for GetInterceptEndpointGroupAssociation.
GetInterceptEndpointGroupRequest
Request message for GetInterceptEndpointGroup.
GetMirroringDeploymentGroupRequest
Request message for GetMirroringDeploymentGroup.
GetMirroringDeploymentRequest
Request message for GetMirroringDeployment.
GetMirroringEndpointGroupAssociationRequest
Request message for GetMirroringEndpointGroupAssociation.
GetMirroringEndpointGroupRequest
Request message for GetMirroringEndpointGroup.
GetSecurityProfileGroupRequest
Request used by the GetSecurityProfileGroup method.
GetSecurityProfileRequest
Request used by the GetSecurityProfile method.
GetServerTlsPolicyRequest
Request used by the GetServerTlsPolicy method.
GetTlsInspectionPolicyRequest
Request used by the GetTlsInspectionPolicy method.
GetUrlListRequest
Request used by the GetUrlList method.
GrpcEndpoint
Specification of the GRPC Endpoint.
InterceptDeployment
A deployment represents a zonal intercept backend ready to accept GENEVE-encapsulated traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global intercept service.
InterceptDeploymentGroup
A deployment group aggregates many zonal intercept backends (deployments) into a single global intercept service. Consumers can connect this service using an endpoint group.
InterceptEndpointGroup
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure intercept for a network, consumers must create:
InterceptEndpointGroupAssociation
An endpoint group association represents a link between a network and an endpoint group in the organization.
InterceptLocation
Details about intercept in a specific cloud location.
ListAddressGroupReferencesRequest
Request used by the ListAddressGroupReferences method.
ListAddressGroupReferencesResponse
Response of the ListAddressGroupReferences method.
ListAddressGroupsRequest
Request used with the ListAddressGroups method.
ListAddressGroupsResponse
Response returned by the ListAddressGroups method.
ListAuthorizationPoliciesRequest
Request used with the ListAuthorizationPolicies method.
ListAuthorizationPoliciesResponse
Response returned by the ListAuthorizationPolicies method.
ListAuthzPoliciesRequest
Message for requesting list of AuthzPolicy resources.
ListAuthzPoliciesResponse
Message for response to listing AuthzPolicy resources.
ListBackendAuthenticationConfigsRequest
Request used by the ListBackendAuthenticationConfigs method.
ListBackendAuthenticationConfigsResponse
Response returned by the ListBackendAuthenticationConfigs method.
ListClientTlsPoliciesRequest
Request used by the ListClientTlsPolicies method.
ListClientTlsPoliciesResponse
Response returned by the ListClientTlsPolicies method.
ListDnsThreatDetectorsRequest
The message for requesting a list of DnsThreatDetectors in the project.
ListDnsThreatDetectorsResponse
The response message to requesting a list of DnsThreatDetectors.
ListFirewallEndpointAssociationsRequest
Message for requesting list of Associations
ListFirewallEndpointAssociationsResponse
Message for response to listing Associations
ListFirewallEndpointsRequest
Message for requesting list of Endpoints
ListFirewallEndpointsResponse
Message for response to listing Endpoints
ListGatewaySecurityPoliciesRequest
Request used with the ListGatewaySecurityPolicies method.
ListGatewaySecurityPoliciesResponse
Response returned by the ListGatewaySecurityPolicies method.
ListGatewaySecurityPolicyRulesRequest
Request used with the ListGatewaySecurityPolicyRules method.
ListGatewaySecurityPolicyRulesResponse
Response returned by the ListGatewaySecurityPolicyRules method.
ListInterceptDeploymentGroupsRequest
Request message for ListInterceptDeploymentGroups.
ListInterceptDeploymentGroupsResponse
Response message for ListInterceptDeploymentGroups.
ListInterceptDeploymentsRequest
Request message for ListInterceptDeployments.
ListInterceptDeploymentsResponse
Response message for ListInterceptDeployments.
ListInterceptEndpointGroupAssociationsRequest
Request message for ListInterceptEndpointGroupAssociations.
ListInterceptEndpointGroupAssociationsResponse
Response message for ListInterceptEndpointGroupAssociations.
ListInterceptEndpointGroupsRequest
Request message for ListInterceptEndpointGroups.
ListInterceptEndpointGroupsResponse
Response message for ListInterceptEndpointGroups.
ListMirroringDeploymentGroupsRequest
Request message for ListMirroringDeploymentGroups.
ListMirroringDeploymentGroupsResponse
Response message for ListMirroringDeploymentGroups.
ListMirroringDeploymentsRequest
Request message for ListMirroringDeployments.
ListMirroringDeploymentsResponse
Response message for ListMirroringDeployments.
ListMirroringEndpointGroupAssociationsRequest
Request message for ListMirroringEndpointGroupAssociations.
ListMirroringEndpointGroupAssociationsResponse
Response message for ListMirroringEndpointGroupAssociations.
ListMirroringEndpointGroupsRequest
Request message for ListMirroringEndpointGroups.
ListMirroringEndpointGroupsResponse
Response message for ListMirroringEndpointGroups.
ListSecurityProfileGroupsRequest
Request used with the ListSecurityProfileGroups method.
ListSecurityProfileGroupsResponse
Response returned by the ListSecurityProfileGroups method.
ListSecurityProfilesRequest
Request used with the ListSecurityProfiles method.
ListSecurityProfilesResponse
Response returned by the ListSecurityProfiles method.
ListServerTlsPoliciesRequest
Request used by the ListServerTlsPolicies method.
ListServerTlsPoliciesResponse
Response returned by the ListServerTlsPolicies method.
ListTlsInspectionPoliciesRequest
Request used with the ListTlsInspectionPolicies method.
ListTlsInspectionPoliciesResponse
Response returned by the ListTlsInspectionPolicies method.
ListUrlListsRequest
Request used by the ListUrlList method.
ListUrlListsResponse
Response returned by the ListUrlLists method.
MirroringDeployment
A deployment represents a zonal mirroring backend ready to accept GENEVE-encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.
MirroringDeploymentGroup
A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.
MirroringEndpointGroup
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create:
MirroringEndpointGroupAssociation
An endpoint group association represents a link between a network and an endpoint group in the organization.
MirroringLocation
Details about mirroring in a specific cloud location.
OperationMetadata
Represents the metadata of the long-running operation.
RemoveAddressGroupItemsRequest
Request used by the RemoveAddressGroupItems method.
SecurityProfile
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
SecurityProfileGroup
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
ServerTlsPolicy
ServerTlsPolicy is a resource that specifies how a server should authenticate incoming requests. This resource itself does not affect configuration unless it is attached to a target HTTPS proxy or endpoint config selector resource.
SeverityOverride
Defines what action to take for a specific severity match.
ThreatOverride
Defines what action to take for a specific threat_id match.
ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
TlsInspectionPolicy
The TlsInspectionPolicy resource contains references to CA pools in Certificate Authority Service and associated metadata.
UpdateAddressGroupRequest
Request used by the UpdateAddressGroup method.
UpdateAuthorizationPolicyRequest
Request used by the UpdateAuthorizationPolicy method.
UpdateAuthzPolicyRequest
Message for updating an AuthzPolicy resource.
UpdateBackendAuthenticationConfigRequest
Request used by UpdateBackendAuthenticationConfig method.
UpdateClientTlsPolicyRequest
Request used by UpdateClientTlsPolicy method.
UpdateDnsThreatDetectorRequest
The message for updating a DnsThreatDetector.
UpdateFirewallEndpointAssociationRequest
Message for updating an Association
UpdateFirewallEndpointRequest
Message for updating a Endpoint
UpdateGatewaySecurityPolicyRequest
Request used by the UpdateGatewaySecurityPolicy method.
UpdateGatewaySecurityPolicyRuleRequest
Request used by the UpdateGatewaySecurityPolicyRule method.
UpdateInterceptDeploymentGroupRequest
Request message for UpdateInterceptDeploymentGroup.
UpdateInterceptDeploymentRequest
Request message for UpdateInterceptDeployment.
UpdateInterceptEndpointGroupAssociationRequest
Request message for UpdateInterceptEndpointGroupAssociation.
UpdateInterceptEndpointGroupRequest
Request message for UpdateInterceptEndpointGroup.
UpdateMirroringDeploymentGroupRequest
Request message for UpdateMirroringDeploymentGroup.
UpdateMirroringDeploymentRequest
Request message for UpdateMirroringDeployment.
UpdateMirroringEndpointGroupAssociationRequest
Request message for UpdateMirroringEndpointGroupAssociation.
UpdateMirroringEndpointGroupRequest
Request message for UpdateMirroringEndpointGroup.
UpdateSecurityProfileGroupRequest
Request used by the UpdateSecurityProfileGroup method.
UpdateSecurityProfileRequest
Request used by the UpdateSecurityProfile method.
UpdateServerTlsPolicyRequest
Request used by UpdateServerTlsPolicy method.
UpdateTlsInspectionPolicyRequest
Request used by the UpdateTlsInspectionPolicy method.
UpdateUrlListRequest
Request used by UpdateUrlList method.
UrlFilter
A URL filter defines an action to take for some URL match.
UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
UrlList
UrlList proto helps users to set reusable, independently manageable lists of hosts, host patterns, URLs, URL patterns.
ValidationCA
Specification of ValidationCA. Defines the mechanism to obtain the Certificate Authority certificate to validate the peer certificate.

Enums

Protocol
Antivirus protocol.
Severity
Severity level.
ThreatAction
Threat action override.
ThreatType
Type of threat.