RequestResource

Struct RequestResource 

#[non_exhaustive]
pub struct RequestResource { pub tag_value_id_set: Option<TagValueIdSet>, pub iam_service_account: Option<StringMatch>, /* private fields */ }
Describes the properties of a client VM resource accessing the internal application load balancers.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tag_value_id_set: Option<TagValueIdSet>

Optional. A list of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request.

iam_service_account: Option<StringMatch>

Optional. An IAM service account to match against the source service account of the VM sending the request.

Implementations

Source

impl RequestResource

pub fn new() -> Self

Creates a new default instance.

pub fn set_tag_value_id_set<T>(self, v: T) -> Self
where T: Into<TagValueIdSet>,

Sets the value of tag_value_id_set.

Example
use google_cloud_networksecurity_v1::model::authz_policy::authz_rule::request_resource::TagValueIdSet;
let x = RequestResource::new().set_tag_value_id_set(TagValueIdSet::default()/* use setters */);
pub fn set_or_clear_tag_value_id_set<T>(self, v: Option<T>) -> Self
where T: Into<TagValueIdSet>,

Sets or clears the value of tag_value_id_set.

Example
use google_cloud_networksecurity_v1::model::authz_policy::authz_rule::request_resource::TagValueIdSet;
let x = RequestResource::new().set_or_clear_tag_value_id_set(Some(TagValueIdSet::default()/* use setters */));
let x = RequestResource::new().set_or_clear_tag_value_id_set(None::<TagValueIdSet>);
pub fn set_iam_service_account<T>(self, v: T) -> Self
where T: Into<StringMatch>,

Sets the value of iam_service_account.

Example
use google_cloud_networksecurity_v1::model::authz_policy::authz_rule::StringMatch;
let x = RequestResource::new().set_iam_service_account(StringMatch::default()/* use setters */);
pub fn set_or_clear_iam_service_account<T>(self, v: Option<T>) -> Self
where T: Into<StringMatch>,

Sets or clears the value of iam_service_account.

Example
use google_cloud_networksecurity_v1::model::authz_policy::authz_rule::StringMatch;
let x = RequestResource::new().set_or_clear_iam_service_account(Some(StringMatch::default()/* use setters */));
let x = RequestResource::new().set_or_clear_iam_service_account(None::<StringMatch>);