To

#[non_exhaustive]
pub struct To { pub operations: Vec<RequestOperation>, pub not_operations: Vec<RequestOperation>, /* private fields */ }
Describes properties of one or more targets of a request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
operations: Vec<RequestOperation>

Optional. Describes properties of one or more targets of a request. At least one of operations or notOperations must be specified. Limited to 1 operation. A match occurs when ANY operation (in operations or notOperations) matches. Within an operation, the match follows AND semantics across fields and OR semantics within a field, i.e. a match occurs when ANY path matches AND ANY header matches and ANY method matches.

not_operations: Vec<RequestOperation>

Optional. Describes the negated properties of the targets of a request. Matches requests for operations that do not match the criteria specified in this field. At least one of operations or notOperations must be specified.

Implementations

Source

impl To

pub fn new() -> Self

pub fn set_operations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<RequestOperation>,

Sets the value of operations.

Example
use google_cloud_networksecurity_v1::model::authz_policy::authz_rule::to::RequestOperation;
let x = To::new()
    .set_operations([
        RequestOperation::default()/* use setters */,
        RequestOperation::default()/* use (different) setters */,
    ]);
pub fn set_not_operations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<RequestOperation>,

Sets the value of not_operations.

Example
use google_cloud_networksecurity_v1::model::authz_policy::authz_rule::to::RequestOperation;
let x = To::new()
    .set_not_operations([
        RequestOperation::default()/* use setters */,
        RequestOperation::default()/* use (different) setters */,
    ]);