#[non_exhaustive]pub enum AuthzAction {
Unspecified,
Allow,
Deny,
Custom,
UnknownValue(UnknownValue),
}Expand description
The action to be applied to this policy. Valid values are
ALLOW, DENY, CUSTOM.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified action.
Allow
Allow request to pass through to the backend.
Deny
Deny the request and return a HTTP 404 to the client.
Custom
Delegate the authorization decision to an external authorization engine.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using AuthzAction::value or AuthzAction::name.
Implementations