#[non_exhaustive]pub enum PolicyProfile {
Unspecified,
RequestAuthz,
ContentAuthz,
UnknownValue(UnknownValue),
}Expand description
The type of authorization being performed. New values may be added in the future.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified policy profile.
RequestAuthz
Applies to request authorization. CUSTOM authorization
policies with Authz extensions will be allowed with EXT_AUTHZ_GRPC or
EXT_PROC_GRPC protocols. Extensions are invoked only for request header
events.
ContentAuthz
Applies to content security, sanitization, etc. Only
CUSTOM action is allowed in this policy profile. AuthzExtensions in the
custom provider must support EXT_PROC_GRPC protocol only and be capable
of receiving all EXT_PROC_GRPC events (REQUEST_HEADERS, REQUEST_BODY,
REQUEST_TRAILERS, RESPONSE_HEADERS, RESPONSE_BODY, RESPONSE_TRAILERS)
with FULL_DUPLEX_STREAMED body send mode.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PolicyProfile::value or PolicyProfile::name.
Implementations