#[non_exhaustive]pub struct AuthzRule {
pub from: Option<From>,
pub to: Option<To>,
pub when: String,
/* private fields */
}Expand description
Conditions to match against the incoming request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.from: Option<From>Optional. Describes properties of a source of a request.
to: Option<To>Optional. Describes properties of a target of a request.
when: StringOptional. CEL expression that describes the conditions to be satisfied for the action. The result of the CEL expression is ANDed with the from and to. Refer to the CEL language reference for a list of available attributes.
Implementations