#[non_exhaustive]pub struct Target {
pub load_balancing_scheme: LoadBalancingScheme,
pub resources: Vec<String>,
/* private fields */
}Expand description
Specifies the set of targets to which this policy should be applied to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.load_balancing_scheme: LoadBalancingSchemeOptional. All gateways and forwarding rules referenced by this policy and
extensions must share the same load balancing scheme. Supported values:
INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer
to Backend services
overview.
resources: Vec<String>Required. A list of references to the Forwarding Rules on which this policy will be applied.
Implementations
Sourceimpl Target
impl Target
pub fn new() -> Self
Sourcepub fn set_load_balancing_scheme<T: Into<LoadBalancingScheme>>(
self,
v: T,
) -> Self
pub fn set_load_balancing_scheme<T: Into<LoadBalancingScheme>>( self, v: T, ) -> Self
Sets the value of load_balancing_scheme.
Example
ⓘ
use google_cloud_networksecurity_v1::model::authz_policy::LoadBalancingScheme;
let x0 = Target::new().set_load_balancing_scheme(LoadBalancingScheme::InternalManaged);
let x1 = Target::new().set_load_balancing_scheme(LoadBalancingScheme::ExternalManaged);
let x2 = Target::new().set_load_balancing_scheme(LoadBalancingScheme::InternalSelfManaged);Sourcepub fn set_resources<T, V>(self, v: T) -> Self
pub fn set_resources<T, V>(self, v: T) -> Self