#[non_exhaustive]pub enum WellKnownRoots {
Unspecified,
None,
PublicRoots,
UnknownValue(UnknownValue),
}Expand description
Enum to specify the well known roots to use for server certificate validation.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Equivalent to NONE.
None
The BackendService will only validate server certificates against roots specified in TrustConfig.
PublicRoots
The BackendService uses a set of well-known public roots, in addition to any roots specified in the trustConfig field, when validating the server certificates presented by the backend. Validation with these roots is only considered when the TlsSettings.sni field in the BackendService is set.
The well-known roots are a set of root CAs managed by Google. CAs in this set can be added or removed without notice.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using WellKnownRoots::value or WellKnownRoots::name.
Implementations