#[non_exhaustive]pub enum Severity {
Unspecified,
Informational,
Low,
Medium,
High,
Critical,
UnknownValue(UnknownValue),
}Expand description
Severity level.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Severity level not specified.
Informational
Suspicious events that do not pose an immediate threat, but that are reported to call attention to deeper problems that could possibly exist.
Low
Warning-level threats that have very little impact on an organization’s infrastructure. They usually require local or physical system access and may often result in victim privacy issues and information leakage.
Medium
Minor threats in which impact is minimized, that do not compromise the target or exploits that require an attacker to reside on the same local network as the victim, affect only non-standard configurations or obscure applications, or provide very limited access.
High
Threats that have the ability to become critical but have mitigating factors; for example, they may be difficult to exploit, do not result in elevated privileges, or do not have a large victim pool.
Critical
Serious threats, such as those that affect default installations of widely deployed software, result in root compromise of servers, and the exploit code is widely available to attackers. The attacker usually does not need any special authentication credentials or knowledge about the individual victims and the target does not need to be manipulated into performing any special functions.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Severity::value or Severity::name.
Implementations