#[non_exhaustive]pub enum ThreatAction {
Unspecified,
DefaultAction,
Allow,
Alert,
Deny,
UnknownValue(UnknownValue),
}Expand description
Threat action override.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Threat action not specified.
DefaultAction
The default action (as specified by the vendor) is taken.
Allow
The packet matching this rule will be allowed to transmit.
Alert
The packet matching this rule will be allowed to transmit, but a threat_log entry will be sent to the consumer project.
Deny
The packet matching this rule will be dropped, and a threat_log entry will be sent to the consumer project.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ThreatAction::value or ThreatAction::name.
Implementations