#[non_exhaustive]pub enum State {
Unspecified,
Active,
Creating,
Deleting,
OutOfSync,
DeleteFailed,
UnknownValue(UnknownValue),
}Expand description
The current state of the deployment.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
State not set (this is not a valid state).
Active
The deployment is ready and in sync with the parent group.
Creating
The deployment is being created.
Deleting
The deployment is being deleted.
OutOfSync
The deployment is out of sync with the parent group. In most cases, this is a result of a transient issue within the system (e.g. a delayed data-path config) and the system is expected to recover automatically. See the parent deployment group’s state for more details.
DeleteFailed
An attempt to delete the deployment has failed. This is a terminal state and the deployment is not expected to recover. The only permitted operation is to retry deleting the deployment.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations