#[non_exhaustive]pub enum State {
Unspecified,
Active,
Creating,
Deleting,
Closed,
OutOfSync,
DeleteFailed,
UnknownValue(UnknownValue),
}Expand description
The state of the association.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not set.
Active
The association is ready and in sync with the linked endpoint group.
Creating
The association is being created.
Deleting
The association is being deleted.
Closed
The association is disabled due to a breaking change in another resource.
OutOfSync
The association is out of sync with the linked endpoint group.
In most cases, this is a result of a transient issue within the system
(e.g. an inaccessible location) and the system is expected to recover
automatically. Check the locations_details field for more details.
DeleteFailed
An attempt to delete the association has failed. This is a terminal state and the association is not expected to be usable as some of its resources have been deleted. The only permitted operation is to retry deleting the association.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations