This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The deployment is out of sync with the parent group.
In most cases, this is a result of a transient issue within the system
(e.g. a delayed data-path config) and the system is expected to recover
automatically. See the parent deployment group’s state for more details.
An attempt to delete the deployment has failed. This is a terminal state
and the deployment is not expected to recover. The only permitted
operation is to retry deleting the deployment.