#[non_exhaustive]pub enum State {
Unspecified,
Active,
Closed,
Creating,
Deleting,
OutOfSync,
DeleteFailed,
UnknownValue(UnknownValue),
}Expand description
The current state of the endpoint group.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
State not set (this is not a valid state).
Active
The endpoint group is ready and in sync with the target deployment group.
Closed
The deployment group backing this endpoint group has been force-deleted. This endpoint group cannot be used and mirroring is effectively disabled.
Creating
The endpoint group is being created.
Deleting
The endpoint group is being deleted.
OutOfSync
The endpoint group is out of sync with the backing deployment group. In most cases, this is a result of a transient issue within the system (e.g. an inaccessible location) and the system is expected to recover automatically. See the associations field for details per network and location.
DeleteFailed
An attempt to delete the endpoint group has failed. This is a terminal state and the endpoint group is not expected to recover. The only permitted operation is to retry deleting the endpoint group.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations