#[non_exhaustive]pub struct AntivirusOverride {
pub protocol: Protocol,
pub action: ThreatAction,
/* private fields */
}Expand description
Defines what action to take for antivirus threats per protocol.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.protocol: ProtocolRequired. Protocol to match.
action: ThreatActionRequired. Threat action override. For some threat types, only a subset of actions applies.
Implementations
Sourceimpl AntivirusOverride
impl AntivirusOverride
pub fn new() -> Self
Sourcepub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self
pub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self
Sourcepub fn set_action<T: Into<ThreatAction>>(self, v: T) -> Self
pub fn set_action<T: Into<ThreatAction>>(self, v: T) -> Self
Sets the value of action.
Example
ⓘ
use google_cloud_networksecurity_v1::model::ThreatAction;
let x0 = AntivirusOverride::new().set_action(ThreatAction::DefaultAction);
let x1 = AntivirusOverride::new().set_action(ThreatAction::Allow);
let x2 = AntivirusOverride::new().set_action(ThreatAction::Alert);Trait Implementations
Sourceimpl Clone for AntivirusOverride
impl Clone for AntivirusOverride
Sourcefn clone(&self) -> AntivirusOverride
fn clone(&self) -> AntivirusOverride
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AntivirusOverride
impl Debug for AntivirusOverride
Sourceimpl Default for AntivirusOverride
impl Default for AntivirusOverride
Sourcefn default() -> AntivirusOverride
fn default() -> AntivirusOverride
Returns the “default value” for a type. Read more
Sourceimpl Message for AntivirusOverride
impl Message for AntivirusOverride
Sourceimpl PartialEq for AntivirusOverride
impl PartialEq for AntivirusOverride
impl StructuralPartialEq for AntivirusOverride