#[non_exhaustive]pub struct CertificateProvider {
pub type: Option<Type>,
/* private fields */
}Expand description
Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<Type>The type of certificate provider which provides the certificates and private keys.
Implementations
Sourceimpl CertificateProvider
impl CertificateProvider
Sourcepub fn set_type<T: Into<Option<Type>>>(self, v: T) -> Self
pub fn set_type<T: Into<Option<Type>>>(self, v: T) -> Self
Sets the value of r#type.
Note that all the setters affecting r#type are mutually
exclusive.
Example
use google_cloud_networksecurity_v1::model::GrpcEndpoint;
let x = CertificateProvider::new().set_type(Some(
google_cloud_networksecurity_v1::model::certificate_provider::Type::GrpcEndpoint(GrpcEndpoint::default().into())));Sourcepub fn grpc_endpoint(&self) -> Option<&Box<GrpcEndpoint>>
pub fn grpc_endpoint(&self) -> Option<&Box<GrpcEndpoint>>
The value of [r#type][crate::model::CertificateProvider::r#type]
if it holds a GrpcEndpoint, None if the field is not set or
holds a different branch.
Sourcepub fn set_grpc_endpoint<T: Into<Box<GrpcEndpoint>>>(self, v: T) -> Self
pub fn set_grpc_endpoint<T: Into<Box<GrpcEndpoint>>>(self, v: T) -> Self
Sets the value of [r#type][crate::model::CertificateProvider::r#type]
to hold a GrpcEndpoint.
Note that all the setters affecting r#type are
mutually exclusive.
Example
use google_cloud_networksecurity_v1::model::GrpcEndpoint;
let x = CertificateProvider::new().set_grpc_endpoint(GrpcEndpoint::default()/* use setters */);
assert!(x.grpc_endpoint().is_some());
assert!(x.certificate_provider_instance().is_none());Sourcepub fn certificate_provider_instance(
&self,
) -> Option<&Box<CertificateProviderInstance>>
pub fn certificate_provider_instance( &self, ) -> Option<&Box<CertificateProviderInstance>>
The value of [r#type][crate::model::CertificateProvider::r#type]
if it holds a CertificateProviderInstance, None if the field is not set or
holds a different branch.
Sourcepub fn set_certificate_provider_instance<T: Into<Box<CertificateProviderInstance>>>(
self,
v: T,
) -> Self
pub fn set_certificate_provider_instance<T: Into<Box<CertificateProviderInstance>>>( self, v: T, ) -> Self
Sets the value of [r#type][crate::model::CertificateProvider::r#type]
to hold a CertificateProviderInstance.
Note that all the setters affecting r#type are
mutually exclusive.
Example
use google_cloud_networksecurity_v1::model::CertificateProviderInstance;
let x = CertificateProvider::new().set_certificate_provider_instance(CertificateProviderInstance::default()/* use setters */);
assert!(x.certificate_provider_instance().is_some());
assert!(x.grpc_endpoint().is_none());Trait Implementations
Sourceimpl Clone for CertificateProvider
impl Clone for CertificateProvider
Sourcefn clone(&self) -> CertificateProvider
fn clone(&self) -> CertificateProvider
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CertificateProvider
impl Debug for CertificateProvider
Sourceimpl Default for CertificateProvider
impl Default for CertificateProvider
Sourcefn default() -> CertificateProvider
fn default() -> CertificateProvider
Sourceimpl Message for CertificateProvider
impl Message for CertificateProvider
Sourceimpl PartialEq for CertificateProvider
impl PartialEq for CertificateProvider
impl StructuralPartialEq for CertificateProvider