#[non_exhaustive]pub struct CloneAddressGroupItemsRequest {
pub address_group: String,
pub source_address_group: String,
pub request_id: String,
/* private fields */
}Expand description
Request used by the CloneAddressGroupItems method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.address_group: StringRequired. A name of the AddressGroup to clone items to. Must be in the
format projects|organization/*/locations/{location}/addressGroups/*.
source_address_group: StringRequired. Source address group to clone items from.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CloneAddressGroupItemsRequest
impl CloneAddressGroupItemsRequest
Sourcepub fn set_address_group<T: Into<String>>(self, v: T) -> Self
pub fn set_address_group<T: Into<String>>(self, v: T) -> Self
Sets the value of address_group.
Example
let x = CloneAddressGroupItemsRequest::new().set_address_group(format!("projects/{project_id}/locations/{location_id}/addressGroups/{address_group_id}"));Sourcepub fn set_source_address_group<T: Into<String>>(self, v: T) -> Self
pub fn set_source_address_group<T: Into<String>>(self, v: T) -> Self
Sets the value of source_address_group.
Example
let x = CloneAddressGroupItemsRequest::new().set_source_address_group(format!("projects/{project_id}/locations/{location_id}/addressGroups/{address_group_id}"));Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CloneAddressGroupItemsRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CloneAddressGroupItemsRequest
impl Clone for CloneAddressGroupItemsRequest
Sourcefn clone(&self) -> CloneAddressGroupItemsRequest
fn clone(&self) -> CloneAddressGroupItemsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CloneAddressGroupItemsRequest
impl Default for CloneAddressGroupItemsRequest
Sourcefn default() -> CloneAddressGroupItemsRequest
fn default() -> CloneAddressGroupItemsRequest
impl StructuralPartialEq for CloneAddressGroupItemsRequest