#[non_exhaustive]pub struct CreateAuthzPolicyRequest {
pub parent: String,
pub authz_policy_id: String,
pub authz_policy: Option<AuthzPolicy>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating an AuthzPolicy resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the AuthzPolicy resource. Must be in
the format projects/{project}/locations/{location}.
authz_policy_id: StringRequired. User-provided ID of the AuthzPolicy resource to be created.
authz_policy: Option<AuthzPolicy>Required. AuthzPolicy resource to be created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateAuthzPolicyRequest
impl CreateAuthzPolicyRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_authz_policy_id<T: Into<String>>(self, v: T) -> Self
pub fn set_authz_policy_id<T: Into<String>>(self, v: T) -> Self
Sets the value of authz_policy_id.
Example
let x = CreateAuthzPolicyRequest::new().set_authz_policy_id("example");Sourcepub fn set_authz_policy<T>(self, v: T) -> Selfwhere
T: Into<AuthzPolicy>,
pub fn set_authz_policy<T>(self, v: T) -> Selfwhere
T: Into<AuthzPolicy>,
Sets the value of authz_policy.
Example
use google_cloud_networksecurity_v1::model::AuthzPolicy;
let x = CreateAuthzPolicyRequest::new().set_authz_policy(AuthzPolicy::default()/* use setters */);Sourcepub fn set_or_clear_authz_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<AuthzPolicy>,
pub fn set_or_clear_authz_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<AuthzPolicy>,
Sets or clears the value of authz_policy.
Example
use google_cloud_networksecurity_v1::model::AuthzPolicy;
let x = CreateAuthzPolicyRequest::new().set_or_clear_authz_policy(Some(AuthzPolicy::default()/* use setters */));
let x = CreateAuthzPolicyRequest::new().set_or_clear_authz_policy(None::<AuthzPolicy>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateAuthzPolicyRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateAuthzPolicyRequest
impl Clone for CreateAuthzPolicyRequest
Sourcefn clone(&self) -> CreateAuthzPolicyRequest
fn clone(&self) -> CreateAuthzPolicyRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more