#[non_exhaustive]pub struct CreateBackendAuthenticationConfigRequest {
pub parent: String,
pub backend_authentication_config_id: String,
pub backend_authentication_config: Option<BackendAuthenticationConfig>,
/* private fields */
}Expand description
Request used by the CreateBackendAuthenticationConfig method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the BackendAuthenticationConfig. Must be
in the format projects/*/locations/{location}.
backend_authentication_config_id: StringRequired. Short name of the BackendAuthenticationConfig resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. “backend-auth-config”.
backend_authentication_config: Option<BackendAuthenticationConfig>Required. BackendAuthenticationConfig resource to be created.
Implementations
Sourceimpl CreateBackendAuthenticationConfigRequest
impl CreateBackendAuthenticationConfigRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backend_authentication_config_id<T: Into<String>>(self, v: T) -> Self
pub fn set_backend_authentication_config_id<T: Into<String>>(self, v: T) -> Self
Sets the value of backend_authentication_config_id.
Example
ⓘ
let x = CreateBackendAuthenticationConfigRequest::new().set_backend_authentication_config_id("example");Sourcepub fn set_backend_authentication_config<T>(self, v: T) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
pub fn set_backend_authentication_config<T>(self, v: T) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
Sets the value of backend_authentication_config.
Example
ⓘ
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
let x = CreateBackendAuthenticationConfigRequest::new().set_backend_authentication_config(BackendAuthenticationConfig::default()/* use setters */);Sourcepub fn set_or_clear_backend_authentication_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
pub fn set_or_clear_backend_authentication_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
Sets or clears the value of backend_authentication_config.
Example
ⓘ
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
let x = CreateBackendAuthenticationConfigRequest::new().set_or_clear_backend_authentication_config(Some(BackendAuthenticationConfig::default()/* use setters */));
let x = CreateBackendAuthenticationConfigRequest::new().set_or_clear_backend_authentication_config(None::<BackendAuthenticationConfig>);Trait Implementations
Sourceimpl Clone for CreateBackendAuthenticationConfigRequest
impl Clone for CreateBackendAuthenticationConfigRequest
Sourcefn clone(&self) -> CreateBackendAuthenticationConfigRequest
fn clone(&self) -> CreateBackendAuthenticationConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateBackendAuthenticationConfigRequest
impl Default for CreateBackendAuthenticationConfigRequest
Sourcefn default() -> CreateBackendAuthenticationConfigRequest
fn default() -> CreateBackendAuthenticationConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateBackendAuthenticationConfigRequest
impl PartialEq for CreateBackendAuthenticationConfigRequest
Sourcefn eq(&self, other: &CreateBackendAuthenticationConfigRequest) -> bool
fn eq(&self, other: &CreateBackendAuthenticationConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateBackendAuthenticationConfigRequest