#[non_exhaustive]pub struct CreateFirewallEndpointRequest {
pub parent: String,
pub firewall_endpoint_id: String,
pub firewall_endpoint: Option<FirewallEndpoint>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a Endpoint
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
firewall_endpoint_id: StringRequired. Id of the requesting object. If auto-generating Id server-side, remove this field and firewall_endpoint_id from the method_signature of Create RPC.
firewall_endpoint: Option<FirewallEndpoint>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateFirewallEndpointRequest
impl CreateFirewallEndpointRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_firewall_endpoint_id<T: Into<String>>(self, v: T) -> Self
pub fn set_firewall_endpoint_id<T: Into<String>>(self, v: T) -> Self
Sets the value of firewall_endpoint_id.
Example
let x = CreateFirewallEndpointRequest::new().set_firewall_endpoint_id("example");Sourcepub fn set_firewall_endpoint<T>(self, v: T) -> Selfwhere
T: Into<FirewallEndpoint>,
pub fn set_firewall_endpoint<T>(self, v: T) -> Selfwhere
T: Into<FirewallEndpoint>,
Sets the value of firewall_endpoint.
Example
use google_cloud_networksecurity_v1::model::FirewallEndpoint;
let x = CreateFirewallEndpointRequest::new().set_firewall_endpoint(FirewallEndpoint::default()/* use setters */);Sourcepub fn set_or_clear_firewall_endpoint<T>(self, v: Option<T>) -> Selfwhere
T: Into<FirewallEndpoint>,
pub fn set_or_clear_firewall_endpoint<T>(self, v: Option<T>) -> Selfwhere
T: Into<FirewallEndpoint>,
Sets or clears the value of firewall_endpoint.
Example
use google_cloud_networksecurity_v1::model::FirewallEndpoint;
let x = CreateFirewallEndpointRequest::new().set_or_clear_firewall_endpoint(Some(FirewallEndpoint::default()/* use setters */));
let x = CreateFirewallEndpointRequest::new().set_or_clear_firewall_endpoint(None::<FirewallEndpoint>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateFirewallEndpointRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateFirewallEndpointRequest
impl Clone for CreateFirewallEndpointRequest
Sourcefn clone(&self) -> CreateFirewallEndpointRequest
fn clone(&self) -> CreateFirewallEndpointRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateFirewallEndpointRequest
impl Default for CreateFirewallEndpointRequest
Sourcefn default() -> CreateFirewallEndpointRequest
fn default() -> CreateFirewallEndpointRequest
impl StructuralPartialEq for CreateFirewallEndpointRequest