#[non_exhaustive]pub struct CreateInterceptDeploymentGroupRequest {
pub parent: String,
pub intercept_deployment_group_id: String,
pub intercept_deployment_group: Option<InterceptDeploymentGroup>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateInterceptDeploymentGroup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this deployment group will be created. Format: projects/{project}/locations/{location}
intercept_deployment_group_id: StringRequired. The ID to use for the new deployment group, which will become the final component of the deployment group’s resource name.
intercept_deployment_group: Option<InterceptDeploymentGroup>Required. The deployment group to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateInterceptDeploymentGroupRequest
impl CreateInterceptDeploymentGroupRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_intercept_deployment_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_intercept_deployment_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of intercept_deployment_group_id.
Example
ⓘ
let x = CreateInterceptDeploymentGroupRequest::new().set_intercept_deployment_group_id("example");Sourcepub fn set_intercept_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<InterceptDeploymentGroup>,
pub fn set_intercept_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<InterceptDeploymentGroup>,
Sets the value of intercept_deployment_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptDeploymentGroup;
let x = CreateInterceptDeploymentGroupRequest::new().set_intercept_deployment_group(InterceptDeploymentGroup::default()/* use setters */);Sourcepub fn set_or_clear_intercept_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterceptDeploymentGroup>,
pub fn set_or_clear_intercept_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterceptDeploymentGroup>,
Sets or clears the value of intercept_deployment_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptDeploymentGroup;
let x = CreateInterceptDeploymentGroupRequest::new().set_or_clear_intercept_deployment_group(Some(InterceptDeploymentGroup::default()/* use setters */));
let x = CreateInterceptDeploymentGroupRequest::new().set_or_clear_intercept_deployment_group(None::<InterceptDeploymentGroup>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateInterceptDeploymentGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateInterceptDeploymentGroupRequest
impl Clone for CreateInterceptDeploymentGroupRequest
Sourcefn clone(&self) -> CreateInterceptDeploymentGroupRequest
fn clone(&self) -> CreateInterceptDeploymentGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateInterceptDeploymentGroupRequest
impl Default for CreateInterceptDeploymentGroupRequest
Sourcefn default() -> CreateInterceptDeploymentGroupRequest
fn default() -> CreateInterceptDeploymentGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateInterceptDeploymentGroupRequest
impl PartialEq for CreateInterceptDeploymentGroupRequest
Sourcefn eq(&self, other: &CreateInterceptDeploymentGroupRequest) -> bool
fn eq(&self, other: &CreateInterceptDeploymentGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateInterceptDeploymentGroupRequest