#[non_exhaustive]pub struct CreateInterceptDeploymentRequest {
pub parent: String,
pub intercept_deployment_id: String,
pub intercept_deployment: Option<InterceptDeployment>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateInterceptDeployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this deployment will be created. Format: projects/{project}/locations/{location}
intercept_deployment_id: StringRequired. The ID to use for the new deployment, which will become the final component of the deployment’s resource name.
intercept_deployment: Option<InterceptDeployment>Required. The deployment to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateInterceptDeploymentRequest
impl CreateInterceptDeploymentRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_intercept_deployment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_intercept_deployment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of intercept_deployment_id.
Example
ⓘ
let x = CreateInterceptDeploymentRequest::new().set_intercept_deployment_id("example");Sourcepub fn set_intercept_deployment<T>(self, v: T) -> Selfwhere
T: Into<InterceptDeployment>,
pub fn set_intercept_deployment<T>(self, v: T) -> Selfwhere
T: Into<InterceptDeployment>,
Sets the value of intercept_deployment.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptDeployment;
let x = CreateInterceptDeploymentRequest::new().set_intercept_deployment(InterceptDeployment::default()/* use setters */);Sourcepub fn set_or_clear_intercept_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterceptDeployment>,
pub fn set_or_clear_intercept_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterceptDeployment>,
Sets or clears the value of intercept_deployment.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptDeployment;
let x = CreateInterceptDeploymentRequest::new().set_or_clear_intercept_deployment(Some(InterceptDeployment::default()/* use setters */));
let x = CreateInterceptDeploymentRequest::new().set_or_clear_intercept_deployment(None::<InterceptDeployment>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateInterceptDeploymentRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateInterceptDeploymentRequest
impl Clone for CreateInterceptDeploymentRequest
Sourcefn clone(&self) -> CreateInterceptDeploymentRequest
fn clone(&self) -> CreateInterceptDeploymentRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateInterceptDeploymentRequest
impl Default for CreateInterceptDeploymentRequest
Sourcefn default() -> CreateInterceptDeploymentRequest
fn default() -> CreateInterceptDeploymentRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateInterceptDeploymentRequest
impl PartialEq for CreateInterceptDeploymentRequest
Sourcefn eq(&self, other: &CreateInterceptDeploymentRequest) -> bool
fn eq(&self, other: &CreateInterceptDeploymentRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateInterceptDeploymentRequest