#[non_exhaustive]pub struct CreateInterceptEndpointGroupRequest {
pub parent: String,
pub intercept_endpoint_group_id: String,
pub intercept_endpoint_group: Option<InterceptEndpointGroup>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateInterceptEndpointGroup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this endpoint group will be created. Format: projects/{project}/locations/{location}
intercept_endpoint_group_id: StringRequired. The ID to use for the endpoint group, which will become the final component of the endpoint group’s resource name.
intercept_endpoint_group: Option<InterceptEndpointGroup>Required. The endpoint group to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateInterceptEndpointGroupRequest
impl CreateInterceptEndpointGroupRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_intercept_endpoint_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_intercept_endpoint_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of intercept_endpoint_group_id.
Example
ⓘ
let x = CreateInterceptEndpointGroupRequest::new().set_intercept_endpoint_group_id("example");Sourcepub fn set_intercept_endpoint_group<T>(self, v: T) -> Selfwhere
T: Into<InterceptEndpointGroup>,
pub fn set_intercept_endpoint_group<T>(self, v: T) -> Selfwhere
T: Into<InterceptEndpointGroup>,
Sets the value of intercept_endpoint_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptEndpointGroup;
let x = CreateInterceptEndpointGroupRequest::new().set_intercept_endpoint_group(InterceptEndpointGroup::default()/* use setters */);Sourcepub fn set_or_clear_intercept_endpoint_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterceptEndpointGroup>,
pub fn set_or_clear_intercept_endpoint_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<InterceptEndpointGroup>,
Sets or clears the value of intercept_endpoint_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptEndpointGroup;
let x = CreateInterceptEndpointGroupRequest::new().set_or_clear_intercept_endpoint_group(Some(InterceptEndpointGroup::default()/* use setters */));
let x = CreateInterceptEndpointGroupRequest::new().set_or_clear_intercept_endpoint_group(None::<InterceptEndpointGroup>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateInterceptEndpointGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateInterceptEndpointGroupRequest
impl Clone for CreateInterceptEndpointGroupRequest
Sourcefn clone(&self) -> CreateInterceptEndpointGroupRequest
fn clone(&self) -> CreateInterceptEndpointGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateInterceptEndpointGroupRequest
impl Default for CreateInterceptEndpointGroupRequest
Sourcefn default() -> CreateInterceptEndpointGroupRequest
fn default() -> CreateInterceptEndpointGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateInterceptEndpointGroupRequest
impl PartialEq for CreateInterceptEndpointGroupRequest
Sourcefn eq(&self, other: &CreateInterceptEndpointGroupRequest) -> bool
fn eq(&self, other: &CreateInterceptEndpointGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateInterceptEndpointGroupRequest