#[non_exhaustive]pub struct CreateMirroringDeploymentGroupRequest {
pub parent: String,
pub mirroring_deployment_group_id: String,
pub mirroring_deployment_group: Option<MirroringDeploymentGroup>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateMirroringDeploymentGroup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this deployment group will be created. Format: projects/{project}/locations/{location}
mirroring_deployment_group_id: StringRequired. The ID to use for the new deployment group, which will become the final component of the deployment group’s resource name.
mirroring_deployment_group: Option<MirroringDeploymentGroup>Required. The deployment group to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateMirroringDeploymentGroupRequest
impl CreateMirroringDeploymentGroupRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_mirroring_deployment_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_mirroring_deployment_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of mirroring_deployment_group_id.
Example
ⓘ
let x = CreateMirroringDeploymentGroupRequest::new().set_mirroring_deployment_group_id("example");Sourcepub fn set_mirroring_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<MirroringDeploymentGroup>,
pub fn set_mirroring_deployment_group<T>(self, v: T) -> Selfwhere
T: Into<MirroringDeploymentGroup>,
Sets the value of mirroring_deployment_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringDeploymentGroup;
let x = CreateMirroringDeploymentGroupRequest::new().set_mirroring_deployment_group(MirroringDeploymentGroup::default()/* use setters */);Sourcepub fn set_or_clear_mirroring_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<MirroringDeploymentGroup>,
pub fn set_or_clear_mirroring_deployment_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<MirroringDeploymentGroup>,
Sets or clears the value of mirroring_deployment_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringDeploymentGroup;
let x = CreateMirroringDeploymentGroupRequest::new().set_or_clear_mirroring_deployment_group(Some(MirroringDeploymentGroup::default()/* use setters */));
let x = CreateMirroringDeploymentGroupRequest::new().set_or_clear_mirroring_deployment_group(None::<MirroringDeploymentGroup>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateMirroringDeploymentGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateMirroringDeploymentGroupRequest
impl Clone for CreateMirroringDeploymentGroupRequest
Sourcefn clone(&self) -> CreateMirroringDeploymentGroupRequest
fn clone(&self) -> CreateMirroringDeploymentGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateMirroringDeploymentGroupRequest
impl Default for CreateMirroringDeploymentGroupRequest
Sourcefn default() -> CreateMirroringDeploymentGroupRequest
fn default() -> CreateMirroringDeploymentGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateMirroringDeploymentGroupRequest
impl PartialEq for CreateMirroringDeploymentGroupRequest
Sourcefn eq(&self, other: &CreateMirroringDeploymentGroupRequest) -> bool
fn eq(&self, other: &CreateMirroringDeploymentGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateMirroringDeploymentGroupRequest