#[non_exhaustive]pub struct CreateMirroringDeploymentRequest {
pub parent: String,
pub mirroring_deployment_id: String,
pub mirroring_deployment: Option<MirroringDeployment>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateMirroringDeployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this deployment will be created. Format: projects/{project}/locations/{location}
mirroring_deployment_id: StringRequired. The ID to use for the new deployment, which will become the final component of the deployment’s resource name.
mirroring_deployment: Option<MirroringDeployment>Required. The deployment to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateMirroringDeploymentRequest
impl CreateMirroringDeploymentRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_mirroring_deployment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_mirroring_deployment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of mirroring_deployment_id.
Example
ⓘ
let x = CreateMirroringDeploymentRequest::new().set_mirroring_deployment_id("example");Sourcepub fn set_mirroring_deployment<T>(self, v: T) -> Selfwhere
T: Into<MirroringDeployment>,
pub fn set_mirroring_deployment<T>(self, v: T) -> Selfwhere
T: Into<MirroringDeployment>,
Sets the value of mirroring_deployment.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringDeployment;
let x = CreateMirroringDeploymentRequest::new().set_mirroring_deployment(MirroringDeployment::default()/* use setters */);Sourcepub fn set_or_clear_mirroring_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<MirroringDeployment>,
pub fn set_or_clear_mirroring_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<MirroringDeployment>,
Sets or clears the value of mirroring_deployment.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringDeployment;
let x = CreateMirroringDeploymentRequest::new().set_or_clear_mirroring_deployment(Some(MirroringDeployment::default()/* use setters */));
let x = CreateMirroringDeploymentRequest::new().set_or_clear_mirroring_deployment(None::<MirroringDeployment>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateMirroringDeploymentRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateMirroringDeploymentRequest
impl Clone for CreateMirroringDeploymentRequest
Sourcefn clone(&self) -> CreateMirroringDeploymentRequest
fn clone(&self) -> CreateMirroringDeploymentRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateMirroringDeploymentRequest
impl Default for CreateMirroringDeploymentRequest
Sourcefn default() -> CreateMirroringDeploymentRequest
fn default() -> CreateMirroringDeploymentRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateMirroringDeploymentRequest
impl PartialEq for CreateMirroringDeploymentRequest
Sourcefn eq(&self, other: &CreateMirroringDeploymentRequest) -> bool
fn eq(&self, other: &CreateMirroringDeploymentRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateMirroringDeploymentRequest