#[non_exhaustive]pub struct CreateMirroringEndpointGroupAssociationRequest {
pub parent: String,
pub mirroring_endpoint_group_association_id: String,
pub mirroring_endpoint_group_association: Option<MirroringEndpointGroupAssociation>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateMirroringEndpointGroupAssociation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this association will be created. Format: projects/{project}/locations/{location}
mirroring_endpoint_group_association_id: StringOptional. The ID to use for the new association, which will become the final component of the endpoint group’s resource name. If not provided, the server will generate a unique ID.
mirroring_endpoint_group_association: Option<MirroringEndpointGroupAssociation>Required. The association to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateMirroringEndpointGroupAssociationRequest
impl CreateMirroringEndpointGroupAssociationRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_mirroring_endpoint_group_association_id<T: Into<String>>(
self,
v: T,
) -> Self
pub fn set_mirroring_endpoint_group_association_id<T: Into<String>>( self, v: T, ) -> Self
Sets the value of mirroring_endpoint_group_association_id.
Example
let x = CreateMirroringEndpointGroupAssociationRequest::new().set_mirroring_endpoint_group_association_id("example");Sourcepub fn set_mirroring_endpoint_group_association<T>(self, v: T) -> Selfwhere
T: Into<MirroringEndpointGroupAssociation>,
pub fn set_mirroring_endpoint_group_association<T>(self, v: T) -> Selfwhere
T: Into<MirroringEndpointGroupAssociation>,
Sets the value of mirroring_endpoint_group_association.
Example
use google_cloud_networksecurity_v1::model::MirroringEndpointGroupAssociation;
let x = CreateMirroringEndpointGroupAssociationRequest::new().set_mirroring_endpoint_group_association(MirroringEndpointGroupAssociation::default()/* use setters */);Sourcepub fn set_or_clear_mirroring_endpoint_group_association<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<MirroringEndpointGroupAssociation>,
pub fn set_or_clear_mirroring_endpoint_group_association<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<MirroringEndpointGroupAssociation>,
Sets or clears the value of mirroring_endpoint_group_association.
Example
use google_cloud_networksecurity_v1::model::MirroringEndpointGroupAssociation;
let x = CreateMirroringEndpointGroupAssociationRequest::new().set_or_clear_mirroring_endpoint_group_association(Some(MirroringEndpointGroupAssociation::default()/* use setters */));
let x = CreateMirroringEndpointGroupAssociationRequest::new().set_or_clear_mirroring_endpoint_group_association(None::<MirroringEndpointGroupAssociation>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateMirroringEndpointGroupAssociationRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateMirroringEndpointGroupAssociationRequest
impl Clone for CreateMirroringEndpointGroupAssociationRequest
Sourcefn clone(&self) -> CreateMirroringEndpointGroupAssociationRequest
fn clone(&self) -> CreateMirroringEndpointGroupAssociationRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateMirroringEndpointGroupAssociationRequest
impl Default for CreateMirroringEndpointGroupAssociationRequest
Sourcefn default() -> CreateMirroringEndpointGroupAssociationRequest
fn default() -> CreateMirroringEndpointGroupAssociationRequest
Sourceimpl PartialEq for CreateMirroringEndpointGroupAssociationRequest
impl PartialEq for CreateMirroringEndpointGroupAssociationRequest
Sourcefn eq(&self, other: &CreateMirroringEndpointGroupAssociationRequest) -> bool
fn eq(&self, other: &CreateMirroringEndpointGroupAssociationRequest) -> bool
self and other values to be equal, and is used by ==.