#[non_exhaustive]pub struct CreateMirroringEndpointGroupRequest {
pub parent: String,
pub mirroring_endpoint_group_id: String,
pub mirroring_endpoint_group: Option<MirroringEndpointGroup>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateMirroringEndpointGroup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this endpoint group will be created. Format: projects/{project}/locations/{location}
mirroring_endpoint_group_id: StringRequired. The ID to use for the endpoint group, which will become the final component of the endpoint group’s resource name.
mirroring_endpoint_group: Option<MirroringEndpointGroup>Required. The endpoint group to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateMirroringEndpointGroupRequest
impl CreateMirroringEndpointGroupRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_mirroring_endpoint_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_mirroring_endpoint_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of mirroring_endpoint_group_id.
Example
ⓘ
let x = CreateMirroringEndpointGroupRequest::new().set_mirroring_endpoint_group_id("example");Sourcepub fn set_mirroring_endpoint_group<T>(self, v: T) -> Selfwhere
T: Into<MirroringEndpointGroup>,
pub fn set_mirroring_endpoint_group<T>(self, v: T) -> Selfwhere
T: Into<MirroringEndpointGroup>,
Sets the value of mirroring_endpoint_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringEndpointGroup;
let x = CreateMirroringEndpointGroupRequest::new().set_mirroring_endpoint_group(MirroringEndpointGroup::default()/* use setters */);Sourcepub fn set_or_clear_mirroring_endpoint_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<MirroringEndpointGroup>,
pub fn set_or_clear_mirroring_endpoint_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<MirroringEndpointGroup>,
Sets or clears the value of mirroring_endpoint_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringEndpointGroup;
let x = CreateMirroringEndpointGroupRequest::new().set_or_clear_mirroring_endpoint_group(Some(MirroringEndpointGroup::default()/* use setters */));
let x = CreateMirroringEndpointGroupRequest::new().set_or_clear_mirroring_endpoint_group(None::<MirroringEndpointGroup>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateMirroringEndpointGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateMirroringEndpointGroupRequest
impl Clone for CreateMirroringEndpointGroupRequest
Sourcefn clone(&self) -> CreateMirroringEndpointGroupRequest
fn clone(&self) -> CreateMirroringEndpointGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateMirroringEndpointGroupRequest
impl Default for CreateMirroringEndpointGroupRequest
Sourcefn default() -> CreateMirroringEndpointGroupRequest
fn default() -> CreateMirroringEndpointGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateMirroringEndpointGroupRequest
impl PartialEq for CreateMirroringEndpointGroupRequest
Sourcefn eq(&self, other: &CreateMirroringEndpointGroupRequest) -> bool
fn eq(&self, other: &CreateMirroringEndpointGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateMirroringEndpointGroupRequest