#[non_exhaustive]pub struct CreateSACAttachmentRequest {
pub parent: String,
pub sac_attachment_id: String,
pub sac_attachment: Option<SACAttachment>,
pub request_id: String,
/* private fields */
}Expand description
Request for CreateSACAttachment method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, in the form
projects/{project}/locations/{location}.
sac_attachment_id: StringRequired. ID of the created attachment.
The ID must be 1-63 characters long, and comply with
RFC1035.
Specifically, it must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
sac_attachment: Option<SACAttachment>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateSACAttachmentRequest
impl CreateSACAttachmentRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_sac_attachment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_sac_attachment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of sac_attachment_id.
Example
let x = CreateSACAttachmentRequest::new().set_sac_attachment_id("example");Sourcepub fn set_sac_attachment<T>(self, v: T) -> Selfwhere
T: Into<SACAttachment>,
pub fn set_sac_attachment<T>(self, v: T) -> Selfwhere
T: Into<SACAttachment>,
Sets the value of sac_attachment.
Example
use google_cloud_networksecurity_v1::model::SACAttachment;
let x = CreateSACAttachmentRequest::new().set_sac_attachment(SACAttachment::default()/* use setters */);Sourcepub fn set_or_clear_sac_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<SACAttachment>,
pub fn set_or_clear_sac_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<SACAttachment>,
Sets or clears the value of sac_attachment.
Example
use google_cloud_networksecurity_v1::model::SACAttachment;
let x = CreateSACAttachmentRequest::new().set_or_clear_sac_attachment(Some(SACAttachment::default()/* use setters */));
let x = CreateSACAttachmentRequest::new().set_or_clear_sac_attachment(None::<SACAttachment>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSACAttachmentRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSACAttachmentRequest
impl Clone for CreateSACAttachmentRequest
Sourcefn clone(&self) -> CreateSACAttachmentRequest
fn clone(&self) -> CreateSACAttachmentRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateSACAttachmentRequest
impl Debug for CreateSACAttachmentRequest
Sourceimpl Default for CreateSACAttachmentRequest
impl Default for CreateSACAttachmentRequest
Sourcefn default() -> CreateSACAttachmentRequest
fn default() -> CreateSACAttachmentRequest
Sourceimpl Message for CreateSACAttachmentRequest
impl Message for CreateSACAttachmentRequest
Sourceimpl PartialEq for CreateSACAttachmentRequest
impl PartialEq for CreateSACAttachmentRequest
Sourcefn eq(&self, other: &CreateSACAttachmentRequest) -> bool
fn eq(&self, other: &CreateSACAttachmentRequest) -> bool
self and other values to be equal, and is used by ==.