#[non_exhaustive]pub struct CreateSACRealmRequest {
pub parent: String,
pub sac_realm_id: String,
pub sac_realm: Option<SACRealm>,
pub request_id: String,
/* private fields */
}Expand description
Request for CreateSACRealm method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, in the form projects/{project}/locations/global.
sac_realm_id: StringRequired. ID of the created realm.
The ID must be 1-63 characters long, and comply with
RFC1035.
Specifically, it must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
sac_realm: Option<SACRealm>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateSACRealmRequest
impl CreateSACRealmRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_sac_realm_id<T: Into<String>>(self, v: T) -> Self
pub fn set_sac_realm_id<T: Into<String>>(self, v: T) -> Self
Sets the value of sac_realm_id.
Example
let x = CreateSACRealmRequest::new().set_sac_realm_id("example");Sourcepub fn set_sac_realm<T>(self, v: T) -> Self
pub fn set_sac_realm<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_sac_realm<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_sac_realm<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSACRealmRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSACRealmRequest
impl Clone for CreateSACRealmRequest
Sourcefn clone(&self) -> CreateSACRealmRequest
fn clone(&self) -> CreateSACRealmRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateSACRealmRequest
impl Debug for CreateSACRealmRequest
Sourceimpl Default for CreateSACRealmRequest
impl Default for CreateSACRealmRequest
Sourcefn default() -> CreateSACRealmRequest
fn default() -> CreateSACRealmRequest
Sourceimpl Message for CreateSACRealmRequest
impl Message for CreateSACRealmRequest
Sourceimpl PartialEq for CreateSACRealmRequest
impl PartialEq for CreateSACRealmRequest
Sourcefn eq(&self, other: &CreateSACRealmRequest) -> bool
fn eq(&self, other: &CreateSACRealmRequest) -> bool
self and other values to be equal, and is used by ==.