#[non_exhaustive]pub struct CreateSecurityProfileGroupRequest {
pub parent: String,
pub security_profile_group_id: String,
pub security_profile_group: Option<SecurityProfileGroup>,
/* private fields */
}Expand description
Request used by the CreateSecurityProfileGroup method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the SecurityProfileGroup. Must be in the
format projects|organizations/*/locations/{location}.
security_profile_group_id: StringRequired. Short name of the SecurityProfileGroup resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. “security_profile_group1”.
security_profile_group: Option<SecurityProfileGroup>Required. SecurityProfileGroup resource to be created.
Implementations
Sourceimpl CreateSecurityProfileGroupRequest
impl CreateSecurityProfileGroupRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_security_profile_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_security_profile_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of security_profile_group_id.
Example
ⓘ
let x = CreateSecurityProfileGroupRequest::new().set_security_profile_group_id("example");Sourcepub fn set_security_profile_group<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfileGroup>,
pub fn set_security_profile_group<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfileGroup>,
Sets the value of security_profile_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
let x = CreateSecurityProfileGroupRequest::new().set_security_profile_group(SecurityProfileGroup::default()/* use setters */);Sourcepub fn set_or_clear_security_profile_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfileGroup>,
pub fn set_or_clear_security_profile_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfileGroup>,
Sets or clears the value of security_profile_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
let x = CreateSecurityProfileGroupRequest::new().set_or_clear_security_profile_group(Some(SecurityProfileGroup::default()/* use setters */));
let x = CreateSecurityProfileGroupRequest::new().set_or_clear_security_profile_group(None::<SecurityProfileGroup>);Trait Implementations
Sourceimpl Clone for CreateSecurityProfileGroupRequest
impl Clone for CreateSecurityProfileGroupRequest
Sourcefn clone(&self) -> CreateSecurityProfileGroupRequest
fn clone(&self) -> CreateSecurityProfileGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateSecurityProfileGroupRequest
impl Default for CreateSecurityProfileGroupRequest
Sourcefn default() -> CreateSecurityProfileGroupRequest
fn default() -> CreateSecurityProfileGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateSecurityProfileGroupRequest
impl PartialEq for CreateSecurityProfileGroupRequest
Sourcefn eq(&self, other: &CreateSecurityProfileGroupRequest) -> bool
fn eq(&self, other: &CreateSecurityProfileGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateSecurityProfileGroupRequest