#[non_exhaustive]pub struct CreateSecurityProfileRequest {
pub parent: String,
pub security_profile_id: String,
pub security_profile: Option<SecurityProfile>,
/* private fields */
}Expand description
Request used by the CreateSecurityProfile method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the SecurityProfile. Must be in the format
projects|organizations/*/locations/{location}.
security_profile_id: StringRequired. Short name of the SecurityProfile resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. “security_profile1”.
security_profile: Option<SecurityProfile>Required. SecurityProfile resource to be created.
Implementations
Sourceimpl CreateSecurityProfileRequest
impl CreateSecurityProfileRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_security_profile_id<T: Into<String>>(self, v: T) -> Self
pub fn set_security_profile_id<T: Into<String>>(self, v: T) -> Self
Sets the value of security_profile_id.
Example
ⓘ
let x = CreateSecurityProfileRequest::new().set_security_profile_id("example");Sourcepub fn set_security_profile<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfile>,
pub fn set_security_profile<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfile>,
Sets the value of security_profile.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfile;
let x = CreateSecurityProfileRequest::new().set_security_profile(SecurityProfile::default()/* use setters */);Sourcepub fn set_or_clear_security_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfile>,
pub fn set_or_clear_security_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfile>,
Sets or clears the value of security_profile.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfile;
let x = CreateSecurityProfileRequest::new().set_or_clear_security_profile(Some(SecurityProfile::default()/* use setters */));
let x = CreateSecurityProfileRequest::new().set_or_clear_security_profile(None::<SecurityProfile>);Trait Implementations
Sourceimpl Clone for CreateSecurityProfileRequest
impl Clone for CreateSecurityProfileRequest
Sourcefn clone(&self) -> CreateSecurityProfileRequest
fn clone(&self) -> CreateSecurityProfileRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateSecurityProfileRequest
impl Debug for CreateSecurityProfileRequest
Sourceimpl Default for CreateSecurityProfileRequest
impl Default for CreateSecurityProfileRequest
Sourcefn default() -> CreateSecurityProfileRequest
fn default() -> CreateSecurityProfileRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateSecurityProfileRequest
impl PartialEq for CreateSecurityProfileRequest
Sourcefn eq(&self, other: &CreateSecurityProfileRequest) -> bool
fn eq(&self, other: &CreateSecurityProfileRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateSecurityProfileRequest