#[non_exhaustive]pub struct CreateTlsInspectionPolicyRequest {
pub parent: String,
pub tls_inspection_policy_id: String,
pub tls_inspection_policy: Option<TlsInspectionPolicy>,
/* private fields */
}Expand description
Request used by the CreateTlsInspectionPolicy method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource of the TlsInspectionPolicy. Must be in the
format projects/{project}/locations/{location}.
tls_inspection_policy_id: StringRequired. Short name of the TlsInspectionPolicy resource to be created. This value should be 1-63 characters long, containing only letters, numbers, hyphens, and underscores, and should not start with a number. E.g. “tls_inspection_policy1”.
tls_inspection_policy: Option<TlsInspectionPolicy>Required. TlsInspectionPolicy resource to be created.
Implementations
Sourceimpl CreateTlsInspectionPolicyRequest
impl CreateTlsInspectionPolicyRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_tls_inspection_policy_id<T: Into<String>>(self, v: T) -> Self
pub fn set_tls_inspection_policy_id<T: Into<String>>(self, v: T) -> Self
Sets the value of tls_inspection_policy_id.
Example
ⓘ
let x = CreateTlsInspectionPolicyRequest::new().set_tls_inspection_policy_id("example");Sourcepub fn set_tls_inspection_policy<T>(self, v: T) -> Selfwhere
T: Into<TlsInspectionPolicy>,
pub fn set_tls_inspection_policy<T>(self, v: T) -> Selfwhere
T: Into<TlsInspectionPolicy>,
Sets the value of tls_inspection_policy.
Example
ⓘ
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
let x = CreateTlsInspectionPolicyRequest::new().set_tls_inspection_policy(TlsInspectionPolicy::default()/* use setters */);Sourcepub fn set_or_clear_tls_inspection_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<TlsInspectionPolicy>,
pub fn set_or_clear_tls_inspection_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<TlsInspectionPolicy>,
Sets or clears the value of tls_inspection_policy.
Example
ⓘ
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
let x = CreateTlsInspectionPolicyRequest::new().set_or_clear_tls_inspection_policy(Some(TlsInspectionPolicy::default()/* use setters */));
let x = CreateTlsInspectionPolicyRequest::new().set_or_clear_tls_inspection_policy(None::<TlsInspectionPolicy>);Trait Implementations
Sourceimpl Clone for CreateTlsInspectionPolicyRequest
impl Clone for CreateTlsInspectionPolicyRequest
Sourcefn clone(&self) -> CreateTlsInspectionPolicyRequest
fn clone(&self) -> CreateTlsInspectionPolicyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateTlsInspectionPolicyRequest
impl Default for CreateTlsInspectionPolicyRequest
Sourcefn default() -> CreateTlsInspectionPolicyRequest
fn default() -> CreateTlsInspectionPolicyRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateTlsInspectionPolicyRequest
impl PartialEq for CreateTlsInspectionPolicyRequest
Sourcefn eq(&self, other: &CreateTlsInspectionPolicyRequest) -> bool
fn eq(&self, other: &CreateTlsInspectionPolicyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateTlsInspectionPolicyRequest