#[non_exhaustive]pub struct CustomInterceptProfile {
pub intercept_endpoint_group: String,
/* private fields */
}Expand description
CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intercept_endpoint_group: StringRequired. The target InterceptEndpointGroup. When a firewall rule with this security profile attached matches a packet, the packet will be intercepted to the location-local target in this group.
Implementations
Sourceimpl CustomInterceptProfile
impl CustomInterceptProfile
pub fn new() -> Self
Sourcepub fn set_intercept_endpoint_group<T: Into<String>>(self, v: T) -> Self
pub fn set_intercept_endpoint_group<T: Into<String>>(self, v: T) -> Self
Sets the value of intercept_endpoint_group.
Example
ⓘ
let x = CustomInterceptProfile::new().set_intercept_endpoint_group("example");Trait Implementations
Sourceimpl Clone for CustomInterceptProfile
impl Clone for CustomInterceptProfile
Sourcefn clone(&self) -> CustomInterceptProfile
fn clone(&self) -> CustomInterceptProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomInterceptProfile
impl Debug for CustomInterceptProfile
Sourceimpl Default for CustomInterceptProfile
impl Default for CustomInterceptProfile
Sourcefn default() -> CustomInterceptProfile
fn default() -> CustomInterceptProfile
Returns the “default value” for a type. Read more
Sourceimpl Message for CustomInterceptProfile
impl Message for CustomInterceptProfile
Sourceimpl PartialEq for CustomInterceptProfile
impl PartialEq for CustomInterceptProfile
impl StructuralPartialEq for CustomInterceptProfile