#[non_exhaustive]pub struct CustomMirroringProfile {
pub mirroring_endpoint_group: String,
/* private fields */
}Expand description
CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mirroring_endpoint_group: StringRequired. Immutable. The target MirroringEndpointGroup. When a mirroring rule with this security profile attached matches a packet, a replica will be mirrored to the location-local target in this group.
Implementations
Sourceimpl CustomMirroringProfile
impl CustomMirroringProfile
pub fn new() -> Self
Sourcepub fn set_mirroring_endpoint_group<T: Into<String>>(self, v: T) -> Self
pub fn set_mirroring_endpoint_group<T: Into<String>>(self, v: T) -> Self
Sets the value of mirroring_endpoint_group.
Example
ⓘ
let x = CustomMirroringProfile::new().set_mirroring_endpoint_group("example");Trait Implementations
Sourceimpl Clone for CustomMirroringProfile
impl Clone for CustomMirroringProfile
Sourcefn clone(&self) -> CustomMirroringProfile
fn clone(&self) -> CustomMirroringProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomMirroringProfile
impl Debug for CustomMirroringProfile
Sourceimpl Default for CustomMirroringProfile
impl Default for CustomMirroringProfile
Sourcefn default() -> CustomMirroringProfile
fn default() -> CustomMirroringProfile
Returns the “default value” for a type. Read more
Sourceimpl Message for CustomMirroringProfile
impl Message for CustomMirroringProfile
Sourceimpl PartialEq for CustomMirroringProfile
impl PartialEq for CustomMirroringProfile
impl StructuralPartialEq for CustomMirroringProfile