#[non_exhaustive]pub struct DeleteTlsInspectionPolicyRequest {
pub name: String,
pub force: bool,
/* private fields */
}Expand description
Request used by the DeleteTlsInspectionPolicy method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. A name of the TlsInspectionPolicy to delete. Must be in the
format
projects/{project}/locations/{location}/tlsInspectionPolicies/{tls_inspection_policy}.
force: boolIf set to true, any rules for this TlsInspectionPolicy will also be deleted. (Otherwise, the request will only work if the TlsInspectionPolicy has no rules.)
Implementations