DnsThreatDetector

Struct DnsThreatDetector 

#[non_exhaustive]
pub struct DnsThreatDetector { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub excluded_networks: Vec<String>, pub provider: Provider, /* private fields */ }
A DNS threat detector sends DNS query logs to a provider that then analyzes the logs to identify threat events in the DNS queries. By default, all VPC networks in your projects are included. You can exclude specific networks by supplying excluded_networks.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. Identifier. Name of the DnsThreatDetector resource.

create_time: Option<Timestamp>

Output only. Create time stamp.

update_time: Option<Timestamp>

Output only. Update time stamp.

labels: HashMap<String, String>

Optional. Any labels associated with the DnsThreatDetector, listed as key value pairs.

excluded_networks: Vec<String>

Optional. A list of network resource names which aren’t monitored by this DnsThreatDetector.

Example: projects/PROJECT_ID/global/networks/NETWORK_NAME.

provider: Provider

Required. The provider used for DNS threat analysis.

Implementations

Source

impl DnsThreatDetector

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DnsThreatDetector::new().set_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = DnsThreatDetector::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = DnsThreatDetector::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DnsThreatDetector::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = DnsThreatDetector::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = DnsThreatDetector::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DnsThreatDetector::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DnsThreatDetector::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_excluded_networks<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of excluded_networks.

Example
let x = DnsThreatDetector::new().set_excluded_networks(["a", "b", "c"]);
pub fn set_provider<T: Into<Provider>>(self, v: T) -> Self

Sets the value of provider.

Example
use google_cloud_networksecurity_v1::model::dns_threat_detector::Provider;
let x0 = DnsThreatDetector::new().set_provider(Provider::Infoblox);