FirewallEndpoint

Struct FirewallEndpoint 

#[non_exhaustive]
pub struct FirewallEndpoint {
Show 13 fields pub name: String, pub description: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub state: State, pub reconciling: bool, pub associated_networks: Vec<String>, pub associations: Vec<AssociationReference>, pub satisfies_pzs: Option<bool>, pub satisfies_pzi: Option<bool>, pub billing_project_id: String, pub endpoint_settings: Option<EndpointSettings>, /* private fields */
}
Message describing Endpoint object.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. Identifier. Name of resource.

description: String

Optional. Description of the firewall endpoint. Max length 2048 characters.

create_time: Option<Timestamp>

Output only. Create time stamp.

update_time: Option<Timestamp>

Output only. Update time stamp

labels: HashMap<String, String>

Optional. Labels as key value pairs

state: State

Output only. Current state of the endpoint.

reconciling: bool

Output only. Whether reconciling is in progress, recommended per https://google.aip.dev/128.

associated_networks: Vec<String>
👎Deprecated

Output only. List of networks that are associated with this endpoint in the local zone. This is a projection of the FirewallEndpointAssociations pointing at this endpoint. A network will only appear in this list after traffic routing is fully configured. Format: projects/{project}/global/networks/{name}.

associations: Vec<AssociationReference>

Output only. List of FirewallEndpointAssociations that are associated to this endpoint. An association will only appear in this list after traffic routing is fully configured.

satisfies_pzs: Option<bool>

Output only. [Output Only] Reserved for future use.

satisfies_pzi: Option<bool>

Output only. [Output Only] Reserved for future use.

billing_project_id: String

Optional. Project to charge for the deployed firewall endpoint. This field must be specified when creating the endpoint in the organization scope, and should be omitted otherwise.

endpoint_settings: Option<EndpointSettings>

Optional. Settings for the endpoint.

Implementations

Source

impl FirewallEndpoint

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = FirewallEndpoint::new().set_name("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = FirewallEndpoint::new().set_description("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = FirewallEndpoint::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FirewallEndpoint::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = FirewallEndpoint::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::State;
let x0 = FirewallEndpoint::new().set_state(State::Creating);
let x1 = FirewallEndpoint::new().set_state(State::Active);
let x2 = FirewallEndpoint::new().set_state(State::Deleting);
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = FirewallEndpoint::new().set_reconciling(true);
pub fn set_associated_networks<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

👎Deprecated

Sets the value of associated_networks.

Example
let x = FirewallEndpoint::new().set_associated_networks(["a", "b", "c"]);
pub fn set_associations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<AssociationReference>,

Sets the value of associations.

Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::AssociationReference;
let x = FirewallEndpoint::new()
    .set_associations([
        AssociationReference::default()/* use setters */,
        AssociationReference::default()/* use (different) setters */,
    ]);
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of satisfies_pzs.

Example
let x = FirewallEndpoint::new().set_satisfies_pzs(true);
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of satisfies_pzs.

Example
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzs(Some(false));
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzs(None::<bool>);
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of satisfies_pzi.

Example
let x = FirewallEndpoint::new().set_satisfies_pzi(true);
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of satisfies_pzi.

Example
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzi(Some(false));
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzi(None::<bool>);
pub fn set_billing_project_id<T: Into<String>>(self, v: T) -> Self

Sets the value of billing_project_id.

Example
let x = FirewallEndpoint::new().set_billing_project_id("example");
pub fn set_endpoint_settings<T>(self, v: T) -> Self

Sets the value of endpoint_settings.

Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::EndpointSettings;
let x = FirewallEndpoint::new().set_endpoint_settings(EndpointSettings::default()/* use setters */);
pub fn set_or_clear_endpoint_settings<T>(self, v: Option<T>) -> Self

Sets or clears the value of endpoint_settings.

Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::EndpointSettings;
let x = FirewallEndpoint::new().set_or_clear_endpoint_settings(Some(EndpointSettings::default()/* use setters */));
let x = FirewallEndpoint::new().set_or_clear_endpoint_settings(None::<EndpointSettings>);