InterceptDeployment

Struct InterceptDeployment 

#[non_exhaustive]
pub struct InterceptDeployment { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub forwarding_rule: String, pub intercept_deployment_group: String, pub state: State, pub reconciling: bool, pub description: String, /* private fields */ }
A deployment represents a zonal intercept backend ready to accept GENEVE-encapsulated traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global intercept service.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. Identifier. The resource name of this deployment, for example: projects/123456789/locations/us-central1-a/interceptDeployments/my-dep. See https://google.aip.dev/122 for more details.

create_time: Option<Timestamp>

Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

update_time: Option<Timestamp>

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.

labels: HashMap<String, String>

Optional. Labels are key/value pairs that help to organize and filter resources.

forwarding_rule: String

Required. Immutable. The regional forwarding rule that fronts the interceptors, for example: projects/123456789/regions/us-central1/forwardingRules/my-rule. See https://google.aip.dev/124.

intercept_deployment_group: String

Required. Immutable. The deployment group that this deployment is a part of, for example: projects/123456789/locations/global/interceptDeploymentGroups/my-dg. See https://google.aip.dev/124.

state: State

Output only. The current state of the deployment. See https://google.aip.dev/216.

reconciling: bool

Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This part of the normal operation (e.g. linking a new association to the parent group). See https://google.aip.dev/128.

description: String

Optional. User-provided description of the deployment. Used as additional context for the deployment.

Implementations

Source

impl InterceptDeployment

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = InterceptDeployment::new().set_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = InterceptDeployment::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = InterceptDeployment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = InterceptDeployment::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = InterceptDeployment::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = InterceptDeployment::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = InterceptDeployment::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = InterceptDeployment::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_forwarding_rule<T: Into<String>>(self, v: T) -> Self

Sets the value of forwarding_rule.

Example
let x = InterceptDeployment::new().set_forwarding_rule("example");
pub fn set_intercept_deployment_group<T: Into<String>>(self, v: T) -> Self

Sets the value of intercept_deployment_group.

Example
let x = InterceptDeployment::new().set_intercept_deployment_group("example");
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_networksecurity_v1::model::intercept_deployment::State;
let x0 = InterceptDeployment::new().set_state(State::Active);
let x1 = InterceptDeployment::new().set_state(State::Creating);
let x2 = InterceptDeployment::new().set_state(State::Deleting);
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = InterceptDeployment::new().set_reconciling(true);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = InterceptDeployment::new().set_description("example");