#[non_exhaustive]pub struct InterceptEndpointGroupAssociation {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub intercept_endpoint_group: String,
pub network: String,
pub locations_details: Vec<LocationDetails>,
pub state: State,
pub reconciling: bool,
pub locations: Vec<InterceptLocation>,
pub network_cookie: u32,
/* private fields */
}Expand description
An endpoint group association represents a link between a network and an endpoint group in the organization.
Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable intercept by itself. To enable intercept, the user must also create a network firewall policy containing intercept rules and associate it with the network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. Identifier. The resource name of this endpoint group
association, for example:
projects/123456789/locations/global/interceptEndpointGroupAssociations/my-eg-association.
See https://google.aip.dev/122 for more details.
create_time: Option<Timestamp>Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.
update_time: Option<Timestamp>Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.
labels: HashMap<String, String>Optional. Labels are key/value pairs that help to organize and filter resources.
intercept_endpoint_group: StringRequired. Immutable. The endpoint group that this association is connected
to, for example:
projects/123456789/locations/global/interceptEndpointGroups/my-eg.
See https://google.aip.dev/124.
network: StringRequired. Immutable. The VPC network that is associated. for example:
projects/123456789/global/networks/my-network.
See https://google.aip.dev/124.
locations_details: Vec<LocationDetails>Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself.
state: StateOutput only. Current state of the endpoint group association.
reconciling: boolOutput only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128.
locations: Vec<InterceptLocation>Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group.
Output only. Identifier used by the data-path. See the NSI GENEVE format for more details: https://docs.cloud.google.com/network-security-integration/docs/understand-geneve#network_id
Implementations
Sourceimpl InterceptEndpointGroupAssociation
impl InterceptEndpointGroupAssociation
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = InterceptEndpointGroupAssociation::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = InterceptEndpointGroupAssociation::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = InterceptEndpointGroupAssociation::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = InterceptEndpointGroupAssociation::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = InterceptEndpointGroupAssociation::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = InterceptEndpointGroupAssociation::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_intercept_endpoint_group<T: Into<String>>(self, v: T) -> Self
pub fn set_intercept_endpoint_group<T: Into<String>>(self, v: T) -> Self
Sets the value of intercept_endpoint_group.
Example
let x = InterceptEndpointGroupAssociation::new().set_intercept_endpoint_group("example");Sourcepub fn set_network<T: Into<String>>(self, v: T) -> Self
pub fn set_network<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_locations_details<T, V>(self, v: T) -> Self
👎Deprecated
pub fn set_locations_details<T, V>(self, v: T) -> Self
Sets the value of locations_details.
Example
use google_cloud_networksecurity_v1::model::intercept_endpoint_group_association::LocationDetails;
let x = InterceptEndpointGroupAssociation::new()
.set_locations_details([
LocationDetails::default()/* use setters */,
LocationDetails::default()/* use (different) setters */,
]);Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_networksecurity_v1::model::intercept_endpoint_group_association::State;
let x0 = InterceptEndpointGroupAssociation::new().set_state(State::Active);
let x1 = InterceptEndpointGroupAssociation::new().set_state(State::Creating);
let x2 = InterceptEndpointGroupAssociation::new().set_state(State::Deleting);Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sets the value of reconciling.
Example
let x = InterceptEndpointGroupAssociation::new().set_reconciling(true);Sourcepub fn set_locations<T, V>(self, v: T) -> Self
pub fn set_locations<T, V>(self, v: T) -> Self
Sets the value of network_cookie.
Example
let x = InterceptEndpointGroupAssociation::new().set_network_cookie(42_u32);Trait Implementations
Sourceimpl Clone for InterceptEndpointGroupAssociation
impl Clone for InterceptEndpointGroupAssociation
Sourcefn clone(&self) -> InterceptEndpointGroupAssociation
fn clone(&self) -> InterceptEndpointGroupAssociation
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for InterceptEndpointGroupAssociation
impl Default for InterceptEndpointGroupAssociation
Sourcefn default() -> InterceptEndpointGroupAssociation
fn default() -> InterceptEndpointGroupAssociation
Sourceimpl PartialEq for InterceptEndpointGroupAssociation
impl PartialEq for InterceptEndpointGroupAssociation
Sourcefn eq(&self, other: &InterceptEndpointGroupAssociation) -> bool
fn eq(&self, other: &InterceptEndpointGroupAssociation) -> bool
self and other values to be equal, and is used by ==.