#[non_exhaustive]pub struct ListBackendAuthenticationConfigsResponse {
pub backend_authentication_configs: Vec<BackendAuthenticationConfig>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response returned by the ListBackendAuthenticationConfigs method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backend_authentication_configs: Vec<BackendAuthenticationConfig>List of BackendAuthenticationConfig resources.
next_page_token: StringIf there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListBackendAuthenticationConfigsResponse
impl ListBackendAuthenticationConfigsResponse
pub fn new() -> Self
Sourcepub fn set_backend_authentication_configs<T, V>(self, v: T) -> Self
pub fn set_backend_authentication_configs<T, V>(self, v: T) -> Self
Sets the value of backend_authentication_configs.
Example
ⓘ
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
let x = ListBackendAuthenticationConfigsResponse::new()
.set_backend_authentication_configs([
BackendAuthenticationConfig::default()/* use setters */,
BackendAuthenticationConfig::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListBackendAuthenticationConfigsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListBackendAuthenticationConfigsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListBackendAuthenticationConfigsResponse
impl Clone for ListBackendAuthenticationConfigsResponse
Sourcefn clone(&self) -> ListBackendAuthenticationConfigsResponse
fn clone(&self) -> ListBackendAuthenticationConfigsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListBackendAuthenticationConfigsResponse
impl Default for ListBackendAuthenticationConfigsResponse
Sourcefn default() -> ListBackendAuthenticationConfigsResponse
fn default() -> ListBackendAuthenticationConfigsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListBackendAuthenticationConfigsResponse
impl PartialEq for ListBackendAuthenticationConfigsResponse
Sourcefn eq(&self, other: &ListBackendAuthenticationConfigsResponse) -> bool
fn eq(&self, other: &ListBackendAuthenticationConfigsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListBackendAuthenticationConfigsResponse