#[non_exhaustive]pub struct ListDnsThreatDetectorsResponse {
pub dns_threat_detectors: Vec<DnsThreatDetector>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
The response message to requesting a list of DnsThreatDetectors.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dns_threat_detectors: Vec<DnsThreatDetector>The list of DnsThreatDetector resources.
next_page_token: StringA token, which can be sent as page_token, to retrieve the next page.
unreachable: Vec<String>Unordered list. Unreachable DnsThreatDetector resources.
Implementations
Sourceimpl ListDnsThreatDetectorsResponse
impl ListDnsThreatDetectorsResponse
pub fn new() -> Self
Sourcepub fn set_dns_threat_detectors<T, V>(self, v: T) -> Self
pub fn set_dns_threat_detectors<T, V>(self, v: T) -> Self
Sets the value of dns_threat_detectors.
Example
ⓘ
use google_cloud_networksecurity_v1::model::DnsThreatDetector;
let x = ListDnsThreatDetectorsResponse::new()
.set_dns_threat_detectors([
DnsThreatDetector::default()/* use setters */,
DnsThreatDetector::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListDnsThreatDetectorsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListDnsThreatDetectorsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListDnsThreatDetectorsResponse
impl Clone for ListDnsThreatDetectorsResponse
Sourcefn clone(&self) -> ListDnsThreatDetectorsResponse
fn clone(&self) -> ListDnsThreatDetectorsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListDnsThreatDetectorsResponse
impl Default for ListDnsThreatDetectorsResponse
Sourcefn default() -> ListDnsThreatDetectorsResponse
fn default() -> ListDnsThreatDetectorsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListDnsThreatDetectorsResponse
impl PartialEq for ListDnsThreatDetectorsResponse
Sourcefn eq(&self, other: &ListDnsThreatDetectorsResponse) -> bool
fn eq(&self, other: &ListDnsThreatDetectorsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListDnsThreatDetectorsResponse