#[non_exhaustive]pub struct ListFirewallEndpointAssociationsResponse {
pub firewall_endpoint_associations: Vec<FirewallEndpointAssociation>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Message for response to listing Associations
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.firewall_endpoint_associations: Vec<FirewallEndpointAssociation>The list of Association
next_page_token: StringA token identifying a page of results the server should return.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListFirewallEndpointAssociationsResponse
impl ListFirewallEndpointAssociationsResponse
pub fn new() -> Self
Sourcepub fn set_firewall_endpoint_associations<T, V>(self, v: T) -> Self
pub fn set_firewall_endpoint_associations<T, V>(self, v: T) -> Self
Sets the value of firewall_endpoint_associations.
Example
ⓘ
use google_cloud_networksecurity_v1::model::FirewallEndpointAssociation;
let x = ListFirewallEndpointAssociationsResponse::new()
.set_firewall_endpoint_associations([
FirewallEndpointAssociation::default()/* use setters */,
FirewallEndpointAssociation::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListFirewallEndpointAssociationsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListFirewallEndpointAssociationsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListFirewallEndpointAssociationsResponse
impl Clone for ListFirewallEndpointAssociationsResponse
Sourcefn clone(&self) -> ListFirewallEndpointAssociationsResponse
fn clone(&self) -> ListFirewallEndpointAssociationsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListFirewallEndpointAssociationsResponse
impl Default for ListFirewallEndpointAssociationsResponse
Sourcefn default() -> ListFirewallEndpointAssociationsResponse
fn default() -> ListFirewallEndpointAssociationsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListFirewallEndpointAssociationsResponse
impl PartialEq for ListFirewallEndpointAssociationsResponse
Sourcefn eq(&self, other: &ListFirewallEndpointAssociationsResponse) -> bool
fn eq(&self, other: &ListFirewallEndpointAssociationsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListFirewallEndpointAssociationsResponse