#[non_exhaustive]pub struct ListFirewallEndpointsResponse {
pub firewall_endpoints: Vec<FirewallEndpoint>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Message for response to listing Endpoints
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.firewall_endpoints: Vec<FirewallEndpoint>The list of Endpoint
next_page_token: StringA token identifying a page of results the server should return.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListFirewallEndpointsResponse
impl ListFirewallEndpointsResponse
pub fn new() -> Self
Sourcepub fn set_firewall_endpoints<T, V>(self, v: T) -> Self
pub fn set_firewall_endpoints<T, V>(self, v: T) -> Self
Sets the value of firewall_endpoints.
Example
ⓘ
use google_cloud_networksecurity_v1::model::FirewallEndpoint;
let x = ListFirewallEndpointsResponse::new()
.set_firewall_endpoints([
FirewallEndpoint::default()/* use setters */,
FirewallEndpoint::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListFirewallEndpointsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListFirewallEndpointsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListFirewallEndpointsResponse
impl Clone for ListFirewallEndpointsResponse
Sourcefn clone(&self) -> ListFirewallEndpointsResponse
fn clone(&self) -> ListFirewallEndpointsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListFirewallEndpointsResponse
impl Default for ListFirewallEndpointsResponse
Sourcefn default() -> ListFirewallEndpointsResponse
fn default() -> ListFirewallEndpointsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListFirewallEndpointsResponse
impl PartialEq for ListFirewallEndpointsResponse
Sourcefn eq(&self, other: &ListFirewallEndpointsResponse) -> bool
fn eq(&self, other: &ListFirewallEndpointsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListFirewallEndpointsResponse