#[non_exhaustive]pub struct ListGatewaySecurityPoliciesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request used with the ListGatewaySecurityPolicies method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project and location from which the GatewaySecurityPolicies
should be listed, specified in the format
projects/{project}/locations/{location}.
page_size: i32Maximum number of GatewaySecurityPolicies to return per call.
page_token: StringThe value returned by the last ‘ListGatewaySecurityPoliciesResponse’ Indicates that this is a continuation of a prior ‘ListGatewaySecurityPolicies’ call, and that the system should return the next page of data.
Implementations
Sourceimpl ListGatewaySecurityPoliciesRequest
impl ListGatewaySecurityPoliciesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListGatewaySecurityPoliciesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListGatewaySecurityPoliciesRequest
impl Clone for ListGatewaySecurityPoliciesRequest
Sourcefn clone(&self) -> ListGatewaySecurityPoliciesRequest
fn clone(&self) -> ListGatewaySecurityPoliciesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListGatewaySecurityPoliciesRequest
impl Default for ListGatewaySecurityPoliciesRequest
Sourcefn default() -> ListGatewaySecurityPoliciesRequest
fn default() -> ListGatewaySecurityPoliciesRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListGatewaySecurityPoliciesRequest
impl PartialEq for ListGatewaySecurityPoliciesRequest
Sourcefn eq(&self, other: &ListGatewaySecurityPoliciesRequest) -> bool
fn eq(&self, other: &ListGatewaySecurityPoliciesRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListGatewaySecurityPoliciesRequest