#[non_exhaustive]pub struct ListGatewaySecurityPolicyRulesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request used with the ListGatewaySecurityPolicyRules method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project, location and GatewaySecurityPolicy from which the
GatewaySecurityPolicyRules should be listed, specified in the format
projects/{project}/locations/{location}/gatewaySecurityPolicies/{gatewaySecurityPolicy}.
page_size: i32Maximum number of GatewaySecurityPolicyRules to return per call.
page_token: StringThe value returned by the last ‘ListGatewaySecurityPolicyRulesResponse’ Indicates that this is a continuation of a prior ‘ListGatewaySecurityPolicyRules’ call, and that the system should return the next page of data.
Implementations
Sourceimpl ListGatewaySecurityPolicyRulesRequest
impl ListGatewaySecurityPolicyRulesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListGatewaySecurityPolicyRulesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListGatewaySecurityPolicyRulesRequest
impl Clone for ListGatewaySecurityPolicyRulesRequest
Sourcefn clone(&self) -> ListGatewaySecurityPolicyRulesRequest
fn clone(&self) -> ListGatewaySecurityPolicyRulesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListGatewaySecurityPolicyRulesRequest
impl Default for ListGatewaySecurityPolicyRulesRequest
Sourcefn default() -> ListGatewaySecurityPolicyRulesRequest
fn default() -> ListGatewaySecurityPolicyRulesRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListGatewaySecurityPolicyRulesRequest
impl PartialEq for ListGatewaySecurityPolicyRulesRequest
Sourcefn eq(&self, other: &ListGatewaySecurityPolicyRulesRequest) -> bool
fn eq(&self, other: &ListGatewaySecurityPolicyRulesRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListGatewaySecurityPolicyRulesRequest