#[non_exhaustive]pub struct ListGatewaySecurityPolicyRulesResponse {
pub gateway_security_policy_rules: Vec<GatewaySecurityPolicyRule>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response returned by the ListGatewaySecurityPolicyRules method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.gateway_security_policy_rules: Vec<GatewaySecurityPolicyRule>List of GatewaySecurityPolicyRule resources.
next_page_token: StringIf there might be more results than those appearing in this response, then ‘next_page_token’ is included. To get the next set of results, call this method again using the value of ‘next_page_token’ as ‘page_token’.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListGatewaySecurityPolicyRulesResponse
impl ListGatewaySecurityPolicyRulesResponse
Sourcepub fn set_gateway_security_policy_rules<T, V>(self, v: T) -> Self
pub fn set_gateway_security_policy_rules<T, V>(self, v: T) -> Self
Sets the value of gateway_security_policy_rules.
Example
ⓘ
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicyRule;
let x = ListGatewaySecurityPolicyRulesResponse::new()
.set_gateway_security_policy_rules([
GatewaySecurityPolicyRule::default()/* use setters */,
GatewaySecurityPolicyRule::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListGatewaySecurityPolicyRulesResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListGatewaySecurityPolicyRulesResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListGatewaySecurityPolicyRulesResponse
impl Clone for ListGatewaySecurityPolicyRulesResponse
Sourcefn clone(&self) -> ListGatewaySecurityPolicyRulesResponse
fn clone(&self) -> ListGatewaySecurityPolicyRulesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListGatewaySecurityPolicyRulesResponse
impl Default for ListGatewaySecurityPolicyRulesResponse
Sourcefn default() -> ListGatewaySecurityPolicyRulesResponse
fn default() -> ListGatewaySecurityPolicyRulesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListGatewaySecurityPolicyRulesResponse
impl PartialEq for ListGatewaySecurityPolicyRulesResponse
Sourcefn eq(&self, other: &ListGatewaySecurityPolicyRulesResponse) -> bool
fn eq(&self, other: &ListGatewaySecurityPolicyRulesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListGatewaySecurityPolicyRulesResponse