#[non_exhaustive]pub struct ListInterceptDeploymentGroupsResponse {
pub intercept_deployment_groups: Vec<InterceptDeploymentGroup>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListInterceptDeploymentGroups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intercept_deployment_groups: Vec<InterceptDeploymentGroup>The deployment groups from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
Implementations
Sourceimpl ListInterceptDeploymentGroupsResponse
impl ListInterceptDeploymentGroupsResponse
pub fn new() -> Self
Sourcepub fn set_intercept_deployment_groups<T, V>(self, v: T) -> Self
pub fn set_intercept_deployment_groups<T, V>(self, v: T) -> Self
Sets the value of intercept_deployment_groups.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptDeploymentGroup;
let x = ListInterceptDeploymentGroupsResponse::new()
.set_intercept_deployment_groups([
InterceptDeploymentGroup::default()/* use setters */,
InterceptDeploymentGroup::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListInterceptDeploymentGroupsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListInterceptDeploymentGroupsResponse
impl Clone for ListInterceptDeploymentGroupsResponse
Sourcefn clone(&self) -> ListInterceptDeploymentGroupsResponse
fn clone(&self) -> ListInterceptDeploymentGroupsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListInterceptDeploymentGroupsResponse
impl Default for ListInterceptDeploymentGroupsResponse
Sourcefn default() -> ListInterceptDeploymentGroupsResponse
fn default() -> ListInterceptDeploymentGroupsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListInterceptDeploymentGroupsResponse
impl PartialEq for ListInterceptDeploymentGroupsResponse
Sourcefn eq(&self, other: &ListInterceptDeploymentGroupsResponse) -> bool
fn eq(&self, other: &ListInterceptDeploymentGroupsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListInterceptDeploymentGroupsResponse