#[non_exhaustive]pub struct ListInterceptDeploymentsResponse {
pub intercept_deployments: Vec<InterceptDeployment>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListInterceptDeployments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intercept_deployments: Vec<InterceptDeployment>The deployments from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListInterceptDeploymentsResponse
impl ListInterceptDeploymentsResponse
pub fn new() -> Self
Sourcepub fn set_intercept_deployments<T, V>(self, v: T) -> Self
pub fn set_intercept_deployments<T, V>(self, v: T) -> Self
Sets the value of intercept_deployments.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptDeployment;
let x = ListInterceptDeploymentsResponse::new()
.set_intercept_deployments([
InterceptDeployment::default()/* use setters */,
InterceptDeployment::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListInterceptDeploymentsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListInterceptDeploymentsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListInterceptDeploymentsResponse
impl Clone for ListInterceptDeploymentsResponse
Sourcefn clone(&self) -> ListInterceptDeploymentsResponse
fn clone(&self) -> ListInterceptDeploymentsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListInterceptDeploymentsResponse
impl Default for ListInterceptDeploymentsResponse
Sourcefn default() -> ListInterceptDeploymentsResponse
fn default() -> ListInterceptDeploymentsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListInterceptDeploymentsResponse
impl PartialEq for ListInterceptDeploymentsResponse
Sourcefn eq(&self, other: &ListInterceptDeploymentsResponse) -> bool
fn eq(&self, other: &ListInterceptDeploymentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListInterceptDeploymentsResponse