#[non_exhaustive]pub struct ListInterceptEndpointGroupAssociationsResponse {
pub intercept_endpoint_group_associations: Vec<InterceptEndpointGroupAssociation>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListInterceptEndpointGroupAssociations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intercept_endpoint_group_associations: Vec<InterceptEndpointGroupAssociation>The associations from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
Implementations
Sourceimpl ListInterceptEndpointGroupAssociationsResponse
impl ListInterceptEndpointGroupAssociationsResponse
pub fn new() -> Self
Sourcepub fn set_intercept_endpoint_group_associations<T, V>(self, v: T) -> Self
pub fn set_intercept_endpoint_group_associations<T, V>(self, v: T) -> Self
Sets the value of intercept_endpoint_group_associations.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptEndpointGroupAssociation;
let x = ListInterceptEndpointGroupAssociationsResponse::new()
.set_intercept_endpoint_group_associations([
InterceptEndpointGroupAssociation::default()/* use setters */,
InterceptEndpointGroupAssociation::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListInterceptEndpointGroupAssociationsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListInterceptEndpointGroupAssociationsResponse
impl Clone for ListInterceptEndpointGroupAssociationsResponse
Sourcefn clone(&self) -> ListInterceptEndpointGroupAssociationsResponse
fn clone(&self) -> ListInterceptEndpointGroupAssociationsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListInterceptEndpointGroupAssociationsResponse
impl Default for ListInterceptEndpointGroupAssociationsResponse
Sourcefn default() -> ListInterceptEndpointGroupAssociationsResponse
fn default() -> ListInterceptEndpointGroupAssociationsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListInterceptEndpointGroupAssociationsResponse
impl PartialEq for ListInterceptEndpointGroupAssociationsResponse
Sourcefn eq(&self, other: &ListInterceptEndpointGroupAssociationsResponse) -> bool
fn eq(&self, other: &ListInterceptEndpointGroupAssociationsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListInterceptEndpointGroupAssociationsResponse