#[non_exhaustive]pub struct ListInterceptEndpointGroupsResponse {
pub intercept_endpoint_groups: Vec<InterceptEndpointGroup>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListInterceptEndpointGroups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intercept_endpoint_groups: Vec<InterceptEndpointGroup>The endpoint groups from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
Implementations
Sourceimpl ListInterceptEndpointGroupsResponse
impl ListInterceptEndpointGroupsResponse
pub fn new() -> Self
Sourcepub fn set_intercept_endpoint_groups<T, V>(self, v: T) -> Self
pub fn set_intercept_endpoint_groups<T, V>(self, v: T) -> Self
Sets the value of intercept_endpoint_groups.
Example
ⓘ
use google_cloud_networksecurity_v1::model::InterceptEndpointGroup;
let x = ListInterceptEndpointGroupsResponse::new()
.set_intercept_endpoint_groups([
InterceptEndpointGroup::default()/* use setters */,
InterceptEndpointGroup::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListInterceptEndpointGroupsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListInterceptEndpointGroupsResponse
impl Clone for ListInterceptEndpointGroupsResponse
Sourcefn clone(&self) -> ListInterceptEndpointGroupsResponse
fn clone(&self) -> ListInterceptEndpointGroupsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListInterceptEndpointGroupsResponse
impl Default for ListInterceptEndpointGroupsResponse
Sourcefn default() -> ListInterceptEndpointGroupsResponse
fn default() -> ListInterceptEndpointGroupsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListInterceptEndpointGroupsResponse
impl PartialEq for ListInterceptEndpointGroupsResponse
Sourcefn eq(&self, other: &ListInterceptEndpointGroupsResponse) -> bool
fn eq(&self, other: &ListInterceptEndpointGroupsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListInterceptEndpointGroupsResponse