#[non_exhaustive]pub struct ListMirroringDeploymentGroupsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request message for ListMirroringDeploymentGroups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of deployment groups.
Example: projects/123456789/locations/global.
See https://google.aip.dev/132 for more details.
page_size: i32Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default. See https://google.aip.dev/158 for more details.
page_token: StringOptional. A page token, received from a previous
ListMirroringDeploymentGroups call. Provide this to retrieve the
subsequent page. When paginating, all other parameters provided to
ListMirroringDeploymentGroups must match the call that provided the page
token. See https://google.aip.dev/158 for more details.
filter: StringOptional. Filter expression. See https://google.aip.dev/160#filtering for more details.
order_by: StringOptional. Sort expression. See https://google.aip.dev/132#ordering for more details.
Implementations
Sourceimpl ListMirroringDeploymentGroupsRequest
impl ListMirroringDeploymentGroupsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListMirroringDeploymentGroupsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self