#[non_exhaustive]pub struct ListMirroringDeploymentGroupsResponse {
pub mirroring_deployment_groups: Vec<MirroringDeploymentGroup>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListMirroringDeploymentGroups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mirroring_deployment_groups: Vec<MirroringDeploymentGroup>The deployment groups from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
Implementations
Sourceimpl ListMirroringDeploymentGroupsResponse
impl ListMirroringDeploymentGroupsResponse
pub fn new() -> Self
Sourcepub fn set_mirroring_deployment_groups<T, V>(self, v: T) -> Self
pub fn set_mirroring_deployment_groups<T, V>(self, v: T) -> Self
Sets the value of mirroring_deployment_groups.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringDeploymentGroup;
let x = ListMirroringDeploymentGroupsResponse::new()
.set_mirroring_deployment_groups([
MirroringDeploymentGroup::default()/* use setters */,
MirroringDeploymentGroup::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMirroringDeploymentGroupsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListMirroringDeploymentGroupsResponse
impl Clone for ListMirroringDeploymentGroupsResponse
Sourcefn clone(&self) -> ListMirroringDeploymentGroupsResponse
fn clone(&self) -> ListMirroringDeploymentGroupsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListMirroringDeploymentGroupsResponse
impl Default for ListMirroringDeploymentGroupsResponse
Sourcefn default() -> ListMirroringDeploymentGroupsResponse
fn default() -> ListMirroringDeploymentGroupsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListMirroringDeploymentGroupsResponse
impl PartialEq for ListMirroringDeploymentGroupsResponse
Sourcefn eq(&self, other: &ListMirroringDeploymentGroupsResponse) -> bool
fn eq(&self, other: &ListMirroringDeploymentGroupsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMirroringDeploymentGroupsResponse