#[non_exhaustive]pub struct ListMirroringDeploymentsResponse {
pub mirroring_deployments: Vec<MirroringDeployment>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ListMirroringDeployments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mirroring_deployments: Vec<MirroringDeployment>The deployments from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListMirroringDeploymentsResponse
impl ListMirroringDeploymentsResponse
pub fn new() -> Self
Sourcepub fn set_mirroring_deployments<T, V>(self, v: T) -> Self
pub fn set_mirroring_deployments<T, V>(self, v: T) -> Self
Sets the value of mirroring_deployments.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringDeployment;
let x = ListMirroringDeploymentsResponse::new()
.set_mirroring_deployments([
MirroringDeployment::default()/* use setters */,
MirroringDeployment::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMirroringDeploymentsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListMirroringDeploymentsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListMirroringDeploymentsResponse
impl Clone for ListMirroringDeploymentsResponse
Sourcefn clone(&self) -> ListMirroringDeploymentsResponse
fn clone(&self) -> ListMirroringDeploymentsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListMirroringDeploymentsResponse
impl Default for ListMirroringDeploymentsResponse
Sourcefn default() -> ListMirroringDeploymentsResponse
fn default() -> ListMirroringDeploymentsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListMirroringDeploymentsResponse
impl PartialEq for ListMirroringDeploymentsResponse
Sourcefn eq(&self, other: &ListMirroringDeploymentsResponse) -> bool
fn eq(&self, other: &ListMirroringDeploymentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMirroringDeploymentsResponse