#[non_exhaustive]pub struct ListMirroringEndpointGroupAssociationsResponse {
pub mirroring_endpoint_group_associations: Vec<MirroringEndpointGroupAssociation>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListMirroringEndpointGroupAssociations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mirroring_endpoint_group_associations: Vec<MirroringEndpointGroupAssociation>The associations from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
Implementations
Sourceimpl ListMirroringEndpointGroupAssociationsResponse
impl ListMirroringEndpointGroupAssociationsResponse
pub fn new() -> Self
Sourcepub fn set_mirroring_endpoint_group_associations<T, V>(self, v: T) -> Self
pub fn set_mirroring_endpoint_group_associations<T, V>(self, v: T) -> Self
Sets the value of mirroring_endpoint_group_associations.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringEndpointGroupAssociation;
let x = ListMirroringEndpointGroupAssociationsResponse::new()
.set_mirroring_endpoint_group_associations([
MirroringEndpointGroupAssociation::default()/* use setters */,
MirroringEndpointGroupAssociation::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMirroringEndpointGroupAssociationsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListMirroringEndpointGroupAssociationsResponse
impl Clone for ListMirroringEndpointGroupAssociationsResponse
Sourcefn clone(&self) -> ListMirroringEndpointGroupAssociationsResponse
fn clone(&self) -> ListMirroringEndpointGroupAssociationsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListMirroringEndpointGroupAssociationsResponse
impl Default for ListMirroringEndpointGroupAssociationsResponse
Sourcefn default() -> ListMirroringEndpointGroupAssociationsResponse
fn default() -> ListMirroringEndpointGroupAssociationsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListMirroringEndpointGroupAssociationsResponse
impl PartialEq for ListMirroringEndpointGroupAssociationsResponse
Sourcefn eq(&self, other: &ListMirroringEndpointGroupAssociationsResponse) -> bool
fn eq(&self, other: &ListMirroringEndpointGroupAssociationsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMirroringEndpointGroupAssociationsResponse