#[non_exhaustive]pub struct ListMirroringEndpointGroupsResponse {
pub mirroring_endpoint_groups: Vec<MirroringEndpointGroup>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListMirroringEndpointGroups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mirroring_endpoint_groups: Vec<MirroringEndpointGroup>The endpoint groups from the specified parent.
next_page_token: StringA token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
See https://google.aip.dev/158 for more details.
Implementations
Sourceimpl ListMirroringEndpointGroupsResponse
impl ListMirroringEndpointGroupsResponse
pub fn new() -> Self
Sourcepub fn set_mirroring_endpoint_groups<T, V>(self, v: T) -> Self
pub fn set_mirroring_endpoint_groups<T, V>(self, v: T) -> Self
Sets the value of mirroring_endpoint_groups.
Example
ⓘ
use google_cloud_networksecurity_v1::model::MirroringEndpointGroup;
let x = ListMirroringEndpointGroupsResponse::new()
.set_mirroring_endpoint_groups([
MirroringEndpointGroup::default()/* use setters */,
MirroringEndpointGroup::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMirroringEndpointGroupsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListMirroringEndpointGroupsResponse
impl Clone for ListMirroringEndpointGroupsResponse
Sourcefn clone(&self) -> ListMirroringEndpointGroupsResponse
fn clone(&self) -> ListMirroringEndpointGroupsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListMirroringEndpointGroupsResponse
impl Default for ListMirroringEndpointGroupsResponse
Sourcefn default() -> ListMirroringEndpointGroupsResponse
fn default() -> ListMirroringEndpointGroupsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListMirroringEndpointGroupsResponse
impl PartialEq for ListMirroringEndpointGroupsResponse
Sourcefn eq(&self, other: &ListMirroringEndpointGroupsResponse) -> bool
fn eq(&self, other: &ListMirroringEndpointGroupsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMirroringEndpointGroupsResponse