#[non_exhaustive]pub struct ListSACAttachmentsResponse {
pub sac_attachments: Vec<SACAttachment>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response for ListSACAttachments method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sac_attachments: Vec<SACAttachment>The list of SACAttachments.
next_page_token: StringA token identifying a page of results the server should return.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListSACAttachmentsResponse
impl ListSACAttachmentsResponse
Sourcepub fn set_sac_attachments<T, V>(self, v: T) -> Self
pub fn set_sac_attachments<T, V>(self, v: T) -> Self
Sets the value of sac_attachments.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SACAttachment;
let x = ListSACAttachmentsResponse::new()
.set_sac_attachments([
SACAttachment::default()/* use setters */,
SACAttachment::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSACAttachmentsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListSACAttachmentsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListSACAttachmentsResponse
impl Clone for ListSACAttachmentsResponse
Sourcefn clone(&self) -> ListSACAttachmentsResponse
fn clone(&self) -> ListSACAttachmentsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSACAttachmentsResponse
impl Debug for ListSACAttachmentsResponse
Sourceimpl Default for ListSACAttachmentsResponse
impl Default for ListSACAttachmentsResponse
Sourcefn default() -> ListSACAttachmentsResponse
fn default() -> ListSACAttachmentsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListSACAttachmentsResponse
impl Message for ListSACAttachmentsResponse
Sourceimpl PartialEq for ListSACAttachmentsResponse
impl PartialEq for ListSACAttachmentsResponse
Sourcefn eq(&self, other: &ListSACAttachmentsResponse) -> bool
fn eq(&self, other: &ListSACAttachmentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSACAttachmentsResponse