#[non_exhaustive]pub struct ListSACRealmsResponse {
pub sac_realms: Vec<SACRealm>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response for ListSACRealms method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sac_realms: Vec<SACRealm>The list of SACRealms.
next_page_token: StringA token identifying a page of results the server should return.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListSACRealmsResponse
impl ListSACRealmsResponse
Sourcepub fn set_sac_realms<T, V>(self, v: T) -> Self
pub fn set_sac_realms<T, V>(self, v: T) -> Self
Sets the value of sac_realms.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SACRealm;
let x = ListSACRealmsResponse::new()
.set_sac_realms([
SACRealm::default()/* use setters */,
SACRealm::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSACRealmsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListSACRealmsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListSACRealmsResponse
impl Clone for ListSACRealmsResponse
Sourcefn clone(&self) -> ListSACRealmsResponse
fn clone(&self) -> ListSACRealmsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSACRealmsResponse
impl Debug for ListSACRealmsResponse
Sourceimpl Default for ListSACRealmsResponse
impl Default for ListSACRealmsResponse
Sourcefn default() -> ListSACRealmsResponse
fn default() -> ListSACRealmsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListSACRealmsResponse
impl Message for ListSACRealmsResponse
Sourceimpl PartialEq for ListSACRealmsResponse
impl PartialEq for ListSACRealmsResponse
Sourcefn eq(&self, other: &ListSACRealmsResponse) -> bool
fn eq(&self, other: &ListSACRealmsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSACRealmsResponse