#[non_exhaustive]pub struct ListSecurityProfileGroupsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request used with the ListSecurityProfileGroups method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project or organization and location from which the
SecurityProfileGroups should be listed, specified in the format
projects|organizations/*/locations/{location}.
page_size: i32Optional. Maximum number of SecurityProfileGroups to return per call.
page_token: StringOptional. The value returned by the last
ListSecurityProfileGroupsResponse Indicates that this is a
continuation of a prior ListSecurityProfileGroups call, and
that the system should return the next page of data.
Implementations
Sourceimpl ListSecurityProfileGroupsRequest
impl ListSecurityProfileGroupsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListSecurityProfileGroupsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSecurityProfileGroupsRequest
impl Clone for ListSecurityProfileGroupsRequest
Sourcefn clone(&self) -> ListSecurityProfileGroupsRequest
fn clone(&self) -> ListSecurityProfileGroupsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListSecurityProfileGroupsRequest
impl Default for ListSecurityProfileGroupsRequest
Sourcefn default() -> ListSecurityProfileGroupsRequest
fn default() -> ListSecurityProfileGroupsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListSecurityProfileGroupsRequest
impl PartialEq for ListSecurityProfileGroupsRequest
Sourcefn eq(&self, other: &ListSecurityProfileGroupsRequest) -> bool
fn eq(&self, other: &ListSecurityProfileGroupsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSecurityProfileGroupsRequest