#[non_exhaustive]pub struct ListSecurityProfileGroupsResponse {
pub security_profile_groups: Vec<SecurityProfileGroup>,
pub next_page_token: String,
/* private fields */
}Expand description
Response returned by the ListSecurityProfileGroups method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.security_profile_groups: Vec<SecurityProfileGroup>List of SecurityProfileGroups resources.
next_page_token: StringIf there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
Implementations
Sourceimpl ListSecurityProfileGroupsResponse
impl ListSecurityProfileGroupsResponse
pub fn new() -> Self
Sourcepub fn set_security_profile_groups<T, V>(self, v: T) -> Self
pub fn set_security_profile_groups<T, V>(self, v: T) -> Self
Sets the value of security_profile_groups.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
let x = ListSecurityProfileGroupsResponse::new()
.set_security_profile_groups([
SecurityProfileGroup::default()/* use setters */,
SecurityProfileGroup::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSecurityProfileGroupsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListSecurityProfileGroupsResponse
impl Clone for ListSecurityProfileGroupsResponse
Sourcefn clone(&self) -> ListSecurityProfileGroupsResponse
fn clone(&self) -> ListSecurityProfileGroupsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListSecurityProfileGroupsResponse
impl Default for ListSecurityProfileGroupsResponse
Sourcefn default() -> ListSecurityProfileGroupsResponse
fn default() -> ListSecurityProfileGroupsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListSecurityProfileGroupsResponse
impl PartialEq for ListSecurityProfileGroupsResponse
Sourcefn eq(&self, other: &ListSecurityProfileGroupsResponse) -> bool
fn eq(&self, other: &ListSecurityProfileGroupsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSecurityProfileGroupsResponse