#[non_exhaustive]pub struct ListSecurityProfilesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request used with the ListSecurityProfiles method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project or organization and location from which the
SecurityProfiles should be listed, specified in the format
projects|organizations/*/locations/{location}.
page_size: i32Optional. Maximum number of SecurityProfiles to return per call.
page_token: StringOptional. The value returned by the last
ListSecurityProfilesResponse Indicates that this is a continuation of a
prior ListSecurityProfiles call, and that the system should return the
next page of data.
Implementations
Sourceimpl ListSecurityProfilesRequest
impl ListSecurityProfilesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListSecurityProfilesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSecurityProfilesRequest
impl Clone for ListSecurityProfilesRequest
Sourcefn clone(&self) -> ListSecurityProfilesRequest
fn clone(&self) -> ListSecurityProfilesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSecurityProfilesRequest
impl Debug for ListSecurityProfilesRequest
Sourceimpl Default for ListSecurityProfilesRequest
impl Default for ListSecurityProfilesRequest
Sourcefn default() -> ListSecurityProfilesRequest
fn default() -> ListSecurityProfilesRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListSecurityProfilesRequest