#[non_exhaustive]pub struct ListSecurityProfilesResponse {
pub security_profiles: Vec<SecurityProfile>,
pub next_page_token: String,
/* private fields */
}Expand description
Response returned by the ListSecurityProfiles method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.security_profiles: Vec<SecurityProfile>List of SecurityProfile resources.
next_page_token: StringIf there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
Implementations
Sourceimpl ListSecurityProfilesResponse
impl ListSecurityProfilesResponse
pub fn new() -> Self
Sourcepub fn set_security_profiles<T, V>(self, v: T) -> Self
pub fn set_security_profiles<T, V>(self, v: T) -> Self
Sets the value of security_profiles.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfile;
let x = ListSecurityProfilesResponse::new()
.set_security_profiles([
SecurityProfile::default()/* use setters */,
SecurityProfile::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSecurityProfilesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListSecurityProfilesResponse
impl Clone for ListSecurityProfilesResponse
Sourcefn clone(&self) -> ListSecurityProfilesResponse
fn clone(&self) -> ListSecurityProfilesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSecurityProfilesResponse
impl Debug for ListSecurityProfilesResponse
Sourceimpl Default for ListSecurityProfilesResponse
impl Default for ListSecurityProfilesResponse
Sourcefn default() -> ListSecurityProfilesResponse
fn default() -> ListSecurityProfilesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListSecurityProfilesResponse
impl PartialEq for ListSecurityProfilesResponse
Sourcefn eq(&self, other: &ListSecurityProfilesResponse) -> bool
fn eq(&self, other: &ListSecurityProfilesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSecurityProfilesResponse