#[non_exhaustive]pub struct ListServerTlsPoliciesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub return_partial_success: bool,
/* private fields */
}Expand description
Request used by the ListServerTlsPolicies method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project and location from which the ServerTlsPolicies should
be listed, specified in the format projects/*/locations/{location}.
page_size: i32Maximum number of ServerTlsPolicies to return per call.
page_token: StringThe value returned by the last ListServerTlsPoliciesResponse
Indicates that this is a continuation of a prior
ListServerTlsPolicies call, and that the system
should return the next page of data.
return_partial_success: boolOptional. Setting this field to true will opt the request into returning
the resources that are reachable, and into including the names of those
that were unreachable in the [ListServerTlsPoliciesResponse.unreachable]
field. This can only be true when reading across collections e.g. when
parent is set to "projects/example/locations/-".
Implementations
Sourceimpl ListServerTlsPoliciesRequest
impl ListServerTlsPoliciesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListServerTlsPoliciesRequest::new().set_page_token("example");Sourcepub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self
pub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self
Sets the value of return_partial_success.
Example
let x = ListServerTlsPoliciesRequest::new().set_return_partial_success(true);Trait Implementations
Sourceimpl Clone for ListServerTlsPoliciesRequest
impl Clone for ListServerTlsPoliciesRequest
Sourcefn clone(&self) -> ListServerTlsPoliciesRequest
fn clone(&self) -> ListServerTlsPoliciesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListServerTlsPoliciesRequest
impl Debug for ListServerTlsPoliciesRequest
Sourceimpl Default for ListServerTlsPoliciesRequest
impl Default for ListServerTlsPoliciesRequest
Sourcefn default() -> ListServerTlsPoliciesRequest
fn default() -> ListServerTlsPoliciesRequest
impl StructuralPartialEq for ListServerTlsPoliciesRequest