#[non_exhaustive]pub struct ListTlsInspectionPoliciesResponse {
pub tls_inspection_policies: Vec<TlsInspectionPolicy>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response returned by the ListTlsInspectionPolicies method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tls_inspection_policies: Vec<TlsInspectionPolicy>List of TlsInspectionPolicies resources.
next_page_token: StringIf there might be more results than those appearing in this response, then ‘next_page_token’ is included. To get the next set of results, call this method again using the value of ‘next_page_token’ as ‘page_token’.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListTlsInspectionPoliciesResponse
impl ListTlsInspectionPoliciesResponse
pub fn new() -> Self
Sourcepub fn set_tls_inspection_policies<T, V>(self, v: T) -> Self
pub fn set_tls_inspection_policies<T, V>(self, v: T) -> Self
Sets the value of tls_inspection_policies.
Example
ⓘ
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
let x = ListTlsInspectionPoliciesResponse::new()
.set_tls_inspection_policies([
TlsInspectionPolicy::default()/* use setters */,
TlsInspectionPolicy::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListTlsInspectionPoliciesResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListTlsInspectionPoliciesResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListTlsInspectionPoliciesResponse
impl Clone for ListTlsInspectionPoliciesResponse
Sourcefn clone(&self) -> ListTlsInspectionPoliciesResponse
fn clone(&self) -> ListTlsInspectionPoliciesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListTlsInspectionPoliciesResponse
impl Default for ListTlsInspectionPoliciesResponse
Sourcefn default() -> ListTlsInspectionPoliciesResponse
fn default() -> ListTlsInspectionPoliciesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListTlsInspectionPoliciesResponse
impl PartialEq for ListTlsInspectionPoliciesResponse
Sourcefn eq(&self, other: &ListTlsInspectionPoliciesResponse) -> bool
fn eq(&self, other: &ListTlsInspectionPoliciesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListTlsInspectionPoliciesResponse