#[non_exhaustive]pub struct ListUrlListsResponse {
pub url_lists: Vec<UrlList>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response returned by the ListUrlLists method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url_lists: Vec<UrlList>List of UrlList resources.
next_page_token: StringIf there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListUrlListsResponse
impl ListUrlListsResponse
pub fn new() -> Self
Sourcepub fn set_url_lists<T, V>(self, v: T) -> Self
pub fn set_url_lists<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListUrlListsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListUrlListsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListUrlListsResponse
impl Clone for ListUrlListsResponse
Sourcefn clone(&self) -> ListUrlListsResponse
fn clone(&self) -> ListUrlListsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListUrlListsResponse
impl Debug for ListUrlListsResponse
Sourceimpl Default for ListUrlListsResponse
impl Default for ListUrlListsResponse
Sourcefn default() -> ListUrlListsResponse
fn default() -> ListUrlListsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListUrlListsResponse
impl Message for ListUrlListsResponse
Sourceimpl PartialEq for ListUrlListsResponse
impl PartialEq for ListUrlListsResponse
impl StructuralPartialEq for ListUrlListsResponse