#[non_exhaustive]pub struct MirroringDeploymentGroup {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub network: String,
pub connected_endpoint_groups: Vec<ConnectedEndpointGroup>,
pub nested_deployments: Vec<Deployment>,
pub state: State,
pub reconciling: bool,
pub description: String,
pub locations: Vec<MirroringLocation>,
/* private fields */
}Expand description
A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. Identifier. The resource name of this deployment group, for
example:
projects/123456789/locations/global/mirroringDeploymentGroups/my-dg.
See https://google.aip.dev/122 for more details.
create_time: Option<Timestamp>Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.
update_time: Option<Timestamp>Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.
labels: HashMap<String, String>Optional. Labels are key/value pairs that help to organize and filter resources.
network: StringRequired. Immutable. The network that will be used for all child
deployments, for example: projects/{project}/global/networks/{network}.
See https://google.aip.dev/124.
connected_endpoint_groups: Vec<ConnectedEndpointGroup>Output only. The list of endpoint groups that are connected to this resource.
nested_deployments: Vec<Deployment>Output only. The list of Mirroring Deployments that belong to this group.
state: StateOutput only. The current state of the deployment group. See https://google.aip.dev/216.
reconciling: boolOutput only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https://google.aip.dev/128.
description: StringOptional. User-provided description of the deployment group. Used as additional context for the deployment group.
locations: Vec<MirroringLocation>Output only. The list of locations where the deployment group is present.
Implementations
Sourceimpl MirroringDeploymentGroup
impl MirroringDeploymentGroup
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = MirroringDeploymentGroup::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = MirroringDeploymentGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MirroringDeploymentGroup::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = MirroringDeploymentGroup::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = MirroringDeploymentGroup::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MirroringDeploymentGroup::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_network<T: Into<String>>(self, v: T) -> Self
pub fn set_network<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_connected_endpoint_groups<T, V>(self, v: T) -> Self
pub fn set_connected_endpoint_groups<T, V>(self, v: T) -> Self
Sets the value of connected_endpoint_groups.
Example
use google_cloud_networksecurity_v1::model::mirroring_deployment_group::ConnectedEndpointGroup;
let x = MirroringDeploymentGroup::new()
.set_connected_endpoint_groups([
ConnectedEndpointGroup::default()/* use setters */,
ConnectedEndpointGroup::default()/* use (different) setters */,
]);Sourcepub fn set_nested_deployments<T, V>(self, v: T) -> Self
👎Deprecated
pub fn set_nested_deployments<T, V>(self, v: T) -> Self
Sets the value of nested_deployments.
Example
use google_cloud_networksecurity_v1::model::mirroring_deployment_group::Deployment;
let x = MirroringDeploymentGroup::new()
.set_nested_deployments([
Deployment::default()/* use setters */,
Deployment::default()/* use (different) setters */,
]);Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_networksecurity_v1::model::mirroring_deployment_group::State;
let x0 = MirroringDeploymentGroup::new().set_state(State::Active);
let x1 = MirroringDeploymentGroup::new().set_state(State::Creating);
let x2 = MirroringDeploymentGroup::new().set_state(State::Deleting);Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sets the value of reconciling.
Example
let x = MirroringDeploymentGroup::new().set_reconciling(true);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = MirroringDeploymentGroup::new().set_description("example");Sourcepub fn set_locations<T, V>(self, v: T) -> Self
pub fn set_locations<T, V>(self, v: T) -> Self