MirroringEndpointGroup

Struct MirroringEndpointGroup 

#[non_exhaustive]
pub struct MirroringEndpointGroup { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub mirroring_deployment_group: String, pub connected_deployment_groups: Vec<ConnectedDeploymentGroup>, pub state: State, pub reconciling: bool, pub type: Type, pub associations: Vec<AssociationDetails>, pub description: String, /* private fields */ }
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create:

  • An association between their network and the endpoint group.
  • A security profile that points to the endpoint group.
  • A mirroring rule that references the security profile (group).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/122 for more details.

create_time: Option<Timestamp>

Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

update_time: Option<Timestamp>

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.

labels: HashMap<String, String>

Optional. Labels are key/value pairs that help to organize and filter resources.

mirroring_deployment_group: String

Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.

connected_deployment_groups: Vec<ConnectedDeploymentGroup>

Output only. List of details about the connected deployment groups to this endpoint group.

state: State

Output only. The current state of the endpoint group. See https://google.aip.dev/216.

reconciling: bool

Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https://google.aip.dev/128.

type: Type

Immutable. The type of the endpoint group. If left unspecified, defaults to DIRECT.

associations: Vec<AssociationDetails>

Output only. List of associations to this endpoint group.

description: String

Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group.

Implementations

Source

impl MirroringEndpointGroup

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = MirroringEndpointGroup::new().set_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroup::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MirroringEndpointGroup::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroup::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroup::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MirroringEndpointGroup::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = MirroringEndpointGroup::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_mirroring_deployment_group<T: Into<String>>(self, v: T) -> Self

Sets the value of mirroring_deployment_group.

Example
let x = MirroringEndpointGroup::new().set_mirroring_deployment_group("example");
pub fn set_connected_deployment_groups<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ConnectedDeploymentGroup>,

Sets the value of connected_deployment_groups.

Example
use google_cloud_networksecurity_v1::model::mirroring_endpoint_group::ConnectedDeploymentGroup;
let x = MirroringEndpointGroup::new()
    .set_connected_deployment_groups([
        ConnectedDeploymentGroup::default()/* use setters */,
        ConnectedDeploymentGroup::default()/* use (different) setters */,
    ]);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_networksecurity_v1::model::mirroring_endpoint_group::State;
let x0 = MirroringEndpointGroup::new().set_state(State::Active);
let x1 = MirroringEndpointGroup::new().set_state(State::Closed);
let x2 = MirroringEndpointGroup::new().set_state(State::Creating);
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = MirroringEndpointGroup::new().set_reconciling(true);
pub fn set_type<T: Into<Type>>(self, v: T) -> Self

Sets the value of r#type.

Example
use google_cloud_networksecurity_v1::model::mirroring_endpoint_group::Type;
let x0 = MirroringEndpointGroup::new().set_type(Type::Direct);
pub fn set_associations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<AssociationDetails>,

Sets the value of associations.

Example
use google_cloud_networksecurity_v1::model::mirroring_endpoint_group::AssociationDetails;
let x = MirroringEndpointGroup::new()
    .set_associations([
        AssociationDetails::default()/* use setters */,
        AssociationDetails::default()/* use (different) setters */,
    ]);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = MirroringEndpointGroup::new().set_description("example");