MirroringEndpointGroupAssociation

Struct MirroringEndpointGroupAssociation 

#[non_exhaustive]
pub struct MirroringEndpointGroupAssociation { pub name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub mirroring_endpoint_group: String, pub network: String, pub locations_details: Vec<LocationDetails>, pub state: State, pub reconciling: bool, pub locations: Vec<MirroringLocation>, /* private fields */ }
An endpoint group association represents a link between a network and an endpoint group in the organization.

Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable mirroring by itself. To enable mirroring, the user must also create a network firewall policy containing mirroring rules and associate it with the network.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. Identifier. The resource name of this endpoint group association, for example: projects/123456789/locations/global/mirroringEndpointGroupAssociations/my-eg-association. See https://google.aip.dev/122 for more details.

create_time: Option<Timestamp>

Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

update_time: Option<Timestamp>

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.

labels: HashMap<String, String>

Optional. Labels are key/value pairs that help to organize and filter resources.

mirroring_endpoint_group: String

Immutable. The endpoint group that this association is connected to, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/124.

network: String

Immutable. The VPC network that is associated. for example: projects/123456789/global/networks/my-network. See https://google.aip.dev/124.

locations_details: Vec<LocationDetails>
👎Deprecated

Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself.

state: State

Output only. Current state of the endpoint group association.

reconciling: bool

Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128.

locations: Vec<MirroringLocation>

Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group.

Implementations

Source

impl MirroringEndpointGroupAssociation

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = MirroringEndpointGroupAssociation::new().set_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroupAssociation::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroupAssociation::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MirroringEndpointGroupAssociation::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroupAssociation::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = MirroringEndpointGroupAssociation::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MirroringEndpointGroupAssociation::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = MirroringEndpointGroupAssociation::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_mirroring_endpoint_group<T: Into<String>>(self, v: T) -> Self

Sets the value of mirroring_endpoint_group.

Example
let x = MirroringEndpointGroupAssociation::new().set_mirroring_endpoint_group("example");
pub fn set_network<T: Into<String>>(self, v: T) -> Self

Sets the value of network.

Example
let x = MirroringEndpointGroupAssociation::new().set_network("example");
pub fn set_locations_details<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<LocationDetails>,

👎Deprecated

Sets the value of locations_details.

Example
use google_cloud_networksecurity_v1::model::mirroring_endpoint_group_association::LocationDetails;
let x = MirroringEndpointGroupAssociation::new()
    .set_locations_details([
        LocationDetails::default()/* use setters */,
        LocationDetails::default()/* use (different) setters */,
    ]);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_networksecurity_v1::model::mirroring_endpoint_group_association::State;
let x0 = MirroringEndpointGroupAssociation::new().set_state(State::Active);
let x1 = MirroringEndpointGroupAssociation::new().set_state(State::Creating);
let x2 = MirroringEndpointGroupAssociation::new().set_state(State::Deleting);
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = MirroringEndpointGroupAssociation::new().set_reconciling(true);
pub fn set_locations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<MirroringLocation>,

Sets the value of locations.

Example
use google_cloud_networksecurity_v1::model::MirroringLocation;
let x = MirroringEndpointGroupAssociation::new()
    .set_locations([
        MirroringLocation::default()/* use setters */,
        MirroringLocation::default()/* use (different) setters */,
    ]);