#[non_exhaustive]pub struct SecurityProfileGroup {
pub name: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub data_path_id: u64,
pub labels: HashMap<String, String>,
pub threat_prevention_profile: String,
pub custom_mirroring_profile: String,
pub custom_intercept_profile: String,
pub url_filtering_profile: String,
/* private fields */
}Expand description
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. Identifier. Name of the SecurityProfileGroup resource. It
matches pattern
projects|organizations/*/locations/{location}/securityProfileGroups/{security_profile_group}.
description: StringOptional. An optional description of the profile group. Max length 2048 characters.
create_time: Option<Timestamp>Output only. Resource creation timestamp.
update_time: Option<Timestamp>Output only. Last resource update timestamp.
etag: StringOutput only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
data_path_id: u64Output only. Identifier used by the data-path. Unique within {container, location}.
labels: HashMap<String, String>Optional. Labels as key value pairs.
threat_prevention_profile: StringOptional. Reference to a SecurityProfile with the ThreatPrevention configuration.
custom_mirroring_profile: StringOptional. Reference to a SecurityProfile with the CustomMirroring configuration.
custom_intercept_profile: StringOptional. Reference to a SecurityProfile with the CustomIntercept configuration.
url_filtering_profile: StringOptional. Reference to a SecurityProfile with the UrlFiltering configuration.
Implementations
Sourceimpl SecurityProfileGroup
impl SecurityProfileGroup
pub fn new() -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = SecurityProfileGroup::new().set_description("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = SecurityProfileGroup::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = SecurityProfileGroup::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_data_path_id<T: Into<u64>>(self, v: T) -> Self
pub fn set_data_path_id<T: Into<u64>>(self, v: T) -> Self
Sets the value of data_path_id.
Example
let x = SecurityProfileGroup::new().set_data_path_id(42_u32);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_threat_prevention_profile<T: Into<String>>(self, v: T) -> Self
pub fn set_threat_prevention_profile<T: Into<String>>(self, v: T) -> Self
Sets the value of threat_prevention_profile.
Example
let x = SecurityProfileGroup::new().set_threat_prevention_profile("example");Sourcepub fn set_custom_mirroring_profile<T: Into<String>>(self, v: T) -> Self
pub fn set_custom_mirroring_profile<T: Into<String>>(self, v: T) -> Self
Sets the value of custom_mirroring_profile.
Example
let x = SecurityProfileGroup::new().set_custom_mirroring_profile("example");Sourcepub fn set_custom_intercept_profile<T: Into<String>>(self, v: T) -> Self
pub fn set_custom_intercept_profile<T: Into<String>>(self, v: T) -> Self
Sets the value of custom_intercept_profile.
Example
let x = SecurityProfileGroup::new().set_custom_intercept_profile("example");Sourcepub fn set_url_filtering_profile<T: Into<String>>(self, v: T) -> Self
pub fn set_url_filtering_profile<T: Into<String>>(self, v: T) -> Self
Sets the value of url_filtering_profile.
Example
let x = SecurityProfileGroup::new().set_url_filtering_profile("example");Trait Implementations
Sourceimpl Clone for SecurityProfileGroup
impl Clone for SecurityProfileGroup
Sourcefn clone(&self) -> SecurityProfileGroup
fn clone(&self) -> SecurityProfileGroup
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more