#[non_exhaustive]pub struct ThreatOverride {
pub threat_id: String,
pub type: ThreatType,
pub action: ThreatAction,
/* private fields */
}Expand description
Defines what action to take for a specific threat_id match.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.threat_id: StringRequired. Vendor-specific ID of a threat to override.
type: ThreatTypeOutput only. Type of the threat (read only).
action: ThreatActionRequired. Threat action override. For some threat types, only a subset of actions applies.
Implementations
Sourceimpl ThreatOverride
impl ThreatOverride
Sourcepub fn set_threat_id<T: Into<String>>(self, v: T) -> Self
pub fn set_threat_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_type<T: Into<ThreatType>>(self, v: T) -> Self
pub fn set_type<T: Into<ThreatType>>(self, v: T) -> Self
Sourcepub fn set_action<T: Into<ThreatAction>>(self, v: T) -> Self
pub fn set_action<T: Into<ThreatAction>>(self, v: T) -> Self