#[non_exhaustive]pub struct ThreatPreventionProfile {
pub severity_overrides: Vec<SeverityOverride>,
pub threat_overrides: Vec<ThreatOverride>,
pub antivirus_overrides: Vec<AntivirusOverride>,
/* private fields */
}Expand description
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.severity_overrides: Vec<SeverityOverride>Optional. Configuration for overriding threats actions by severity match.
threat_overrides: Vec<ThreatOverride>Optional. Configuration for overriding threats actions by threat_id match. If a threat is matched both by configuration provided in severity_overrides and threat_overrides, the threat_overrides action is applied.
antivirus_overrides: Vec<AntivirusOverride>Optional. Configuration for overriding antivirus actions per protocol.
Implementations
Sourceimpl ThreatPreventionProfile
impl ThreatPreventionProfile
pub fn new() -> Self
Sourcepub fn set_severity_overrides<T, V>(self, v: T) -> Self
pub fn set_severity_overrides<T, V>(self, v: T) -> Self
Sets the value of severity_overrides.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SeverityOverride;
let x = ThreatPreventionProfile::new()
.set_severity_overrides([
SeverityOverride::default()/* use setters */,
SeverityOverride::default()/* use (different) setters */,
]);Sourcepub fn set_threat_overrides<T, V>(self, v: T) -> Self
pub fn set_threat_overrides<T, V>(self, v: T) -> Self
Sets the value of threat_overrides.
Example
ⓘ
use google_cloud_networksecurity_v1::model::ThreatOverride;
let x = ThreatPreventionProfile::new()
.set_threat_overrides([
ThreatOverride::default()/* use setters */,
ThreatOverride::default()/* use (different) setters */,
]);Sourcepub fn set_antivirus_overrides<T, V>(self, v: T) -> Self
pub fn set_antivirus_overrides<T, V>(self, v: T) -> Self
Sets the value of antivirus_overrides.
Example
ⓘ
use google_cloud_networksecurity_v1::model::AntivirusOverride;
let x = ThreatPreventionProfile::new()
.set_antivirus_overrides([
AntivirusOverride::default()/* use setters */,
AntivirusOverride::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ThreatPreventionProfile
impl Clone for ThreatPreventionProfile
Sourcefn clone(&self) -> ThreatPreventionProfile
fn clone(&self) -> ThreatPreventionProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreatPreventionProfile
impl Debug for ThreatPreventionProfile
Sourceimpl Default for ThreatPreventionProfile
impl Default for ThreatPreventionProfile
Sourcefn default() -> ThreatPreventionProfile
fn default() -> ThreatPreventionProfile
Returns the “default value” for a type. Read more
Sourceimpl Message for ThreatPreventionProfile
impl Message for ThreatPreventionProfile
Sourceimpl PartialEq for ThreatPreventionProfile
impl PartialEq for ThreatPreventionProfile
impl StructuralPartialEq for ThreatPreventionProfile