#[non_exhaustive]pub struct UpdateBackendAuthenticationConfigRequest {
pub update_mask: Option<FieldMask>,
pub backend_authentication_config: Option<BackendAuthenticationConfig>,
/* private fields */
}Expand description
Request used by UpdateBackendAuthenticationConfig method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the BackendAuthenticationConfig resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
backend_authentication_config: Option<BackendAuthenticationConfig>Required. Updated BackendAuthenticationConfig resource.
Implementations
Sourceimpl UpdateBackendAuthenticationConfigRequest
impl UpdateBackendAuthenticationConfigRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateBackendAuthenticationConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateBackendAuthenticationConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateBackendAuthenticationConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_backend_authentication_config<T>(self, v: T) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
pub fn set_backend_authentication_config<T>(self, v: T) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
Sets the value of backend_authentication_config.
Example
ⓘ
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
let x = UpdateBackendAuthenticationConfigRequest::new().set_backend_authentication_config(BackendAuthenticationConfig::default()/* use setters */);Sourcepub fn set_or_clear_backend_authentication_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
pub fn set_or_clear_backend_authentication_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackendAuthenticationConfig>,
Sets or clears the value of backend_authentication_config.
Example
ⓘ
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
let x = UpdateBackendAuthenticationConfigRequest::new().set_or_clear_backend_authentication_config(Some(BackendAuthenticationConfig::default()/* use setters */));
let x = UpdateBackendAuthenticationConfigRequest::new().set_or_clear_backend_authentication_config(None::<BackendAuthenticationConfig>);Trait Implementations
Sourceimpl Clone for UpdateBackendAuthenticationConfigRequest
impl Clone for UpdateBackendAuthenticationConfigRequest
Sourcefn clone(&self) -> UpdateBackendAuthenticationConfigRequest
fn clone(&self) -> UpdateBackendAuthenticationConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateBackendAuthenticationConfigRequest
impl Default for UpdateBackendAuthenticationConfigRequest
Sourcefn default() -> UpdateBackendAuthenticationConfigRequest
fn default() -> UpdateBackendAuthenticationConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateBackendAuthenticationConfigRequest
impl PartialEq for UpdateBackendAuthenticationConfigRequest
Sourcefn eq(&self, other: &UpdateBackendAuthenticationConfigRequest) -> bool
fn eq(&self, other: &UpdateBackendAuthenticationConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateBackendAuthenticationConfigRequest