#[non_exhaustive]pub struct UpdateDnsThreatDetectorRequest {
pub update_mask: Option<FieldMask>,
pub dns_threat_detector: Option<DnsThreatDetector>,
/* private fields */
}Expand description
The message for updating a DnsThreatDetector.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. The field mask is used to specify the fields to be overwritten in the DnsThreatDetector resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the mask is not provided then all fields present in the request will be overwritten.
dns_threat_detector: Option<DnsThreatDetector>Required. The DnsThreatDetector resource being updated.
Implementations
Sourceimpl UpdateDnsThreatDetectorRequest
impl UpdateDnsThreatDetectorRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateDnsThreatDetectorRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateDnsThreatDetectorRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateDnsThreatDetectorRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_dns_threat_detector<T>(self, v: T) -> Selfwhere
T: Into<DnsThreatDetector>,
pub fn set_dns_threat_detector<T>(self, v: T) -> Selfwhere
T: Into<DnsThreatDetector>,
Sets the value of dns_threat_detector.
Example
ⓘ
use google_cloud_networksecurity_v1::model::DnsThreatDetector;
let x = UpdateDnsThreatDetectorRequest::new().set_dns_threat_detector(DnsThreatDetector::default()/* use setters */);Sourcepub fn set_or_clear_dns_threat_detector<T>(self, v: Option<T>) -> Selfwhere
T: Into<DnsThreatDetector>,
pub fn set_or_clear_dns_threat_detector<T>(self, v: Option<T>) -> Selfwhere
T: Into<DnsThreatDetector>,
Sets or clears the value of dns_threat_detector.
Example
ⓘ
use google_cloud_networksecurity_v1::model::DnsThreatDetector;
let x = UpdateDnsThreatDetectorRequest::new().set_or_clear_dns_threat_detector(Some(DnsThreatDetector::default()/* use setters */));
let x = UpdateDnsThreatDetectorRequest::new().set_or_clear_dns_threat_detector(None::<DnsThreatDetector>);Trait Implementations
Sourceimpl Clone for UpdateDnsThreatDetectorRequest
impl Clone for UpdateDnsThreatDetectorRequest
Sourcefn clone(&self) -> UpdateDnsThreatDetectorRequest
fn clone(&self) -> UpdateDnsThreatDetectorRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateDnsThreatDetectorRequest
impl Default for UpdateDnsThreatDetectorRequest
Sourcefn default() -> UpdateDnsThreatDetectorRequest
fn default() -> UpdateDnsThreatDetectorRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateDnsThreatDetectorRequest
impl PartialEq for UpdateDnsThreatDetectorRequest
Sourcefn eq(&self, other: &UpdateDnsThreatDetectorRequest) -> bool
fn eq(&self, other: &UpdateDnsThreatDetectorRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateDnsThreatDetectorRequest