#[non_exhaustive]pub struct UpdateGatewaySecurityPolicyRequest {
pub update_mask: Option<FieldMask>,
pub gateway_security_policy: Option<GatewaySecurityPolicy>,
/* private fields */
}Expand description
Request used by the UpdateGatewaySecurityPolicy method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the GatewaySecurityPolicy resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
gateway_security_policy: Option<GatewaySecurityPolicy>Required. Updated GatewaySecurityPolicy resource.
Implementations
Sourceimpl UpdateGatewaySecurityPolicyRequest
impl UpdateGatewaySecurityPolicyRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateGatewaySecurityPolicyRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateGatewaySecurityPolicyRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateGatewaySecurityPolicyRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_gateway_security_policy<T>(self, v: T) -> Selfwhere
T: Into<GatewaySecurityPolicy>,
pub fn set_gateway_security_policy<T>(self, v: T) -> Selfwhere
T: Into<GatewaySecurityPolicy>,
Sets the value of gateway_security_policy.
Example
ⓘ
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicy;
let x = UpdateGatewaySecurityPolicyRequest::new().set_gateway_security_policy(GatewaySecurityPolicy::default()/* use setters */);Sourcepub fn set_or_clear_gateway_security_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<GatewaySecurityPolicy>,
pub fn set_or_clear_gateway_security_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<GatewaySecurityPolicy>,
Sets or clears the value of gateway_security_policy.
Example
ⓘ
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicy;
let x = UpdateGatewaySecurityPolicyRequest::new().set_or_clear_gateway_security_policy(Some(GatewaySecurityPolicy::default()/* use setters */));
let x = UpdateGatewaySecurityPolicyRequest::new().set_or_clear_gateway_security_policy(None::<GatewaySecurityPolicy>);Trait Implementations
Sourceimpl Clone for UpdateGatewaySecurityPolicyRequest
impl Clone for UpdateGatewaySecurityPolicyRequest
Sourcefn clone(&self) -> UpdateGatewaySecurityPolicyRequest
fn clone(&self) -> UpdateGatewaySecurityPolicyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateGatewaySecurityPolicyRequest
impl Default for UpdateGatewaySecurityPolicyRequest
Sourcefn default() -> UpdateGatewaySecurityPolicyRequest
fn default() -> UpdateGatewaySecurityPolicyRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateGatewaySecurityPolicyRequest
impl PartialEq for UpdateGatewaySecurityPolicyRequest
Sourcefn eq(&self, other: &UpdateGatewaySecurityPolicyRequest) -> bool
fn eq(&self, other: &UpdateGatewaySecurityPolicyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateGatewaySecurityPolicyRequest