#[non_exhaustive]pub struct UpdateGatewaySecurityPolicyRuleRequest {
pub update_mask: Option<FieldMask>,
pub gateway_security_policy_rule: Option<GatewaySecurityPolicyRule>,
/* private fields */
}Expand description
Request used by the UpdateGatewaySecurityPolicyRule method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the GatewaySecurityPolicy resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
gateway_security_policy_rule: Option<GatewaySecurityPolicyRule>Required. Updated GatewaySecurityPolicyRule resource.
Implementations
Sourceimpl UpdateGatewaySecurityPolicyRuleRequest
impl UpdateGatewaySecurityPolicyRuleRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateGatewaySecurityPolicyRuleRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateGatewaySecurityPolicyRuleRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateGatewaySecurityPolicyRuleRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_gateway_security_policy_rule<T>(self, v: T) -> Selfwhere
T: Into<GatewaySecurityPolicyRule>,
pub fn set_gateway_security_policy_rule<T>(self, v: T) -> Selfwhere
T: Into<GatewaySecurityPolicyRule>,
Sets the value of gateway_security_policy_rule.
Example
ⓘ
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicyRule;
let x = UpdateGatewaySecurityPolicyRuleRequest::new().set_gateway_security_policy_rule(GatewaySecurityPolicyRule::default()/* use setters */);Sourcepub fn set_or_clear_gateway_security_policy_rule<T>(self, v: Option<T>) -> Selfwhere
T: Into<GatewaySecurityPolicyRule>,
pub fn set_or_clear_gateway_security_policy_rule<T>(self, v: Option<T>) -> Selfwhere
T: Into<GatewaySecurityPolicyRule>,
Sets or clears the value of gateway_security_policy_rule.
Example
ⓘ
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicyRule;
let x = UpdateGatewaySecurityPolicyRuleRequest::new().set_or_clear_gateway_security_policy_rule(Some(GatewaySecurityPolicyRule::default()/* use setters */));
let x = UpdateGatewaySecurityPolicyRuleRequest::new().set_or_clear_gateway_security_policy_rule(None::<GatewaySecurityPolicyRule>);Trait Implementations
Sourceimpl Clone for UpdateGatewaySecurityPolicyRuleRequest
impl Clone for UpdateGatewaySecurityPolicyRuleRequest
Sourcefn clone(&self) -> UpdateGatewaySecurityPolicyRuleRequest
fn clone(&self) -> UpdateGatewaySecurityPolicyRuleRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateGatewaySecurityPolicyRuleRequest
impl Default for UpdateGatewaySecurityPolicyRuleRequest
Sourcefn default() -> UpdateGatewaySecurityPolicyRuleRequest
fn default() -> UpdateGatewaySecurityPolicyRuleRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateGatewaySecurityPolicyRuleRequest
impl PartialEq for UpdateGatewaySecurityPolicyRuleRequest
Sourcefn eq(&self, other: &UpdateGatewaySecurityPolicyRuleRequest) -> bool
fn eq(&self, other: &UpdateGatewaySecurityPolicyRuleRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateGatewaySecurityPolicyRuleRequest