#[non_exhaustive]pub struct UpdateSecurityProfileGroupRequest {
pub update_mask: Option<FieldMask>,
pub security_profile_group: Option<SecurityProfileGroup>,
/* private fields */
}Expand description
Request used by the UpdateSecurityProfileGroup method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the SecurityProfileGroup resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask.
security_profile_group: Option<SecurityProfileGroup>Required. Updated SecurityProfileGroup resource.
Implementations
Sourceimpl UpdateSecurityProfileGroupRequest
impl UpdateSecurityProfileGroupRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateSecurityProfileGroupRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateSecurityProfileGroupRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateSecurityProfileGroupRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_security_profile_group<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfileGroup>,
pub fn set_security_profile_group<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfileGroup>,
Sets the value of security_profile_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
let x = UpdateSecurityProfileGroupRequest::new().set_security_profile_group(SecurityProfileGroup::default()/* use setters */);Sourcepub fn set_or_clear_security_profile_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfileGroup>,
pub fn set_or_clear_security_profile_group<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfileGroup>,
Sets or clears the value of security_profile_group.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfileGroup;
let x = UpdateSecurityProfileGroupRequest::new().set_or_clear_security_profile_group(Some(SecurityProfileGroup::default()/* use setters */));
let x = UpdateSecurityProfileGroupRequest::new().set_or_clear_security_profile_group(None::<SecurityProfileGroup>);Trait Implementations
Sourceimpl Clone for UpdateSecurityProfileGroupRequest
impl Clone for UpdateSecurityProfileGroupRequest
Sourcefn clone(&self) -> UpdateSecurityProfileGroupRequest
fn clone(&self) -> UpdateSecurityProfileGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateSecurityProfileGroupRequest
impl Default for UpdateSecurityProfileGroupRequest
Sourcefn default() -> UpdateSecurityProfileGroupRequest
fn default() -> UpdateSecurityProfileGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateSecurityProfileGroupRequest
impl PartialEq for UpdateSecurityProfileGroupRequest
Sourcefn eq(&self, other: &UpdateSecurityProfileGroupRequest) -> bool
fn eq(&self, other: &UpdateSecurityProfileGroupRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateSecurityProfileGroupRequest