#[non_exhaustive]pub struct UpdateSecurityProfileRequest {
pub update_mask: Option<FieldMask>,
pub security_profile: Option<SecurityProfile>,
/* private fields */
}Expand description
Request used by the UpdateSecurityProfile method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the SecurityProfile resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask.
security_profile: Option<SecurityProfile>Required. Updated SecurityProfile resource.
Implementations
Sourceimpl UpdateSecurityProfileRequest
impl UpdateSecurityProfileRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateSecurityProfileRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateSecurityProfileRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateSecurityProfileRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_security_profile<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfile>,
pub fn set_security_profile<T>(self, v: T) -> Selfwhere
T: Into<SecurityProfile>,
Sets the value of security_profile.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfile;
let x = UpdateSecurityProfileRequest::new().set_security_profile(SecurityProfile::default()/* use setters */);Sourcepub fn set_or_clear_security_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfile>,
pub fn set_or_clear_security_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityProfile>,
Sets or clears the value of security_profile.
Example
ⓘ
use google_cloud_networksecurity_v1::model::SecurityProfile;
let x = UpdateSecurityProfileRequest::new().set_or_clear_security_profile(Some(SecurityProfile::default()/* use setters */));
let x = UpdateSecurityProfileRequest::new().set_or_clear_security_profile(None::<SecurityProfile>);Trait Implementations
Sourceimpl Clone for UpdateSecurityProfileRequest
impl Clone for UpdateSecurityProfileRequest
Sourcefn clone(&self) -> UpdateSecurityProfileRequest
fn clone(&self) -> UpdateSecurityProfileRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateSecurityProfileRequest
impl Debug for UpdateSecurityProfileRequest
Sourceimpl Default for UpdateSecurityProfileRequest
impl Default for UpdateSecurityProfileRequest
Sourcefn default() -> UpdateSecurityProfileRequest
fn default() -> UpdateSecurityProfileRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateSecurityProfileRequest
impl PartialEq for UpdateSecurityProfileRequest
Sourcefn eq(&self, other: &UpdateSecurityProfileRequest) -> bool
fn eq(&self, other: &UpdateSecurityProfileRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateSecurityProfileRequest