#[non_exhaustive]pub struct UpdateTlsInspectionPolicyRequest {
pub update_mask: Option<FieldMask>,
pub tls_inspection_policy: Option<TlsInspectionPolicy>,
/* private fields */
}Expand description
Request used by the UpdateTlsInspectionPolicy method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the TlsInspectionPolicy resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
tls_inspection_policy: Option<TlsInspectionPolicy>Required. Updated TlsInspectionPolicy resource.
Implementations
Sourceimpl UpdateTlsInspectionPolicyRequest
impl UpdateTlsInspectionPolicyRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateTlsInspectionPolicyRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateTlsInspectionPolicyRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateTlsInspectionPolicyRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_tls_inspection_policy<T>(self, v: T) -> Selfwhere
T: Into<TlsInspectionPolicy>,
pub fn set_tls_inspection_policy<T>(self, v: T) -> Selfwhere
T: Into<TlsInspectionPolicy>,
Sets the value of tls_inspection_policy.
Example
ⓘ
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
let x = UpdateTlsInspectionPolicyRequest::new().set_tls_inspection_policy(TlsInspectionPolicy::default()/* use setters */);Sourcepub fn set_or_clear_tls_inspection_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<TlsInspectionPolicy>,
pub fn set_or_clear_tls_inspection_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<TlsInspectionPolicy>,
Sets or clears the value of tls_inspection_policy.
Example
ⓘ
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
let x = UpdateTlsInspectionPolicyRequest::new().set_or_clear_tls_inspection_policy(Some(TlsInspectionPolicy::default()/* use setters */));
let x = UpdateTlsInspectionPolicyRequest::new().set_or_clear_tls_inspection_policy(None::<TlsInspectionPolicy>);Trait Implementations
Sourceimpl Clone for UpdateTlsInspectionPolicyRequest
impl Clone for UpdateTlsInspectionPolicyRequest
Sourcefn clone(&self) -> UpdateTlsInspectionPolicyRequest
fn clone(&self) -> UpdateTlsInspectionPolicyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateTlsInspectionPolicyRequest
impl Default for UpdateTlsInspectionPolicyRequest
Sourcefn default() -> UpdateTlsInspectionPolicyRequest
fn default() -> UpdateTlsInspectionPolicyRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateTlsInspectionPolicyRequest
impl PartialEq for UpdateTlsInspectionPolicyRequest
Sourcefn eq(&self, other: &UpdateTlsInspectionPolicyRequest) -> bool
fn eq(&self, other: &UpdateTlsInspectionPolicyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateTlsInspectionPolicyRequest