#[non_exhaustive]pub struct ValidationCA {
pub type: Option<Type>,
/* private fields */
}Expand description
Specification of ValidationCA. Defines the mechanism to obtain the Certificate Authority certificate to validate the peer certificate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<Type>The type of certificate provider which provides the CA certificate.
Implementations
Sourceimpl ValidationCA
impl ValidationCA
Sourcepub fn set_type<T: Into<Option<Type>>>(self, v: T) -> Self
pub fn set_type<T: Into<Option<Type>>>(self, v: T) -> Self
Sets the value of r#type.
Note that all the setters affecting r#type are mutually
exclusive.
Example
use google_cloud_networksecurity_v1::model::GrpcEndpoint;
let x = ValidationCA::new().set_type(Some(
google_cloud_networksecurity_v1::model::validation_ca::Type::GrpcEndpoint(GrpcEndpoint::default().into())));Sourcepub fn grpc_endpoint(&self) -> Option<&Box<GrpcEndpoint>>
pub fn grpc_endpoint(&self) -> Option<&Box<GrpcEndpoint>>
The value of [r#type][crate::model::ValidationCA::r#type]
if it holds a GrpcEndpoint, None if the field is not set or
holds a different branch.
Sourcepub fn set_grpc_endpoint<T: Into<Box<GrpcEndpoint>>>(self, v: T) -> Self
pub fn set_grpc_endpoint<T: Into<Box<GrpcEndpoint>>>(self, v: T) -> Self
Sets the value of [r#type][crate::model::ValidationCA::r#type]
to hold a GrpcEndpoint.
Note that all the setters affecting r#type are
mutually exclusive.
Example
use google_cloud_networksecurity_v1::model::GrpcEndpoint;
let x = ValidationCA::new().set_grpc_endpoint(GrpcEndpoint::default()/* use setters */);
assert!(x.grpc_endpoint().is_some());
assert!(x.certificate_provider_instance().is_none());Sourcepub fn certificate_provider_instance(
&self,
) -> Option<&Box<CertificateProviderInstance>>
pub fn certificate_provider_instance( &self, ) -> Option<&Box<CertificateProviderInstance>>
The value of [r#type][crate::model::ValidationCA::r#type]
if it holds a CertificateProviderInstance, None if the field is not set or
holds a different branch.
Sourcepub fn set_certificate_provider_instance<T: Into<Box<CertificateProviderInstance>>>(
self,
v: T,
) -> Self
pub fn set_certificate_provider_instance<T: Into<Box<CertificateProviderInstance>>>( self, v: T, ) -> Self
Sets the value of [r#type][crate::model::ValidationCA::r#type]
to hold a CertificateProviderInstance.
Note that all the setters affecting r#type are
mutually exclusive.
Example
use google_cloud_networksecurity_v1::model::CertificateProviderInstance;
let x = ValidationCA::new().set_certificate_provider_instance(CertificateProviderInstance::default()/* use setters */);
assert!(x.certificate_provider_instance().is_some());
assert!(x.grpc_endpoint().is_none());Trait Implementations
Sourceimpl Clone for ValidationCA
impl Clone for ValidationCA
Sourcefn clone(&self) -> ValidationCA
fn clone(&self) -> ValidationCA
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ValidationCA
impl Debug for ValidationCA
Sourceimpl Default for ValidationCA
impl Default for ValidationCA
Sourcefn default() -> ValidationCA
fn default() -> ValidationCA
Sourceimpl Message for ValidationCA
impl Message for ValidationCA
Sourceimpl PartialEq for ValidationCA
impl PartialEq for ValidationCA
impl StructuralPartialEq for ValidationCA