pub struct Intercept { /* private fields */ }Expand description
Implements a client for the Network Security API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Intercept::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_intercept_endpoint_groups()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for Third-Party Packet Intercept (TPPI). TPPI is the “in-band” flavor of the Network Security Integrations product.
Configuration
To configure Intercept use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://networksecurity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Intercept holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Intercept in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Intercept
impl Intercept
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Intercept.
let client = Intercept::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Intercept + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Intercept + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_intercept_endpoint_groups(&self) -> ListInterceptEndpointGroups
pub fn list_intercept_endpoint_groups(&self) -> ListInterceptEndpointGroups
Lists endpoint groups in a given project and location. See https://google.aip.dev/132.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let mut list = client.list_intercept_endpoint_groups()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_intercept_endpoint_group(&self) -> GetInterceptEndpointGroup
pub fn get_intercept_endpoint_group(&self) -> GetInterceptEndpointGroup
Gets a specific endpoint group. See https://google.aip.dev/131.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.get_intercept_endpoint_group()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_intercept_endpoint_group(&self) -> CreateInterceptEndpointGroup
pub fn create_intercept_endpoint_group(&self) -> CreateInterceptEndpointGroup
Creates an endpoint group in a given project and location. See https://google.aip.dev/133.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::InterceptEndpointGroup;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let response = client.create_intercept_endpoint_group()
.set_parent(parent)
.set_intercept_endpoint_group(
InterceptEndpointGroup::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_intercept_endpoint_group(&self) -> UpdateInterceptEndpointGroup
pub fn update_intercept_endpoint_group(&self) -> UpdateInterceptEndpointGroup
Updates an endpoint group. See https://google.aip.dev/134.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::InterceptEndpointGroup;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.update_intercept_endpoint_group()
.set_intercept_endpoint_group(
InterceptEndpointGroup::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_intercept_endpoint_group(&self) -> DeleteInterceptEndpointGroup
pub fn delete_intercept_endpoint_group(&self) -> DeleteInterceptEndpointGroup
Deletes an endpoint group. See https://google.aip.dev/135.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
client.delete_intercept_endpoint_group()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_intercept_endpoint_group_associations(
&self,
) -> ListInterceptEndpointGroupAssociations
pub fn list_intercept_endpoint_group_associations( &self, ) -> ListInterceptEndpointGroupAssociations
Lists associations in a given project and location. See https://google.aip.dev/132.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let mut list = client.list_intercept_endpoint_group_associations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_intercept_endpoint_group_association(
&self,
) -> GetInterceptEndpointGroupAssociation
pub fn get_intercept_endpoint_group_association( &self, ) -> GetInterceptEndpointGroupAssociation
Gets a specific association. See https://google.aip.dev/131.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.get_intercept_endpoint_group_association()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_intercept_endpoint_group_association(
&self,
) -> CreateInterceptEndpointGroupAssociation
pub fn create_intercept_endpoint_group_association( &self, ) -> CreateInterceptEndpointGroupAssociation
Creates an association in a given project and location. See https://google.aip.dev/133.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::InterceptEndpointGroupAssociation;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let response = client.create_intercept_endpoint_group_association()
.set_parent(parent)
.set_intercept_endpoint_group_association(
InterceptEndpointGroupAssociation::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_intercept_endpoint_group_association(
&self,
) -> UpdateInterceptEndpointGroupAssociation
pub fn update_intercept_endpoint_group_association( &self, ) -> UpdateInterceptEndpointGroupAssociation
Updates an association. See https://google.aip.dev/134.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::InterceptEndpointGroupAssociation;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.update_intercept_endpoint_group_association()
.set_intercept_endpoint_group_association(
InterceptEndpointGroupAssociation::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_intercept_endpoint_group_association(
&self,
) -> DeleteInterceptEndpointGroupAssociation
pub fn delete_intercept_endpoint_group_association( &self, ) -> DeleteInterceptEndpointGroupAssociation
Deletes an association. See https://google.aip.dev/135.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
client.delete_intercept_endpoint_group_association()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_intercept_deployment_groups(&self) -> ListInterceptDeploymentGroups
pub fn list_intercept_deployment_groups(&self) -> ListInterceptDeploymentGroups
Lists deployment groups in a given project and location. See https://google.aip.dev/132.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let mut list = client.list_intercept_deployment_groups()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_intercept_deployment_group(&self) -> GetInterceptDeploymentGroup
pub fn get_intercept_deployment_group(&self) -> GetInterceptDeploymentGroup
Gets a specific deployment group. See https://google.aip.dev/131.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.get_intercept_deployment_group()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_intercept_deployment_group(
&self,
) -> CreateInterceptDeploymentGroup
pub fn create_intercept_deployment_group( &self, ) -> CreateInterceptDeploymentGroup
Creates a deployment group in a given project and location. See https://google.aip.dev/133.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::InterceptDeploymentGroup;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let response = client.create_intercept_deployment_group()
.set_parent(parent)
.set_intercept_deployment_group(
InterceptDeploymentGroup::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_intercept_deployment_group(
&self,
) -> UpdateInterceptDeploymentGroup
pub fn update_intercept_deployment_group( &self, ) -> UpdateInterceptDeploymentGroup
Updates a deployment group. See https://google.aip.dev/134.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::InterceptDeploymentGroup;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.update_intercept_deployment_group()
.set_intercept_deployment_group(
InterceptDeploymentGroup::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_intercept_deployment_group(
&self,
) -> DeleteInterceptDeploymentGroup
pub fn delete_intercept_deployment_group( &self, ) -> DeleteInterceptDeploymentGroup
Deletes a deployment group. See https://google.aip.dev/135.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
client.delete_intercept_deployment_group()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_intercept_deployments(&self) -> ListInterceptDeployments
pub fn list_intercept_deployments(&self) -> ListInterceptDeployments
Lists deployments in a given project and location. See https://google.aip.dev/132.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let mut list = client.list_intercept_deployments()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_intercept_deployment(&self) -> GetInterceptDeployment
pub fn get_intercept_deployment(&self) -> GetInterceptDeployment
Gets a specific deployment. See https://google.aip.dev/131.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.get_intercept_deployment()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_intercept_deployment(&self) -> CreateInterceptDeployment
pub fn create_intercept_deployment(&self) -> CreateInterceptDeployment
Creates a deployment in a given project and location. See https://google.aip.dev/133.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::InterceptDeployment;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, parent: &str
) -> Result<()> {
let response = client.create_intercept_deployment()
.set_parent(parent)
.set_intercept_deployment(
InterceptDeployment::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_intercept_deployment(&self) -> UpdateInterceptDeployment
pub fn update_intercept_deployment(&self) -> UpdateInterceptDeployment
Updates a deployment. See https://google.aip.dev/134.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::InterceptDeployment;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
let response = client.update_intercept_deployment()
.set_intercept_deployment(
InterceptDeployment::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_intercept_deployment(&self) -> DeleteInterceptDeployment
pub fn delete_intercept_deployment(&self) -> DeleteInterceptDeployment
Deletes a deployment. See https://google.aip.dev/135.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept, name: &str
) -> Result<()> {
client.delete_intercept_deployment()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &Intercept
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}