pub struct NetworkSecurity { /* private fields */ }Expand description
Implements a client for the Network Security API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
parent: &str,
) -> anyhow::Result<()> {
let client = NetworkSecurity::builder().build().await?;
let mut list = client.list_authorization_policies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Network Security API provides resources to configure authentication and authorization policies. Refer to per API resource documentation for more information.
Configuration
To configure NetworkSecurity use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://networksecurity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
NetworkSecurity holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap NetworkSecurity in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl NetworkSecurity
impl NetworkSecurity
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for NetworkSecurity.
let client = NetworkSecurity::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: NetworkSecurity + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: NetworkSecurity + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Lists AuthorizationPolicies in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_authorization_policies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Gets details of a single AuthorizationPolicy.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, authorization_policy_id: &str
) -> Result<()> {
let response = client.get_authorization_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/authorizationPolicies/{authorization_policy_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Creates a new AuthorizationPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::AuthorizationPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_authorization_policy()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_authorization_policy(
AuthorizationPolicy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Updates the parameters of a single AuthorizationPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::AuthorizationPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, authorization_policy_id: &str
) -> Result<()> {
let response = client.update_authorization_policy()
.set_authorization_policy(
AuthorizationPolicy::new().set_name(format!("projects/{project_id}/locations/{location_id}/authorizationPolicies/{authorization_policy_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Deletes a single AuthorizationPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, authorization_policy_id: &str
) -> Result<()> {
client.delete_authorization_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/authorizationPolicies/{authorization_policy_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_backend_authentication_configs(
&self,
) -> ListBackendAuthenticationConfigs
pub fn list_backend_authentication_configs( &self, ) -> ListBackendAuthenticationConfigs
Lists BackendAuthenticationConfigs in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_backend_authentication_configs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_backend_authentication_config(
&self,
) -> GetBackendAuthenticationConfig
pub fn get_backend_authentication_config( &self, ) -> GetBackendAuthenticationConfig
Gets details of a single BackendAuthenticationConfig to BackendAuthenticationConfig.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, backend_authentication_config_id: &str
) -> Result<()> {
let response = client.get_backend_authentication_config()
.set_name(format!("projects/{project_id}/locations/{location_id}/backendAuthenticationConfigs/{backend_authentication_config_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_backend_authentication_config(
&self,
) -> CreateBackendAuthenticationConfig
pub fn create_backend_authentication_config( &self, ) -> CreateBackendAuthenticationConfig
Creates a new BackendAuthenticationConfig in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_backend_authentication_config()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_backend_authentication_config(
BackendAuthenticationConfig::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_backend_authentication_config(
&self,
) -> UpdateBackendAuthenticationConfig
pub fn update_backend_authentication_config( &self, ) -> UpdateBackendAuthenticationConfig
Updates the parameters of a single BackendAuthenticationConfig to BackendAuthenticationConfig.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::BackendAuthenticationConfig;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, backend_authentication_config_id: &str
) -> Result<()> {
let response = client.update_backend_authentication_config()
.set_backend_authentication_config(
BackendAuthenticationConfig::new().set_name(format!("projects/{project_id}/locations/{location_id}/backendAuthenticationConfigs/{backend_authentication_config_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_backend_authentication_config(
&self,
) -> DeleteBackendAuthenticationConfig
pub fn delete_backend_authentication_config( &self, ) -> DeleteBackendAuthenticationConfig
Deletes a single BackendAuthenticationConfig to BackendAuthenticationConfig.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, backend_authentication_config_id: &str
) -> Result<()> {
client.delete_backend_authentication_config()
.set_name(format!("projects/{project_id}/locations/{location_id}/backendAuthenticationConfigs/{backend_authentication_config_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_server_tls_policies(&self) -> ListServerTlsPolicies
pub fn list_server_tls_policies(&self) -> ListServerTlsPolicies
Lists ServerTlsPolicies in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_server_tls_policies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_server_tls_policy(&self) -> GetServerTlsPolicy
pub fn get_server_tls_policy(&self) -> GetServerTlsPolicy
Gets details of a single ServerTlsPolicy.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, server_tls_policy_id: &str
) -> Result<()> {
let response = client.get_server_tls_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/serverTlsPolicies/{server_tls_policy_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_server_tls_policy(&self) -> CreateServerTlsPolicy
pub fn create_server_tls_policy(&self) -> CreateServerTlsPolicy
Creates a new ServerTlsPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::ServerTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_server_tls_policy()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_server_tls_policy(
ServerTlsPolicy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_server_tls_policy(&self) -> UpdateServerTlsPolicy
pub fn update_server_tls_policy(&self) -> UpdateServerTlsPolicy
Updates the parameters of a single ServerTlsPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::ServerTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, server_tls_policy_id: &str
) -> Result<()> {
let response = client.update_server_tls_policy()
.set_server_tls_policy(
ServerTlsPolicy::new().set_name(format!("projects/{project_id}/locations/{location_id}/serverTlsPolicies/{server_tls_policy_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_server_tls_policy(&self) -> DeleteServerTlsPolicy
pub fn delete_server_tls_policy(&self) -> DeleteServerTlsPolicy
Deletes a single ServerTlsPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, server_tls_policy_id: &str
) -> Result<()> {
client.delete_server_tls_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/serverTlsPolicies/{server_tls_policy_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_client_tls_policies(&self) -> ListClientTlsPolicies
pub fn list_client_tls_policies(&self) -> ListClientTlsPolicies
Lists ClientTlsPolicies in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_client_tls_policies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_client_tls_policy(&self) -> GetClientTlsPolicy
pub fn get_client_tls_policy(&self) -> GetClientTlsPolicy
Gets details of a single ClientTlsPolicy.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, client_tls_policy_id: &str
) -> Result<()> {
let response = client.get_client_tls_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/clientTlsPolicies/{client_tls_policy_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_client_tls_policy(&self) -> CreateClientTlsPolicy
pub fn create_client_tls_policy(&self) -> CreateClientTlsPolicy
Creates a new ClientTlsPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::ClientTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_client_tls_policy()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_client_tls_policy(
ClientTlsPolicy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_client_tls_policy(&self) -> UpdateClientTlsPolicy
pub fn update_client_tls_policy(&self) -> UpdateClientTlsPolicy
Updates the parameters of a single ClientTlsPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::ClientTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, client_tls_policy_id: &str
) -> Result<()> {
let response = client.update_client_tls_policy()
.set_client_tls_policy(
ClientTlsPolicy::new().set_name(format!("projects/{project_id}/locations/{location_id}/clientTlsPolicies/{client_tls_policy_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_client_tls_policy(&self) -> DeleteClientTlsPolicy
pub fn delete_client_tls_policy(&self) -> DeleteClientTlsPolicy
Deletes a single ClientTlsPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, client_tls_policy_id: &str
) -> Result<()> {
client.delete_client_tls_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/clientTlsPolicies/{client_tls_policy_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_gateway_security_policies(&self) -> ListGatewaySecurityPolicies
pub fn list_gateway_security_policies(&self) -> ListGatewaySecurityPolicies
Lists GatewaySecurityPolicies in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_gateway_security_policies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_gateway_security_policy(&self) -> GetGatewaySecurityPolicy
pub fn get_gateway_security_policy(&self) -> GetGatewaySecurityPolicy
Gets details of a single GatewaySecurityPolicy.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str
) -> Result<()> {
let response = client.get_gateway_security_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_gateway_security_policy(&self) -> CreateGatewaySecurityPolicy
pub fn create_gateway_security_policy(&self) -> CreateGatewaySecurityPolicy
Creates a new GatewaySecurityPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_gateway_security_policy()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_gateway_security_policy(
GatewaySecurityPolicy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_gateway_security_policy(&self) -> UpdateGatewaySecurityPolicy
pub fn update_gateway_security_policy(&self) -> UpdateGatewaySecurityPolicy
Updates the parameters of a single GatewaySecurityPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str
) -> Result<()> {
let response = client.update_gateway_security_policy()
.set_gateway_security_policy(
GatewaySecurityPolicy::new().set_name(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_gateway_security_policy(&self) -> DeleteGatewaySecurityPolicy
pub fn delete_gateway_security_policy(&self) -> DeleteGatewaySecurityPolicy
Deletes a single GatewaySecurityPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str
) -> Result<()> {
client.delete_gateway_security_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_gateway_security_policy_rules(
&self,
) -> ListGatewaySecurityPolicyRules
pub fn list_gateway_security_policy_rules( &self, ) -> ListGatewaySecurityPolicyRules
Lists GatewaySecurityPolicyRules in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str
) -> Result<()> {
let mut list = client.list_gateway_security_policy_rules()
.set_parent(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_gateway_security_policy_rule(&self) -> GetGatewaySecurityPolicyRule
pub fn get_gateway_security_policy_rule(&self) -> GetGatewaySecurityPolicyRule
Gets details of a single GatewaySecurityPolicyRule.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str, rule_id: &str
) -> Result<()> {
let response = client.get_gateway_security_policy_rule()
.set_name(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}/rules/{rule_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_gateway_security_policy_rule(
&self,
) -> CreateGatewaySecurityPolicyRule
pub fn create_gateway_security_policy_rule( &self, ) -> CreateGatewaySecurityPolicyRule
Creates a new GatewaySecurityPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicyRule;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str
) -> Result<()> {
let response = client.create_gateway_security_policy_rule()
.set_parent(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}"))
.set_gateway_security_policy_rule(
GatewaySecurityPolicyRule::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_gateway_security_policy_rule(
&self,
) -> UpdateGatewaySecurityPolicyRule
pub fn update_gateway_security_policy_rule( &self, ) -> UpdateGatewaySecurityPolicyRule
Updates the parameters of a single GatewaySecurityPolicyRule.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::GatewaySecurityPolicyRule;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str, rule_id: &str
) -> Result<()> {
let response = client.update_gateway_security_policy_rule()
.set_gateway_security_policy_rule(
GatewaySecurityPolicyRule::new().set_name(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}/rules/{rule_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_gateway_security_policy_rule(
&self,
) -> DeleteGatewaySecurityPolicyRule
pub fn delete_gateway_security_policy_rule( &self, ) -> DeleteGatewaySecurityPolicyRule
Deletes a single GatewaySecurityPolicyRule.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, gateway_security_policy_id: &str, rule_id: &str
) -> Result<()> {
client.delete_gateway_security_policy_rule()
.set_name(format!("projects/{project_id}/locations/{location_id}/gatewaySecurityPolicies/{gateway_security_policy_id}/rules/{rule_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_url_lists(&self) -> ListUrlLists
pub fn list_url_lists(&self) -> ListUrlLists
Lists UrlLists in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_url_lists()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_url_list(&self) -> GetUrlList
pub fn get_url_list(&self) -> GetUrlList
Gets details of a single UrlList.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, url_list_id: &str
) -> Result<()> {
let response = client.get_url_list()
.set_name(format!("projects/{project_id}/locations/{location_id}/urlLists/{url_list_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_url_list(&self) -> CreateUrlList
pub fn create_url_list(&self) -> CreateUrlList
Creates a new UrlList in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::UrlList;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_url_list()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_url_list(
UrlList::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_url_list(&self) -> UpdateUrlList
pub fn update_url_list(&self) -> UpdateUrlList
Updates the parameters of a single UrlList.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::UrlList;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, url_list_id: &str
) -> Result<()> {
let response = client.update_url_list()
.set_url_list(
UrlList::new().set_name(format!("projects/{project_id}/locations/{location_id}/urlLists/{url_list_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_url_list(&self) -> DeleteUrlList
pub fn delete_url_list(&self) -> DeleteUrlList
Deletes a single UrlList.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, url_list_id: &str
) -> Result<()> {
client.delete_url_list()
.set_name(format!("projects/{project_id}/locations/{location_id}/urlLists/{url_list_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_tls_inspection_policies(&self) -> ListTlsInspectionPolicies
pub fn list_tls_inspection_policies(&self) -> ListTlsInspectionPolicies
Lists TlsInspectionPolicies in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, parent: &str
) -> Result<()> {
let mut list = client.list_tls_inspection_policies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_tls_inspection_policy(&self) -> GetTlsInspectionPolicy
pub fn get_tls_inspection_policy(&self) -> GetTlsInspectionPolicy
Gets details of a single TlsInspectionPolicy.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, tls_inspection_policy_id: &str
) -> Result<()> {
let response = client.get_tls_inspection_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/tlsInspectionPolicies/{tls_inspection_policy_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_tls_inspection_policy(&self) -> CreateTlsInspectionPolicy
pub fn create_tls_inspection_policy(&self) -> CreateTlsInspectionPolicy
Creates a new TlsInspectionPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_tls_inspection_policy()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_tls_inspection_policy(
TlsInspectionPolicy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_tls_inspection_policy(&self) -> UpdateTlsInspectionPolicy
pub fn update_tls_inspection_policy(&self) -> UpdateTlsInspectionPolicy
Updates the parameters of a single TlsInspectionPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::TlsInspectionPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, tls_inspection_policy_id: &str
) -> Result<()> {
let response = client.update_tls_inspection_policy()
.set_tls_inspection_policy(
TlsInspectionPolicy::new().set_name(format!("projects/{project_id}/locations/{location_id}/tlsInspectionPolicies/{tls_inspection_policy_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_tls_inspection_policy(&self) -> DeleteTlsInspectionPolicy
pub fn delete_tls_inspection_policy(&self) -> DeleteTlsInspectionPolicy
Deletes a single TlsInspectionPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, tls_inspection_policy_id: &str
) -> Result<()> {
client.delete_tls_inspection_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/tlsInspectionPolicies/{tls_inspection_policy_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_authz_policies(&self) -> ListAuthzPolicies
pub fn list_authz_policies(&self) -> ListAuthzPolicies
Lists AuthzPolicies in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let mut list = client.list_authz_policies()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_authz_policy(&self) -> GetAuthzPolicy
pub fn get_authz_policy(&self) -> GetAuthzPolicy
Gets details of a single AuthzPolicy.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, authz_policy_id: &str
) -> Result<()> {
let response = client.get_authz_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/authzPolicies/{authz_policy_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_authz_policy(&self) -> CreateAuthzPolicy
pub fn create_authz_policy(&self) -> CreateAuthzPolicy
Creates a new AuthzPolicy in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::AuthzPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_authz_policy()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_authz_policy(
AuthzPolicy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_authz_policy(&self) -> UpdateAuthzPolicy
pub fn update_authz_policy(&self) -> UpdateAuthzPolicy
Updates the parameters of a single AuthzPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::AuthzPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, authz_policy_id: &str
) -> Result<()> {
let response = client.update_authz_policy()
.set_authz_policy(
AuthzPolicy::new().set_name(format!("projects/{project_id}/locations/{location_id}/authzPolicies/{authz_policy_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_authz_policy(&self) -> DeleteAuthzPolicy
pub fn delete_authz_policy(&self) -> DeleteAuthzPolicy
Deletes a single AuthzPolicy.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity, project_id: &str, location_id: &str, authz_policy_id: &str
) -> Result<()> {
client.delete_authz_policy()
.set_name(format!("projects/{project_id}/locations/{location_id}/authzPolicies/{authz_policy_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
client: &NetworkSecurity
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for NetworkSecurity
impl Clone for NetworkSecurity
Sourcefn clone(&self) -> NetworkSecurity
fn clone(&self) -> NetworkSecurity
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more