NetworkSecurity

Struct NetworkSecurity 

pub struct NetworkSecurity { /* private fields */ }
Implements a client for the Network Security API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = NetworkSecurity::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_authorization_policies()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Network Security API provides resources to configure authentication and authorization policies. Refer to per API resource documentation for more information.

Configuration

To configure NetworkSecurity use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://networksecurity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

NetworkSecurity holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap NetworkSecurity in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl NetworkSecurity

pub fn builder() -> ClientBuilder

Returns a builder for NetworkSecurity.

let client = NetworkSecurity::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: NetworkSecurity + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_authorization_policies(&self) -> ListAuthorizationPolicies

Lists AuthorizationPolicies in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, parent: &str
) -> Result<()> {
    let mut list = client.list_authorization_policies()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_authorization_policy(&self) -> GetAuthorizationPolicy

Gets details of a single AuthorizationPolicy.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    let response = client.get_authorization_policy()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_authorization_policy(&self) -> CreateAuthorizationPolicy

Creates a new AuthorizationPolicy in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::AuthorizationPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, parent: &str
) -> Result<()> {
    let response = client.create_authorization_policy()
        .set_parent(parent)
        .set_authorization_policy(
            AuthorizationPolicy::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_authorization_policy(&self) -> UpdateAuthorizationPolicy

Updates the parameters of a single AuthorizationPolicy.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::AuthorizationPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    let response = client.update_authorization_policy()
        .set_authorization_policy(
            AuthorizationPolicy::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_authorization_policy(&self) -> DeleteAuthorizationPolicy

Deletes a single AuthorizationPolicy.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    client.delete_authorization_policy()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_server_tls_policies(&self) -> ListServerTlsPolicies

Lists ServerTlsPolicies in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, parent: &str
) -> Result<()> {
    let mut list = client.list_server_tls_policies()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_server_tls_policy(&self) -> GetServerTlsPolicy

Gets details of a single ServerTlsPolicy.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    let response = client.get_server_tls_policy()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_server_tls_policy(&self) -> CreateServerTlsPolicy

Creates a new ServerTlsPolicy in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::ServerTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, parent: &str
) -> Result<()> {
    let response = client.create_server_tls_policy()
        .set_parent(parent)
        .set_server_tls_policy(
            ServerTlsPolicy::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_server_tls_policy(&self) -> UpdateServerTlsPolicy

Updates the parameters of a single ServerTlsPolicy.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::ServerTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    let response = client.update_server_tls_policy()
        .set_server_tls_policy(
            ServerTlsPolicy::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_server_tls_policy(&self) -> DeleteServerTlsPolicy

Deletes a single ServerTlsPolicy.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    client.delete_server_tls_policy()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_client_tls_policies(&self) -> ListClientTlsPolicies

Lists ClientTlsPolicies in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, parent: &str
) -> Result<()> {
    let mut list = client.list_client_tls_policies()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_client_tls_policy(&self) -> GetClientTlsPolicy

Gets details of a single ClientTlsPolicy.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    let response = client.get_client_tls_policy()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_client_tls_policy(&self) -> CreateClientTlsPolicy

Creates a new ClientTlsPolicy in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::model::ClientTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, parent: &str
) -> Result<()> {
    let response = client.create_client_tls_policy()
        .set_parent(parent)
        .set_client_tls_policy(
            ClientTlsPolicy::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_client_tls_policy(&self) -> UpdateClientTlsPolicy

Updates the parameters of a single ClientTlsPolicy.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networksecurity_v1::model::ClientTlsPolicy;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    let response = client.update_client_tls_policy()
        .set_client_tls_policy(
            ClientTlsPolicy::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_client_tls_policy(&self) -> DeleteClientTlsPolicy

Deletes a single ClientTlsPolicy.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity, name: &str
) -> Result<()> {
    client.delete_client_tls_policy()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networksecurity_v1::Result;
async fn sample(
   client: &NetworkSecurity
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}