The messages and enums that are part of this client library.
Modules
- address_
group - Defines additional types related to AddressGroup.
- authorization_
policy - Defines additional types related to AuthorizationPolicy.
- authz_
policy - Defines additional types related to AuthzPolicy.
- backend_
authentication_ config - Defines additional types related to BackendAuthenticationConfig.
- certificate_
provider - Defines additional types related to CertificateProvider.
- dns_
threat_ detector - Defines additional types related to DnsThreatDetector.
- firewall_
endpoint - Defines additional types related to FirewallEndpoint.
- firewall_
endpoint_ association - Defines additional types related to FirewallEndpointAssociation.
- gateway_
security_ policy_ rule - Defines additional types related to GatewaySecurityPolicyRule.
- intercept_
deployment - Defines additional types related to InterceptDeployment.
- intercept_
deployment_ group - Defines additional types related to InterceptDeploymentGroup.
- intercept_
endpoint_ group - Defines additional types related to InterceptEndpointGroup.
- intercept_
endpoint_ group_ association - Defines additional types related to InterceptEndpointGroupAssociation.
- intercept_
location - Defines additional types related to InterceptLocation.
- list_
address_ group_ references_ response - Defines additional types related to ListAddressGroupReferencesResponse.
- mirroring_
deployment - Defines additional types related to MirroringDeployment.
- mirroring_
deployment_ group - Defines additional types related to MirroringDeploymentGroup.
- mirroring_
endpoint_ group - Defines additional types related to MirroringEndpointGroup.
- mirroring_
endpoint_ group_ association - Defines additional types related to MirroringEndpointGroupAssociation.
- mirroring_
location - Defines additional types related to MirroringLocation.
- security_
profile - Defines additional types related to SecurityProfile.
- server_
tls_ policy - Defines additional types related to ServerTlsPolicy.
- tls_
inspection_ policy - Defines additional types related to TlsInspectionPolicy.
- url_
filter - Defines additional types related to UrlFilter.
- validation_
ca - Defines additional types related to ValidationCA.
Structs
- AddAddress
Group Items Request - Request used by the AddAddressGroupItems method.
- Address
Group - AddressGroup is a resource that specifies how a collection of IP/DNS used in Firewall Policy.
- Antivirus
Override - Defines what action to take for antivirus threats per protocol.
- Authorization
Policy - AuthorizationPolicy is a resource that specifies how a server should authorize incoming connections. This resource in itself does not change the configuration unless it’s attached to a target https proxy or endpoint config selector resource.
- Authz
Policy AuthzPolicyis a resource that allows to forward traffic to a callout backend designed to scan the traffic for security purposes.- Backend
Authentication Config - BackendAuthenticationConfig message groups the TrustConfig together with other settings that control how the load balancer authenticates, and expresses its identity to, the backend:
- Certificate
Provider - Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication.
- Certificate
Provider Instance - Specification of a TLS certificate provider instance. Workloads may have one or more CertificateProvider instances (plugins) and one of them is enabled and configured by specifying this message. Workloads use the values from this message to locate and load the CertificateProvider instance configuration.
- Client
TlsPolicy - ClientTlsPolicy is a resource that specifies how a client should authenticate connections to backends of a service. This resource itself does not affect configuration unless it is attached to a backend service resource.
- Clone
Address Group Items Request - Request used by the CloneAddressGroupItems method.
- Create
Address Group Request - Request used by the CreateAddressGroup method.
- Create
Authorization Policy Request - Request used by the CreateAuthorizationPolicy method.
- Create
Authz Policy Request - Message for creating an
AuthzPolicyresource. - Create
Backend Authentication Config Request - Request used by the CreateBackendAuthenticationConfig method.
- Create
Client TlsPolicy Request - Request used by the CreateClientTlsPolicy method.
- Create
DnsThreat Detector Request - The message to create a DnsThreatDetector.
- Create
Firewall Endpoint Association Request - Message for creating a Association
- Create
Firewall Endpoint Request - Message for creating a Endpoint
- Create
Gateway Security Policy Request - Request used by the CreateGatewaySecurityPolicy method.
- Create
Gateway Security Policy Rule Request - Methods for GatewaySecurityPolicy RULES/GatewaySecurityPolicyRules. Request used by the CreateGatewaySecurityPolicyRule method.
- Create
Intercept Deployment Group Request - Request message for CreateInterceptDeploymentGroup.
- Create
Intercept Deployment Request - Request message for CreateInterceptDeployment.
- Create
Intercept Endpoint Group Association Request - Request message for CreateInterceptEndpointGroupAssociation.
- Create
Intercept Endpoint Group Request - Request message for CreateInterceptEndpointGroup.
- Create
Mirroring Deployment Group Request - Request message for CreateMirroringDeploymentGroup.
- Create
Mirroring Deployment Request - Request message for CreateMirroringDeployment.
- Create
Mirroring Endpoint Group Association Request - Request message for CreateMirroringEndpointGroupAssociation.
- Create
Mirroring Endpoint Group Request - Request message for CreateMirroringEndpointGroup.
- Create
Security Profile Group Request - Request used by the CreateSecurityProfileGroup method.
- Create
Security Profile Request - Request used by the CreateSecurityProfile method.
- Create
Server TlsPolicy Request - Request used by the CreateServerTlsPolicy method.
- Create
TlsInspection Policy Request - Request used by the CreateTlsInspectionPolicy method.
- Create
UrlList Request - Request used by the CreateUrlList method.
- Custom
Intercept Profile - CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
- Custom
Mirroring Profile - CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.
- Delete
Address Group Request - Request used by the DeleteAddressGroup method.
- Delete
Authorization Policy Request - Request used by the DeleteAuthorizationPolicy method.
- Delete
Authz Policy Request - Message for deleting an
AuthzPolicyresource. - Delete
Backend Authentication Config Request - Request used by the DeleteBackendAuthenticationConfig method.
- Delete
Client TlsPolicy Request - Request used by the DeleteClientTlsPolicy method.
- Delete
DnsThreat Detector Request - The message for deleting a DnsThreatDetector.
- Delete
Firewall Endpoint Association Request - Message for deleting a Association
- Delete
Firewall Endpoint Request - Message for deleting a Endpoint
- Delete
Gateway Security Policy Request - Request used by the DeleteGatewaySecurityPolicy method.
- Delete
Gateway Security Policy Rule Request - Request used by the DeleteGatewaySecurityPolicyRule method.
- Delete
Intercept Deployment Group Request - Request message for DeleteInterceptDeploymentGroup.
- Delete
Intercept Deployment Request - Request message for DeleteInterceptDeployment.
- Delete
Intercept Endpoint Group Association Request - Request message for DeleteInterceptEndpointGroupAssociation.
- Delete
Intercept Endpoint Group Request - Request message for DeleteInterceptEndpointGroup.
- Delete
Mirroring Deployment Group Request - Request message for DeleteMirroringDeploymentGroup.
- Delete
Mirroring Deployment Request - Request message for DeleteMirroringDeployment.
- Delete
Mirroring Endpoint Group Association Request - Request message for DeleteMirroringEndpointGroupAssociation.
- Delete
Mirroring Endpoint Group Request - Request message for DeleteMirroringEndpointGroup.
- Delete
Security Profile Group Request - Request used by the DeleteSecurityProfileGroup method.
- Delete
Security Profile Request - Request used by the DeleteSecurityProfile method.
- Delete
Server TlsPolicy Request - Request used by the DeleteServerTlsPolicy method.
- Delete
TlsInspection Policy Request - Request used by the DeleteTlsInspectionPolicy method.
- Delete
UrlList Request - Request used by the DeleteUrlList method.
- DnsThreat
Detector - A DNS threat detector sends DNS query logs to a provider that then
analyzes the logs to identify threat events in the DNS queries.
By default, all VPC networks in your projects are included. You can exclude
specific networks by supplying
excluded_networks. - Firewall
Endpoint - Message describing Endpoint object.
- Firewall
Endpoint Association - Message describing Association object
- Gateway
Security Policy - The GatewaySecurityPolicy resource contains a collection of GatewaySecurityPolicyRules and associated metadata.
- Gateway
Security Policy Rule - The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.
- GetAddress
Group Request - Request used by the GetAddressGroup method.
- GetAuthorization
Policy Request - Request used by the GetAuthorizationPolicy method.
- GetAuthz
Policy Request - Message for getting a
AuthzPolicyresource. - GetBackend
Authentication Config Request - Request used by the GetBackendAuthenticationConfig method.
- GetClient
TlsPolicy Request - Request used by the GetClientTlsPolicy method.
- GetDns
Threat Detector Request - The message sent to get a DnsThreatDetector.
- GetFirewall
Endpoint Association Request - Message for getting a Association
- GetFirewall
Endpoint Request - Message for getting a Endpoint
- GetGateway
Security Policy Request - Request used by the GetGatewaySecurityPolicy method.
- GetGateway
Security Policy Rule Request - Request used by the GetGatewaySecurityPolicyRule method.
- GetIntercept
Deployment Group Request - Request message for GetInterceptDeploymentGroup.
- GetIntercept
Deployment Request - Request message for GetInterceptDeployment.
- GetIntercept
Endpoint Group Association Request - Request message for GetInterceptEndpointGroupAssociation.
- GetIntercept
Endpoint Group Request - Request message for GetInterceptEndpointGroup.
- GetMirroring
Deployment Group Request - Request message for GetMirroringDeploymentGroup.
- GetMirroring
Deployment Request - Request message for GetMirroringDeployment.
- GetMirroring
Endpoint Group Association Request - Request message for GetMirroringEndpointGroupAssociation.
- GetMirroring
Endpoint Group Request - Request message for GetMirroringEndpointGroup.
- GetSecurity
Profile Group Request - Request used by the GetSecurityProfileGroup method.
- GetSecurity
Profile Request - Request used by the GetSecurityProfile method.
- GetServer
TlsPolicy Request - Request used by the GetServerTlsPolicy method.
- GetTls
Inspection Policy Request - Request used by the GetTlsInspectionPolicy method.
- GetUrl
List Request - Request used by the GetUrlList method.
- Grpc
Endpoint - Specification of the GRPC Endpoint.
- Intercept
Deployment - A deployment represents a zonal intercept backend ready to accept GENEVE-encapsulated traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global intercept service.
- Intercept
Deployment Group - A deployment group aggregates many zonal intercept backends (deployments) into a single global intercept service. Consumers can connect this service using an endpoint group.
- Intercept
Endpoint Group - An endpoint group is a consumer frontend for a deployment group (backend). In order to configure intercept for a network, consumers must create:
- Intercept
Endpoint Group Association - An endpoint group association represents a link between a network and an endpoint group in the organization.
- Intercept
Location - Details about intercept in a specific cloud location.
- List
Address Group References Request - Request used by the ListAddressGroupReferences method.
- List
Address Group References Response - Response of the ListAddressGroupReferences method.
- List
Address Groups Request - Request used with the ListAddressGroups method.
- List
Address Groups Response - Response returned by the ListAddressGroups method.
- List
Authorization Policies Request - Request used with the ListAuthorizationPolicies method.
- List
Authorization Policies Response - Response returned by the ListAuthorizationPolicies method.
- List
Authz Policies Request - Message for requesting list of
AuthzPolicyresources. - List
Authz Policies Response - Message for response to listing
AuthzPolicyresources. - List
Backend Authentication Configs Request - Request used by the ListBackendAuthenticationConfigs method.
- List
Backend Authentication Configs Response - Response returned by the ListBackendAuthenticationConfigs method.
- List
Client TlsPolicies Request - Request used by the ListClientTlsPolicies method.
- List
Client TlsPolicies Response - Response returned by the ListClientTlsPolicies method.
- List
DnsThreat Detectors Request - The message for requesting a list of DnsThreatDetectors in the project.
- List
DnsThreat Detectors Response - The response message to requesting a list of DnsThreatDetectors.
- List
Firewall Endpoint Associations Request - Message for requesting list of Associations
- List
Firewall Endpoint Associations Response - Message for response to listing Associations
- List
Firewall Endpoints Request - Message for requesting list of Endpoints
- List
Firewall Endpoints Response - Message for response to listing Endpoints
- List
Gateway Security Policies Request - Request used with the ListGatewaySecurityPolicies method.
- List
Gateway Security Policies Response - Response returned by the ListGatewaySecurityPolicies method.
- List
Gateway Security Policy Rules Request - Request used with the ListGatewaySecurityPolicyRules method.
- List
Gateway Security Policy Rules Response - Response returned by the ListGatewaySecurityPolicyRules method.
- List
Intercept Deployment Groups Request - Request message for ListInterceptDeploymentGroups.
- List
Intercept Deployment Groups Response - Response message for ListInterceptDeploymentGroups.
- List
Intercept Deployments Request - Request message for ListInterceptDeployments.
- List
Intercept Deployments Response - Response message for ListInterceptDeployments.
- List
Intercept Endpoint Group Associations Request - Request message for ListInterceptEndpointGroupAssociations.
- List
Intercept Endpoint Group Associations Response - Response message for ListInterceptEndpointGroupAssociations.
- List
Intercept Endpoint Groups Request - Request message for ListInterceptEndpointGroups.
- List
Intercept Endpoint Groups Response - Response message for ListInterceptEndpointGroups.
- List
Mirroring Deployment Groups Request - Request message for ListMirroringDeploymentGroups.
- List
Mirroring Deployment Groups Response - Response message for ListMirroringDeploymentGroups.
- List
Mirroring Deployments Request - Request message for ListMirroringDeployments.
- List
Mirroring Deployments Response - Response message for ListMirroringDeployments.
- List
Mirroring Endpoint Group Associations Request - Request message for ListMirroringEndpointGroupAssociations.
- List
Mirroring Endpoint Group Associations Response - Response message for ListMirroringEndpointGroupAssociations.
- List
Mirroring Endpoint Groups Request - Request message for ListMirroringEndpointGroups.
- List
Mirroring Endpoint Groups Response - Response message for ListMirroringEndpointGroups.
- List
Security Profile Groups Request - Request used with the ListSecurityProfileGroups method.
- List
Security Profile Groups Response - Response returned by the ListSecurityProfileGroups method.
- List
Security Profiles Request - Request used with the ListSecurityProfiles method.
- List
Security Profiles Response - Response returned by the ListSecurityProfiles method.
- List
Server TlsPolicies Request - Request used by the ListServerTlsPolicies method.
- List
Server TlsPolicies Response - Response returned by the ListServerTlsPolicies method.
- List
TlsInspection Policies Request - Request used with the ListTlsInspectionPolicies method.
- List
TlsInspection Policies Response - Response returned by the ListTlsInspectionPolicies method.
- List
UrlLists Request - Request used by the ListUrlList method.
- List
UrlLists Response - Response returned by the ListUrlLists method.
- Mirroring
Deployment - A deployment represents a zonal mirroring backend ready to accept GENEVE-encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.
- Mirroring
Deployment Group - A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.
- Mirroring
Endpoint Group - An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create:
- Mirroring
Endpoint Group Association - An endpoint group association represents a link between a network and an endpoint group in the organization.
- Mirroring
Location - Details about mirroring in a specific cloud location.
- Operation
Metadata - Represents the metadata of the long-running operation.
- Remove
Address Group Items Request - Request used by the RemoveAddressGroupItems method.
- Security
Profile - SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
- Security
Profile Group - SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
- Server
TlsPolicy - ServerTlsPolicy is a resource that specifies how a server should authenticate incoming requests. This resource itself does not affect configuration unless it is attached to a target HTTPS proxy or endpoint config selector resource.
- Severity
Override - Defines what action to take for a specific severity match.
- Threat
Override - Defines what action to take for a specific threat_id match.
- Threat
Prevention Profile - ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
- TlsInspection
Policy - The TlsInspectionPolicy resource contains references to CA pools in Certificate Authority Service and associated metadata.
- Update
Address Group Request - Request used by the UpdateAddressGroup method.
- Update
Authorization Policy Request - Request used by the UpdateAuthorizationPolicy method.
- Update
Authz Policy Request - Message for updating an
AuthzPolicyresource. - Update
Backend Authentication Config Request - Request used by UpdateBackendAuthenticationConfig method.
- Update
Client TlsPolicy Request - Request used by UpdateClientTlsPolicy method.
- Update
DnsThreat Detector Request - The message for updating a DnsThreatDetector.
- Update
Firewall Endpoint Association Request - Message for updating an Association
- Update
Firewall Endpoint Request - Message for updating a Endpoint
- Update
Gateway Security Policy Request - Request used by the UpdateGatewaySecurityPolicy method.
- Update
Gateway Security Policy Rule Request - Request used by the UpdateGatewaySecurityPolicyRule method.
- Update
Intercept Deployment Group Request - Request message for UpdateInterceptDeploymentGroup.
- Update
Intercept Deployment Request - Request message for UpdateInterceptDeployment.
- Update
Intercept Endpoint Group Association Request - Request message for UpdateInterceptEndpointGroupAssociation.
- Update
Intercept Endpoint Group Request - Request message for UpdateInterceptEndpointGroup.
- Update
Mirroring Deployment Group Request - Request message for UpdateMirroringDeploymentGroup.
- Update
Mirroring Deployment Request - Request message for UpdateMirroringDeployment.
- Update
Mirroring Endpoint Group Association Request - Request message for UpdateMirroringEndpointGroupAssociation.
- Update
Mirroring Endpoint Group Request - Request message for UpdateMirroringEndpointGroup.
- Update
Security Profile Group Request - Request used by the UpdateSecurityProfileGroup method.
- Update
Security Profile Request - Request used by the UpdateSecurityProfile method.
- Update
Server TlsPolicy Request - Request used by UpdateServerTlsPolicy method.
- Update
TlsInspection Policy Request - Request used by the UpdateTlsInspectionPolicy method.
- Update
UrlList Request - Request used by UpdateUrlList method.
- UrlFilter
- A URL filter defines an action to take for some URL match.
- UrlFiltering
Profile - UrlFilteringProfile defines filters based on URL.
- UrlList
- UrlList proto helps users to set reusable, independently manageable lists of hosts, host patterns, URLs, URL patterns.
- ValidationCA
- Specification of ValidationCA. Defines the mechanism to obtain the Certificate Authority certificate to validate the peer certificate.
Enums
- Protocol
- Antivirus protocol.
- Severity
- Severity level.
- Threat
Action - Threat action override.
- Threat
Type - Type of threat.