#[non_exhaustive]pub enum LoadBalancingScheme {
Unspecified,
InternalManaged,
ExternalManaged,
InternalSelfManaged,
UnknownValue(UnknownValue),
}Expand description
Load balancing schemes supported by the AuthzPolicy resource. The valid
values are INTERNAL_MANAGED and
EXTERNAL_MANAGED. For more information, refer to Backend services
overview.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. Do not use.
InternalManaged
Signifies that this is used for Regional internal or Cross-region internal Application Load Balancing.
ExternalManaged
Signifies that this is used for Global external or Regional external Application Load Balancing.
InternalSelfManaged
Signifies that this is used for Cloud Service Mesh. Meant for use by CSM GKE controller only.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LoadBalancingScheme::value or LoadBalancingScheme::name.
Implementations