AntivirusOverride

Struct AntivirusOverride 

#[non_exhaustive]
pub struct AntivirusOverride { pub protocol: Protocol, pub action: ThreatAction, /* private fields */ }
Defines what action to take for antivirus threats per protocol.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
protocol: Protocol

Required. Protocol to match.

action: ThreatAction

Required. Threat action override. For some threat types, only a subset of actions applies.

Implementations

Source

impl AntivirusOverride

pub fn new() -> Self

pub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self

Sets the value of protocol.

Example
use google_cloud_networksecurity_v1::model::Protocol;
let x0 = AntivirusOverride::new().set_protocol(Protocol::Smtp);
let x1 = AntivirusOverride::new().set_protocol(Protocol::Smb);
let x2 = AntivirusOverride::new().set_protocol(Protocol::Pop3);
pub fn set_action<T: Into<ThreatAction>>(self, v: T) -> Self

Sets the value of action.

Example
use google_cloud_networksecurity_v1::model::ThreatAction;
let x0 = AntivirusOverride::new().set_action(ThreatAction::DefaultAction);
let x1 = AntivirusOverride::new().set_action(ThreatAction::Allow);
let x2 = AntivirusOverride::new().set_action(ThreatAction::Alert);