BackendAuthenticationConfig

Struct BackendAuthenticationConfig 

#[non_exhaustive]
pub struct BackendAuthenticationConfig { pub name: String, pub description: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub client_certificate: String, pub trust_config: String, pub well_known_roots: WellKnownRoots, pub etag: String, /* private fields */ }
BackendAuthenticationConfig message groups the TrustConfig together with other settings that control how the load balancer authenticates, and expresses its identity to, the backend:

  • trustConfig is the attached TrustConfig.

  • wellKnownRoots indicates whether the load balance should trust backend server certificates that are issued by public certificate authorities, in addition to certificates trusted by the TrustConfig.

  • clientCertificate is a client certificate that the load balancer uses to express its identity to the backend, if the connection to the backend uses mTLS.

You can attach the BackendAuthenticationConfig to the load balancer’s BackendService directly determining how that BackendService negotiates TLS.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. Name of the BackendAuthenticationConfig resource. It matches the pattern projects/*/locations/{location}/backendAuthenticationConfigs/{backend_authentication_config}

description: String

Optional. Free-text description of the resource.

create_time: Option<Timestamp>

Output only. The timestamp when the resource was created.

update_time: Option<Timestamp>

Output only. The timestamp when the resource was updated.

labels: HashMap<String, String>

Set of label tags associated with the resource.

client_certificate: String

Optional. A reference to a certificatemanager.googleapis.com.Certificate resource. This is a relative resource path following the form “projects/{project}/locations/{location}/certificates/{certificate}”.

Used by a BackendService to negotiate mTLS when the backend connection uses TLS and the backend requests a client certificate. Must have a CLIENT_AUTH scope.

trust_config: String

Optional. A reference to a TrustConfig resource from the certificatemanager.googleapis.com namespace. This is a relative resource path following the form “projects/{project}/locations/{location}/trustConfigs/{trust_config}”.

A BackendService uses the chain of trust represented by this TrustConfig, if specified, to validate the server certificates presented by the backend. Required unless wellKnownRoots is set to PUBLIC_ROOTS.

well_known_roots: WellKnownRoots

Well known roots to use for server certificate validation.

etag: String

Output only. Etag of the resource.

Implementations

Source

impl BackendAuthenticationConfig

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = BackendAuthenticationConfig::new().set_name("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = BackendAuthenticationConfig::new().set_description("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = BackendAuthenticationConfig::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = BackendAuthenticationConfig::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = BackendAuthenticationConfig::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = BackendAuthenticationConfig::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = BackendAuthenticationConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = BackendAuthenticationConfig::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = BackendAuthenticationConfig::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_client_certificate<T: Into<String>>(self, v: T) -> Self

Sets the value of client_certificate.

Example
let x = BackendAuthenticationConfig::new().set_client_certificate("example");
pub fn set_trust_config<T: Into<String>>(self, v: T) -> Self

Sets the value of trust_config.

Example
let x = BackendAuthenticationConfig::new().set_trust_config("example");
pub fn set_well_known_roots<T: Into<WellKnownRoots>>(self, v: T) -> Self

Sets the value of well_known_roots.

Example
use google_cloud_networksecurity_v1::model::backend_authentication_config::WellKnownRoots;
let x0 = BackendAuthenticationConfig::new().set_well_known_roots(WellKnownRoots::None);
let x1 = BackendAuthenticationConfig::new().set_well_known_roots(WellKnownRoots::PublicRoots);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = BackendAuthenticationConfig::new().set_etag("example");