#[non_exhaustive]pub struct CreateInterceptEndpointGroupAssociationRequest {
pub parent: String,
pub intercept_endpoint_group_association_id: String,
pub intercept_endpoint_group_association: Option<InterceptEndpointGroupAssociation>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateInterceptEndpointGroupAssociation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this association will be created. Format: projects/{project}/locations/{location}
intercept_endpoint_group_association_id: StringOptional. The ID to use for the new association, which will become the final component of the endpoint group’s resource name. If not provided, the server will generate a unique ID.
intercept_endpoint_group_association: Option<InterceptEndpointGroupAssociation>Required. The association to create.
request_id: StringOptional. A unique identifier for this request. Must be a UUID4.
This request is only idempotent if a request_id is provided.
See https://google.aip.dev/155 for more details.
Implementations
Sourceimpl CreateInterceptEndpointGroupAssociationRequest
impl CreateInterceptEndpointGroupAssociationRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_intercept_endpoint_group_association_id<T: Into<String>>(
self,
v: T,
) -> Self
pub fn set_intercept_endpoint_group_association_id<T: Into<String>>( self, v: T, ) -> Self
Sets the value of intercept_endpoint_group_association_id.
Example
let x = CreateInterceptEndpointGroupAssociationRequest::new().set_intercept_endpoint_group_association_id("example");Sourcepub fn set_intercept_endpoint_group_association<T>(self, v: T) -> Selfwhere
T: Into<InterceptEndpointGroupAssociation>,
pub fn set_intercept_endpoint_group_association<T>(self, v: T) -> Selfwhere
T: Into<InterceptEndpointGroupAssociation>,
Sets the value of intercept_endpoint_group_association.
Example
use google_cloud_networksecurity_v1::model::InterceptEndpointGroupAssociation;
let x = CreateInterceptEndpointGroupAssociationRequest::new().set_intercept_endpoint_group_association(InterceptEndpointGroupAssociation::default()/* use setters */);Sourcepub fn set_or_clear_intercept_endpoint_group_association<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<InterceptEndpointGroupAssociation>,
pub fn set_or_clear_intercept_endpoint_group_association<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<InterceptEndpointGroupAssociation>,
Sets or clears the value of intercept_endpoint_group_association.
Example
use google_cloud_networksecurity_v1::model::InterceptEndpointGroupAssociation;
let x = CreateInterceptEndpointGroupAssociationRequest::new().set_or_clear_intercept_endpoint_group_association(Some(InterceptEndpointGroupAssociation::default()/* use setters */));
let x = CreateInterceptEndpointGroupAssociationRequest::new().set_or_clear_intercept_endpoint_group_association(None::<InterceptEndpointGroupAssociation>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateInterceptEndpointGroupAssociationRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateInterceptEndpointGroupAssociationRequest
impl Clone for CreateInterceptEndpointGroupAssociationRequest
Sourcefn clone(&self) -> CreateInterceptEndpointGroupAssociationRequest
fn clone(&self) -> CreateInterceptEndpointGroupAssociationRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateInterceptEndpointGroupAssociationRequest
impl Default for CreateInterceptEndpointGroupAssociationRequest
Sourcefn default() -> CreateInterceptEndpointGroupAssociationRequest
fn default() -> CreateInterceptEndpointGroupAssociationRequest
Sourceimpl PartialEq for CreateInterceptEndpointGroupAssociationRequest
impl PartialEq for CreateInterceptEndpointGroupAssociationRequest
Sourcefn eq(&self, other: &CreateInterceptEndpointGroupAssociationRequest) -> bool
fn eq(&self, other: &CreateInterceptEndpointGroupAssociationRequest) -> bool
self and other values to be equal, and is used by ==.