#[non_exhaustive]pub struct FirewallEndpoint {Show 13 fields
pub name: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub state: State,
pub reconciling: bool,
pub associated_networks: Vec<String>,
pub associations: Vec<AssociationReference>,
pub satisfies_pzs: Option<bool>,
pub satisfies_pzi: Option<bool>,
pub billing_project_id: String,
pub endpoint_settings: Option<EndpointSettings>,
/* private fields */
}Expand description
Message describing Endpoint object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. Identifier. Name of resource.
description: StringOptional. Description of the firewall endpoint. Max length 2048 characters.
create_time: Option<Timestamp>Output only. Create time stamp.
update_time: Option<Timestamp>Output only. Update time stamp
labels: HashMap<String, String>Optional. Labels as key value pairs
state: StateOutput only. Current state of the endpoint.
reconciling: boolOutput only. Whether reconciling is in progress, recommended per https://google.aip.dev/128.
associated_networks: Vec<String>Output only. Deprecated: List of networks that are associated with this endpoint in the local zone. This is a projection of the FirewallEndpointAssociations pointing at this endpoint. A network will only appear in this list after traffic routing is fully configured. Format: projects/{project}/global/networks/{name}.
associations: Vec<AssociationReference>Output only. List of FirewallEndpointAssociations that are associated to this endpoint. An association will only appear in this list after traffic routing is fully configured.
satisfies_pzs: Option<bool>Output only. [Output Only] Reserved for future use.
satisfies_pzi: Option<bool>Output only. [Output Only] Reserved for future use.
billing_project_id: StringOptional. Project to charge for the deployed firewall endpoint. This field must be specified when creating the endpoint in the organization scope, and should be omitted otherwise.
endpoint_settings: Option<EndpointSettings>Optional. Settings for the endpoint.
Implementations
Sourceimpl FirewallEndpoint
impl FirewallEndpoint
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = FirewallEndpoint::new().set_description("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = FirewallEndpoint::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = FirewallEndpoint::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FirewallEndpoint::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_associated_networks<T, V>(self, v: T) -> Self
👎Deprecated
pub fn set_associated_networks<T, V>(self, v: T) -> Self
Sets the value of associated_networks.
Example
let x = FirewallEndpoint::new().set_associated_networks(["a", "b", "c"]);Sourcepub fn set_associations<T, V>(self, v: T) -> Self
pub fn set_associations<T, V>(self, v: T) -> Self
Sets the value of associations.
Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::AssociationReference;
let x = FirewallEndpoint::new()
.set_associations([
AssociationReference::default()/* use setters */,
AssociationReference::default()/* use (different) setters */,
]);Sourcepub fn set_satisfies_pzs<T>(self, v: T) -> Self
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzs.
Example
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzs(Some(false));
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzs(None::<bool>);Sourcepub fn set_satisfies_pzi<T>(self, v: T) -> Self
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzi.
Example
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzi(Some(false));
let x = FirewallEndpoint::new().set_or_clear_satisfies_pzi(None::<bool>);Sourcepub fn set_billing_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_billing_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of billing_project_id.
Example
let x = FirewallEndpoint::new().set_billing_project_id("example");Sourcepub fn set_endpoint_settings<T>(self, v: T) -> Selfwhere
T: Into<EndpointSettings>,
pub fn set_endpoint_settings<T>(self, v: T) -> Selfwhere
T: Into<EndpointSettings>,
Sets the value of endpoint_settings.
Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::EndpointSettings;
let x = FirewallEndpoint::new().set_endpoint_settings(EndpointSettings::default()/* use setters */);Sourcepub fn set_or_clear_endpoint_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<EndpointSettings>,
pub fn set_or_clear_endpoint_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<EndpointSettings>,
Sets or clears the value of endpoint_settings.
Example
use google_cloud_networksecurity_v1::model::firewall_endpoint::EndpointSettings;
let x = FirewallEndpoint::new().set_or_clear_endpoint_settings(Some(EndpointSettings::default()/* use setters */));
let x = FirewallEndpoint::new().set_or_clear_endpoint_settings(None::<EndpointSettings>);Trait Implementations
Sourceimpl Clone for FirewallEndpoint
impl Clone for FirewallEndpoint
Sourcefn clone(&self) -> FirewallEndpoint
fn clone(&self) -> FirewallEndpoint
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FirewallEndpoint
impl Debug for FirewallEndpoint
Sourceimpl Default for FirewallEndpoint
impl Default for FirewallEndpoint
Sourcefn default() -> FirewallEndpoint
fn default() -> FirewallEndpoint
Sourceimpl Message for FirewallEndpoint
impl Message for FirewallEndpoint
Sourceimpl PartialEq for FirewallEndpoint
impl PartialEq for FirewallEndpoint
impl StructuralPartialEq for FirewallEndpoint