SecurityProfileGroup

Struct SecurityProfileGroup 

#[non_exhaustive]
pub struct SecurityProfileGroup { pub name: String, pub description: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub etag: String, pub data_path_id: u64, pub labels: HashMap<String, String>, pub threat_prevention_profile: String, pub custom_mirroring_profile: String, pub custom_intercept_profile: String, pub url_filtering_profile: String, /* private fields */ }
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches pattern projects|organizations/*/locations/{location}/securityProfileGroups/{security_profile_group}.

description: String

Optional. An optional description of the profile group. Max length 2048 characters.

create_time: Option<Timestamp>

Output only. Resource creation timestamp.

update_time: Option<Timestamp>

Output only. Last resource update timestamp.

etag: String

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

data_path_id: u64

Output only. Identifier used by the data-path. Unique within {container, location}.

labels: HashMap<String, String>

Optional. Labels as key value pairs.

threat_prevention_profile: String

Optional. Reference to a SecurityProfile with the ThreatPrevention configuration.

custom_mirroring_profile: String

Optional. Reference to a SecurityProfile with the CustomMirroring configuration.

custom_intercept_profile: String

Optional. Reference to a SecurityProfile with the CustomIntercept configuration.

url_filtering_profile: String

Optional. Reference to a SecurityProfile with the UrlFiltering configuration.

Implementations

Source

impl SecurityProfileGroup

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = SecurityProfileGroup::new().set_name("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = SecurityProfileGroup::new().set_description("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = SecurityProfileGroup::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = SecurityProfileGroup::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = SecurityProfileGroup::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = SecurityProfileGroup::new().set_etag("example");
pub fn set_data_path_id<T: Into<u64>>(self, v: T) -> Self

Sets the value of data_path_id.

Example
let x = SecurityProfileGroup::new().set_data_path_id(42_u32);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = SecurityProfileGroup::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_threat_prevention_profile<T: Into<String>>(self, v: T) -> Self

Sets the value of threat_prevention_profile.

Example
let x = SecurityProfileGroup::new().set_threat_prevention_profile("example");
pub fn set_custom_mirroring_profile<T: Into<String>>(self, v: T) -> Self

Sets the value of custom_mirroring_profile.

Example
let x = SecurityProfileGroup::new().set_custom_mirroring_profile("example");
pub fn set_custom_intercept_profile<T: Into<String>>(self, v: T) -> Self

Sets the value of custom_intercept_profile.

Example
let x = SecurityProfileGroup::new().set_custom_intercept_profile("example");
pub fn set_url_filtering_profile<T: Into<String>>(self, v: T) -> Self

Sets the value of url_filtering_profile.

Example
let x = SecurityProfileGroup::new().set_url_filtering_profile("example");